@@ -28,7 +28,9 @@ from kiwi.log import Logger
 
 from stoqlib.database.runtime import get_connection
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.events import StartApplicationEvent
+from stoqlib.gui.editors.producteditor import ProductEditor
+from stoqlib.gui.events import (StartApplicationEvent, StopApplicationEvent,
+                                EditorSlaveCreateEvent)
 from stoqlib.gui.keybindings import add_bindings, get_accels
 from stoqlib.lib.translation import stoqlib_gettext
 
@@ -42,11 +44,14 @@ log = Logger("stoq-books-plugin")
 
 class BooksUI(object):
     def __init__(self):
+        self._ui = None
         self.conn = get_connection()
         StartApplicationEvent.connect(self._on_StartApplicationEvent)
+        StopApplicationEvent.connect(self._on_StopApplicationEvent)
+        EditorSlaveCreateEvent.connect(self._on_EditorSlaveCreateEvent)
         add_bindings([
-            ('plugin.books.search_books', '<Control><Alt>B'),
-            ('plugin.books.search_publishers', '<Control><Alt>P'),
+            ('plugin.books.search_books', '<Primary><Alt>B'),
+            ('plugin.books.search_publishers', '<Primary><Alt>P'),
             ])
 
     #
@@ -56,7 +61,7 @@ class BooksUI(object):
     def _get_menu_ui_string(self):
         return """<ui>
             <menubar name="menubar">
-                <placeholder name="ExtraMenu">
+                <placeholder name="ExtraMenubarPH">
                     <menu action="BooksMenu">
                     %s
                     </menu>
@@ -82,7 +87,7 @@ class BooksUI(object):
         ])
 
         uimanager.insert_action_group(ag, 0)
-        uimanager.add_ui_from_string(ui_string)
+        self._ui = uimanager.add_ui_from_string(ui_string)
 
     def _add_sale_menus(self, uimanager):
         menu_items_str = '<menuitem action="BookSearch"/>'
@@ -98,7 +103,7 @@ class BooksUI(object):
         ])
 
         uimanager.insert_action_group(ag, 0)
-        uimanager.add_ui_from_string(ui_string)
+        self._ui = uimanager.add_ui_from_string(ui_string)
 
     def _add_pos_menus(self, uimanager):
         menu_items_str = '<menuitem action="BookSearch"/>'
@@ -114,15 +119,17 @@ class BooksUI(object):
         ])
 
         uimanager.insert_action_group(ag, 0)
-        uimanager.add_ui_from_string(ui_string)
+        self._ui = uimanager.add_ui_from_string(ui_string)
 
-    #
-    # Accessors
-    #
+    def _remove_app_ui(self, uimanager):
+        if not self._ui:
+            return
+        uimanager.remove_ui(self._ui)
+        self._ui = None
 
-    def get_book_slave(self):
-        """Returns the slave class for product book details UI."""
-        return ProductBookSlave
+    def _add_product_slave(self, editor, model, conn):
+        editor.add_extra_tab(ProductBookSlave.title,
+                             ProductBookSlave(conn, model))
 
     #
     # Events
@@ -136,6 +143,17 @@ class BooksUI(object):
         elif appname == 'pos':
             self._add_pos_menus(app.main_window.uimanager)
 
+    def _on_StopApplicationEvent(self, appname, app):
+        self._remove_app_ui(app.main_window.uimanager)
+
+    def _on_EditorSlaveCreateEvent(self, editor, model, conn, *args):
+        # Use type() instead of isinstance so tab does
+        # not appear on production product editor
+        if not type(editor) is ProductEditor:
+            return
+
+        self._add_product_slave(editor, model, conn)
+
     #
     # Callbacks
     #
