@@ -29,10 +29,8 @@ from stoqlib.database.orm import (DecimalCol, IntCol, UnicodeCol, DateTimeCol,
                                   BoolCol, ForeignKey)
 from stoqlib.database.runtime import get_current_branch, new_transaction
 from stoqlib.domain.base import Domain
-from stoqlib.domain.interfaces import ISalesPerson, IEmployee, IIndividual
-from stoqlib.domain.person import Person
-from stoqlib.domain.product import Product
-from stoqlib.domain.sellable import SellableCategory
+from stoqlib.domain.person import Employee, Individual, Person, SalesPerson
+from stoqlib.domain.sellable import Sellable, SellableCategory
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
 
@@ -59,8 +57,8 @@ class MagentoConfig(Domain):
 
     tz_hours = DecimalCol(default=decimal.Decimal(0))
     qty_days_as_new = IntCol(default=45)
-    branch = ForeignKey('PersonAdaptToBranch')
-    salesperson = ForeignKey('PersonAdaptToSalesPerson')
+    branch = ForeignKey('Branch')
+    salesperson = ForeignKey('SalesPerson')
 
     default_product_set = IntCol(default=None)
     root_category = IntCol(default=None)
@@ -106,14 +104,19 @@ class MagentoConfig(Domain):
     def on_create(self):
         from magentoproduct import MagentoProduct, MagentoCategory
         conn = self.get_connection()
+        sysparam_ = sysparam(conn)
 
         # When commiting, ensure we known all products to synchronize using the
         # server registered on self. Events should take care of creating others
-        for product in Product.select(connection=conn):
+        for sellable in Sellable.select(connection=conn):
+            if sellable.service == sysparam_.DELIVERY_SERVICE:
+                # Do not sync delivery service
+                continue
+
             # Just need to create. All other information will be synchronized
             # on MagentoProduct.synchronize
             mag_product = MagentoProduct(connection=conn,
-                                         product=product,
+                                         sellable=sellable,
                                          config=self)
             assert mag_product
         # Like products above, ensure we know all categories to synchronize.
@@ -142,20 +145,20 @@ class MagentoConfig(Domain):
 
         person = Person(connection=conn,
                         name=name)
-        person.addFacet(IIndividual,
-                        occupation=occupation,
-                        connection=conn)
-        person.addFacet(IEmployee,
-                        role=role,
-                        connection=conn)
+        Individual(person=person,
+                   occupation=occupation,
+                   connection=conn)
+        Employee(person=person,
+                 role=role,
+                 connection=conn)
 
-        return person.addFacet(ISalesPerson, connection=conn)
+        return SalesPerson(person=person, connection=conn)
 
 
 class MagentoTableConfig(Domain):
     """Responsible for storing specific configurations for classes
 
-    @ivar config: the L{MagentoConfig} associated with this obj
+    @ivar config: the :class:`MagentoConfig` associated with this obj
     @ivar magento_table: the name of the table associated with this config
     """
 
