@@ -204,6 +204,7 @@ class StoqCommandHandler:
         trans = new_transaction()
         trans.query("UPDATE parameter_data SET field_value = '1' WHERE field_name = 'DEMO_MODE';")
         trans.commit()
+        trans.close()
 
     def _enable_plugins(self, plugin_names):
         from stoqlib.lib.pluginmanager import (PluginError,
@@ -211,13 +212,17 @@ class StoqCommandHandler:
         manager = get_plugin_manager()
 
         for plugin_name in plugin_names:
+            if plugin_name not in manager.available_plugins_names:
+                print 'ERROR:', plugin_name, 'is not installed.'
+                print "Available plugins are:"
+                for plugin_name in manager.available_plugins_names:
+                    print "  %s" % (plugin_name, )
+                return
+
             try:
                 manager.install_plugin(plugin_name)
             except PluginError as err:
-                print err
-                print "Available plugins:"
-                for plugin_name in manager.available_plugins_names:
-                    print "  %s" % (plugin_name, )
+                print 'ERROR:', err
                 return
 
     def _register_station(self):
@@ -244,6 +249,7 @@ class StoqCommandHandler:
             raise SystemExit("ERROR: %s" % e)
 
         trans.commit()
+        trans.close()
 
     def _create_dbuser(self, username):
         import os
