@@ -41,15 +41,17 @@ from stoqlib.api import api
 from stoqlib.database.orm import ORMObjectQueryExecuter
 from stoqlib.exceptions import StoqlibError
 from stoqlib.lib.crashreport import has_tracebacks
+from stoqlib.lib.decorators import cached_function
 from stoqlib.lib.interfaces import IAppInfo
 from stoqlib.lib.message import yesno
+from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.webservice import WebService
-from stoqlib.gui.base.dialogs import get_dialog, run_dialog
-from stoqlib.gui.base.infobar import InfoBar
+from stoqlib.gui.base.dialogs import (get_dialog, run_dialog,
+                                      get_current_toplevel)
 from stoqlib.gui.base.search import StoqlibSearchSlaveDelegate
 from stoqlib.gui.dialogs.crashreportdialog import show_dialog
 from stoqlib.gui.dialogs.feedbackdialog import FeedbackDialog
-from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporterDialog
+from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporter
 from stoqlib.gui.editors.preferenceseditor import PreferencesEditor
 from stoqlib.gui.events import StopApplicationEvent
 from stoqlib.gui.help import show_contents, show_section
@@ -58,7 +60,6 @@ from stoqlib.gui.keybindings import get_accel, get_accels
 from stoqlib.gui.logo import render_logo_pixbuf
 from stoqlib.gui.openbrowser import open_browser
 from stoqlib.gui.printing import print_report
-from stoqlib.gui.splash import hide_splash
 from stoqlib.gui.toolmenuaction import ToolMenuAction
 from stoqlib.domain.inventory import Inventory
 from twisted.internet import reactor
@@ -157,7 +158,8 @@ class App(object):
                  launcher, name):
         """
         Create a new object App.
-        @param main_window_class: A eAppWindow subclass
+
+        :param main_window_class: A eAppWindow subclass
         """
         if not issubclass(window_class, AppWindow):
             raise TypeError
@@ -190,17 +192,16 @@ class App(object):
 
 class AppWindow(GladeDelegate):
     """ Class for the main window of applications.
-
-    @cvar app_name: This attribute is used when generating titles for
-                    applications.  It's also useful if we get a list of
-                    available applications with the application names
-                    translated. This list is going to be used when
-                    creating new user profiles.
-
     """
 
     app_windows = []
+
+    #: This attribute is used when generating titles for applications.
+    #: It's also useful if we get a list of available applications with
+    #: the application names translated. This list is going to be used when
+    #: creating new user profiles.
     app_name = None
+
     search = None
     gladefile = toplevel_name = ''
     title = ''
@@ -294,15 +295,22 @@ class AppWindow(GladeDelegate):
         if self.app.name != 'launcher':
             return
 
-        hide_splash()
         AppWindow.app_windows.append(self)
         self._restore_window_size()
         self.hide_app()
 
         self._check_demo_mode()
-        self._check_version()
         self._update_toolbar_style()
 
+        # json will restore tuples as lists. We need to convert them
+        # to tuples or the comparison bellow won't work.
+        actual_version = tuple(api.user_settings.get('actual-version', (0,)))
+        if stoq.stoq_version > actual_version:
+            api.user_settings.set('last-version-check', None)
+            self._display_changelog_message()
+
+        self._check_version()
+
         if not stoq.stable and not api.is_developer_mode():
             self._display_unstable_version_message()
 
@@ -493,6 +501,15 @@ class AppWindow(GladeDelegate):
                 'operations that modify your stock.')
         self.inventory_bar = self.add_info_bar(gtk.MESSAGE_WARNING, msg)
 
+    def _display_changelog_message(self):
+        msg = _("Welcome to Stoq version %s!") % stoq.version
+
+        button = gtk.Button(_("See what's new"))
+        button.connect('clicked', self._on_show_chagelog__clicked)
+
+        self._changelog_bar = self.add_info_bar(gtk.MESSAGE_INFO, msg,
+                                                action_widget=button)
+
     def _check_demo_mode(self):
         if not api.sysparam(self.conn).DEMO_MODE:
             return
@@ -559,6 +576,7 @@ class AppWindow(GladeDelegate):
         lines.extend([c.strip() for c in data.split('\n')])
         about.set_authors(lines)
 
+        about.set_transient_for(get_current_toplevel())
         about.run()
         about.destroy()
 
@@ -683,7 +701,7 @@ class AppWindow(GladeDelegate):
         if restart:
             from stoqlib.lib.process import Process
             log.info('Restarting Stoq')
-            Process([sys.argv[0]], shell=True)
+            Process([sys.argv[0], '--no-splash-screen'])
 
         # os._exit() forces a quit without running atexit handlers
         # and does not block on any running threads
@@ -727,7 +745,7 @@ class AppWindow(GladeDelegate):
     def activate(self, params):
         """This is when you switch to an application.
         You should setup widget sensitivity here and refresh lists etc
-        @params: an dictionary with optional parameters.
+        :params params: an dictionary with optional parameters.
         """
 
     def setup_focus(self):
@@ -743,20 +761,20 @@ class AppWindow(GladeDelegate):
     def can_change_application(self):
         """Define if we can change the current application or not.
 
-        @returns: True if we can change the application, False otherwise.
+        :returns: True if we can change the application, False otherwise.
         """
         return True
 
     def can_close_application(self):
         """Define if we can close the current application or not.
 
-        @returns: True if we can close the application, False otherwise.
+        :returns: True if we can close the application, False otherwise.
         """
         return True
 
     def set_open_inventory(self):
         """ Subclasses should overide this if they call
-        check_open_inventory.
+        :obj:`.check_open_inventory`.
 
         This method will be called it there is an open inventory, so the
         application can disable some funcionalities
@@ -794,14 +812,14 @@ class AppWindow(GladeDelegate):
         print_report(report_class, *args, **kwargs)
 
     def set_sensitive(self, widgets, value):
-        """Set the C{widgets} sensitivity based on C{value}
+        """Set the *widgets* sensitivity based on *value*
 
-        @note: if a sensitive group was registered for any widget,
-            it's validation function will be tested and, if C{False}
-            is returned, it will be set insensitive, ignoring C{value}
+        If a sensitive group was registered for any widget,
+        it's validation function will be tested and, if ``False``
+        is returned, it will be set insensitive, ignoring *value*
 
-        @param widgets: a :class:`list` of widgets
-        @param value: either C{True} or C{False}
+        :param widgets: a list of widgets
+        :param value: either `True` or `False`
         """
         # FIXME: Maybe this should ne done on kiwi?
         for widget in widgets:
@@ -817,15 +835,15 @@ class AppWindow(GladeDelegate):
     def register_sensitive_group(self, widgets, validation_func, *args):
         """Register widgets on a sensitive group.
 
-        Everytime self.set_sensitive() is called, if there is any
+        Everytime :obj:`.set_sensitive()` is called, if there is any
         validation function for a given widget on sensitive group,
         then that will be used to decide if it gets sensitive or
         insensitive.
 
-        @param widgets: a :class:`list` of widgets
-        @param validation_func: a function for validation. It should
-            return either C{True} or C{False}.
-        @param args: args that will be passed to C{validation_func}
+        :param widgets: a list of widgets
+        :param validation_func: a function for validation. It should
+            return either ``True`` or ``False``.
+        :param args: args that will be passed to *validation_func*
         """
         assert callable(validation_func)
 
@@ -917,7 +935,8 @@ class AppWindow(GladeDelegate):
 
         self.add_ui_actions(ui_string, actions, 'DebugActions')
 
-    def has_open_inventory(self, from_cache=True):
+    @cached_function()
+    def has_open_inventory(self):
         return Inventory.has_open(self.conn,
                                   api.get_current_branch(self.conn))
 
@@ -944,10 +963,11 @@ class AppWindow(GladeDelegate):
 
     def add_info_bar(self, message_type, label, action_widget=None):
         """Show an information bar to the user.
-        @param message_type: message type, a gtk.MessageType
-        @param label: label to display
-        @param action_widget: optional, most likely a button
-        @returns: the infobar
+
+        :param message_type: message type, a gtk.MessageType
+        :param label: label to display
+        :param action_widget: optional, most likely a button
+        :returns: the infobar
         """
         label = gtk.Label(label)
         label.set_use_markup(True)
@@ -957,7 +977,7 @@ class AppWindow(GladeDelegate):
         label.set_padding(12, 0)
         label.show()
 
-        bar = InfoBar()
+        bar = gtk.InfoBar()
         bar.get_content_area().add(label)
         if action_widget:
             bar.add_action_widget(action_widget, 0)
@@ -966,8 +986,12 @@ class AppWindow(GladeDelegate):
         bar.show()
 
         self.main_vbox.pack_start(bar, False, False, 0)
-        # 0 = menubar, 1 = toolbar, 2 is above iconview
-        self.main_vbox.reorder_child(bar, 2)
+        if self.app.name == 'launcher':
+            # 0 = menubar, 1 = toolbar, 2 is above iconview
+            self.main_vbox.reorder_child(bar, 2)
+        else:
+            # If its any other app, 0 is right bellow the toolbar
+            self.main_vbox.reorder_child(bar, 0)
 
         return bar
 
@@ -1008,15 +1032,14 @@ class AppWindow(GladeDelegate):
         app.activate(params or {})
 
         self.uimanager.ensure_update()
+        self.current_app = app
+        self.current_widget = app_window
         while gtk.events_pending():
             gtk.main_iteration()
         app_window.show()
         app.toplevel = self.get_toplevel()
         app.setup_focus()
 
-        self.current_app = app
-        self.current_widget = app_window
-
     def hide_app(self):
         self.application_box.hide()
         if self.current_app:
@@ -1059,20 +1082,21 @@ class AppWindow(GladeDelegate):
     def shutdown_application(self, restart=False):
         """Shutdown the application:
         There are 3 possible outcomes of calling this function, depending
-        on how many windows and applications are open:
-          - Hide application, save state, show launcher
-          - Close window, save state, show launcher
-          - Close window, save global state, terminate application
+        on how many windows and applications are open::
+
+        * Hide application, save state, show launcher
+        * Close window, save state, show launcher
+        * Close window, save global state, terminate application
 
         This function is called in the following situations:
-          - When closing a window (delete-event)
-          - When clicking File->Close in an application
-          - When clicking File->Quit in the launcher
-          - When clicking enable production mode (restart=True)
-          - Pressing Ctrl-w/F5 in an application
-          - Pressing Ctrl-q in the launcher
-          - Pressing Alt-F4 on Win32
-          - Pressing Cmd-q on Mac
+        * When closing a window (delete-event)
+        * When clicking File->Close in an application
+        * When clicking File->Quit in the launcher
+        * When clicking enable production mode (restart=True)
+        * Pressing Ctrl-w/F5 in an application
+        * Pressing Ctrl-q in the launcher
+        * Pressing Alt-F4 on Win32
+        * Pressing Cmd-q on Mac
 
         :returns: True if shutdown was successful, False if not
         """
@@ -1201,10 +1225,14 @@ class AppWindow(GladeDelegate):
     def _on_Print__activate(self, action):
         if self.current_app:
             self.current_app.print_activate()
+        else:
+            print 'FIXME'
 
     def _on_ExportSpreadSheet__activate(self, action):
         if self.current_app:
             self.current_app.export_spreadsheet_activate()
+        else:
+            print 'FIXME'
 
     def _on_Close__activate(self, action):
         self._hide_current_application()
@@ -1215,12 +1243,13 @@ class AppWindow(GladeDelegate):
         user = api.get_current_user(trans)
         retval = self.run_dialog(PasswordEditor, trans, user)
         api.finish_transaction(trans, retval)
+        trans.close()
 
     def _on_SignOut__activate(self, action):
         from stoqlib.lib.interfaces import ICookieFile
         get_utility(ICookieFile).clear()
-        self.get_toplevel().hide()
-        self.app.shell.relogin()
+        AppWindow.app_windows.remove(self)
+        self.shutdown_application(restart=True)
 
     def _on_Quit__activate(self, action):
         if self._hide_current_application():
@@ -1299,6 +1328,11 @@ class AppWindow(GladeDelegate):
             except KeyError:
                 pass
 
+    def _on_show_chagelog__clicked(self, button):
+        show_section('changelog')
+        self._changelog_bar.hide()
+        api.user_settings.set('actual-version', stoq.stoq_version)
+
     def _on_enable_production__clicked(self, button):
         if not self.can_close_application():
             return
@@ -1318,15 +1352,15 @@ class AppWindow(GladeDelegate):
 class SearchableAppWindow(AppWindow):
     """
     Base class for applications which main interface consists of a list
-
-    @cvar search_table: The we will query on to perform the search
-    @cvar search_label: Label left of the search entry
-    @cvar report_table: the report class for printing the object list
-        embedded on app.
     """
 
+    #: The we will query on to perform the search
     search_table = None
+
+    #: Label left of the search entry
     search_label = _('Search:')
+
+    #: the report class for printing the object list embedded on app.
     report_table = None
 
     def __init__(self, app):
@@ -1335,7 +1369,13 @@ class SearchableAppWindow(AppWindow):
 
         self._loading_filters = False
 
-        self.executer = ORMObjectQueryExecuter(api.get_connection())
+        conn = api.get_connection()
+        self.executer = ORMObjectQueryExecuter()
+        # FIXME: Remove this limit, but we need to migrate all existing
+        #        searches to use lazy lists first. That in turn require
+        #        us to rewrite the queries in such a way that count(*)
+        #        will work properly.
+        self.executer.set_limit(sysparam(conn).MAX_SEARCH_RESULTS)
         self.executer.set_table(self.search_table)
 
         self.search = StoqlibSearchSlaveDelegate(self.get_columns(),
@@ -1367,7 +1407,11 @@ class SearchableAppWindow(AppWindow):
         settings = self._app_settings.setdefault(self.app.name, {})
         filter_states = settings.get('filter-states')
         if filter_states is not None:
+            # Disable auto search to avoid an extra query when restoring the
+            # state
+            self.search.search.set_auto_search(False)
             self.search.search.set_filter_states(filter_states)
+            self.search.search.set_auto_search(True)
         self._loading_filters = False
 
     #
@@ -1394,7 +1438,7 @@ class SearchableAppWindow(AppWindow):
 
     def set_searchtable(self, search_table):
         """
-        @param search_table:
+        :param search_table:
         """
         self.executer.set_table(search_table)
         self.search_table = search_table
@@ -1414,7 +1458,7 @@ class SearchableAppWindow(AppWindow):
 
     def set_text_field_label(self, label):
         """
-        @param label:
+        :param label:
         """
         search_filter = self.search.get_primary_filter()
         search_filter.set_label(label)
@@ -1437,10 +1481,10 @@ class SearchableAppWindow(AppWindow):
     def export_spread_sheet(self):
         """Runs a dialog to export the current search results to a CSV file.
         """
-        self.run_dialog(SpreadSheetExporterDialog,
-                        object_list=self.results,
-                        name=self.app_name,
-                        filename_prefix=self.app.name)
+        sse = SpreadSheetExporter()
+        sse.export(object_list=self.results,
+                   name=self.app_name,
+                   filename_prefix=self.app.name)
 
     def select_result(self, result):
         """Select the object in the result list
