@@ -50,7 +50,7 @@ from stoqlib.gui.accounttree import AccountTree
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.editors.accounteditor import AccountEditor
 from stoqlib.gui.editors.accounttransactioneditor import AccountTransactionEditor
-from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporterDialog
+from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporter
 from stoqlib.gui.dialogs.importerdialog import ImporterDialog
 from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.printing import print_report
@@ -81,8 +81,10 @@ class TransactionSearchContainer(SearchContainer):
         self.model = page.model
         SearchContainer.__init__(self, columns)
 
-    def add_results(self, results):
-        self.page.search.results.clear()
+    def add_results(self, results, clear=True):
+        if clear:
+            self.page.search.results.clear()
+
         if self.page.query.table == AccountTransactionView:
             self.page.append_transactions(results)
         else:
@@ -298,6 +300,7 @@ class TransactionPage(object):
             self.search.results.update(item)
             self.app.accounts.refresh_accounts(self.app.conn)
         api.finish_transaction(trans, transaction)
+        trans.close()
 
     def on_dialog__opened(self, dialog):
         dialog.connect('account-added', self.on_dialog__account_added)
@@ -323,6 +326,7 @@ class TransactionPage(object):
             self.search.results.update(item)
             self.app.accounts.refresh_accounts(self.app.conn)
         api.finish_transaction(trans, transaction)
+        trans.close()
 
     def _on_row__activated(self, objectlist, item):
         if self.model.kind == 'account':
@@ -486,6 +490,7 @@ class FinancialApp(AppWindow):
                                  parent_account=parent_account)
         if api.finish_transaction(trans, retval):
             self.accounts.refresh_accounts(self.conn)
+        trans.close()
 
         return retval
 
@@ -623,9 +628,10 @@ class FinancialApp(AppWindow):
         assert not self._is_accounts_tab()
 
         page = self._get_current_page_widget()
-        self.run_dialog(SpreadSheetExporterDialog, object_list=page.results,
-                        name=self.app_name,
-                        filename_prefix=self.app.name)
+        sse = SpreadSheetExporter()
+        sse.export(object_list=page.results,
+                   name=self.app_name,
+                   filename_prefix=self.app.name)
 
     def _can_add_account(self):
         if self._is_accounts_tab():
@@ -790,8 +796,13 @@ class FinancialApp(AppWindow):
         self.acc_popup.popup(None, None, None, event.button, event.time)
 
     def on_Edit__activate(self, button):
-        account_view = self.accounts.get_selected()
-        self._edit_existing_account(account_view)
+        if self._is_accounts_tab():
+            account_view = self.accounts.get_selected()
+            self._edit_existing_account(account_view)
+        elif self._is_transaction_tab():
+            page = self._get_current_page_widget()
+            transaction = page.results.get_selected()
+            page._edit_transaction_dialog(transaction)
 
     def after_notebook__switch_page(self, notebook, page, page_id):
         self._update_actions()
