@@ -29,7 +29,7 @@ from decimal import Decimal
 
 import pango
 import gtk
-from kiwi.datatypes import currency
+from kiwi.currency import currency
 from kiwi.enums import SearchFilterPosition
 from kiwi.python import all
 from kiwi.ui.objectlist import Column, SearchColumn
@@ -39,6 +39,7 @@ from stoqlib.domain.purchase import PurchaseOrder, PurchaseOrderView
 from stoqlib.gui.dialogs.purchasedetails import PurchaseDetailsDialog
 from stoqlib.gui.dialogs.sellablepricedialog import SellablePriceDialog
 from stoqlib.gui.dialogs.stockcostdialog import StockCostDialog
+from stoqlib.gui.dialogs.manufacturerdialog import ProductManufacturerDialog
 from stoqlib.gui.editors.producteditor import ProductEditor
 from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.categorysearch import SellableCategorySearch
@@ -111,6 +112,8 @@ class PurchaseApp(SearchableAppWindow):
              group.get("search_products")),
             ("ProductUnits", None, _("Product units..."),
              group.get("search_product_units")),
+            ("ProductManufacturers", None, _("Manufacturers..."),
+             group.get("search_product_manufacturers")),
             ("Services", None, _("Services..."),
              group.get("search_services")),
             ("SearchStockItems", None, _("Stock items..."),
@@ -181,7 +184,8 @@ class PurchaseApp(SearchableAppWindow):
             self.SearchQuotes,
             self.Services])
         self.search.set_summary_label(column='total',
-                                      label=_('<b>Orders total:</b>'),
+                                      label=('<b>%s</b>' %
+                                             api.escape(_('Orders total:'))),
                                       format='<b>%s</b>',
                                       parent=self.get_statusbar_message_area())
         self.results.set_selection_mode(gtk.SELECTION_MULTIPLE)
@@ -225,7 +229,8 @@ class PurchaseApp(SearchableAppWindow):
             self.search.set_message("%s\n\n%s" % (
                 _("No orders could be found."),
                 _("Would you like to %s ?") % (
-                    '<a href="new_order">%s</a>' % _("create a new order"))
+                    '<a href="new_order">%s</a>' % (
+                api.escape(_("create a new order"), )))
                 ))
 
         # FIXME: Push number of results to Statusbar
@@ -424,11 +429,11 @@ class PurchaseApp(SearchableAppWindow):
 
     def _new_product(self):
         with api.trans() as trans:
-            self.run_dialog(ProductEditor, trans)
+            self.run_dialog(ProductEditor, trans, model=None)
 
     def _new_consignment(self):
         with api.trans() as trans:
-            self.run_dialog(ConsignmentWizard, trans)
+            self.run_dialog(ConsignmentWizard, trans, model=None)
 
         if trans.committed:
             self.refresh()
@@ -512,6 +517,9 @@ class PurchaseApp(SearchableAppWindow):
     def on_ProductUnits__activate(self, action):
         self.run_dialog(SellableUnitSearch, self.conn)
 
+    def on_ProductManufacturers__activate(self, action):
+        self.run_dialog(ProductManufacturerDialog, self.conn)
+
     def on_Services__activate(self, action):
         self.run_dialog(ServiceSearch, self.conn, hide_price_column=True)
 
