@@ -51,7 +51,6 @@ class Shell(object):
     def __init__(self, options, initial=True):
         global _shell
         _shell = self
-        self._application_cache = {}
         self._appname = None
         self._blocked_apps = []
         self._current_app = None
@@ -90,6 +89,7 @@ class Shell(object):
         self._setup_domain_slave_mapper()
         self._load_key_bindings()
         self._setup_debug_options()
+        self._check_locale()
 
     #
     # Private
@@ -102,6 +102,7 @@ class Shell(object):
     def _set_user_locale(self):
         from stoqlib.lib.settings import get_settings
 
+        self._locale_error = None
         settings = get_settings()
         lang = settings.get('user-locale', None)
         if not lang:
@@ -111,8 +112,10 @@ class Shell(object):
         try:
             locale.setlocale(locale.LC_ALL, lang)
         except locale.Error as err:
-            log.warning("Could not set locale to %s. Error message: %s" %
-                        (lang, err))
+            msg = _("Could not set locale to %s. Make sure that you have "
+                    "the packages for this locale installed.") % lang[:-6]
+            self._locale_error = (msg, err)
+            log.warning(msg)
         else:
             os.environ['LANG'] = lang
             os.environ['LANGUAGE'] = lang
@@ -127,14 +130,19 @@ class Shell(object):
         from stoqlib.lib.kiwilibrary import library
         from stoqlib.lib.interfaces import IAppInfo
         import stoq
+        # FIXME: use only stoq.stoq_version here and all other callsites of
+        # IAppInfo
         stoq_version = stoq.version
+        stoq_ver = stoq.stoq_version
         if hasattr(library, 'get_revision'):
             rev = library.get_revision()
             if rev is not None:
                 stoq_version += ' r' + rev
+                stoq_ver += ('r' + rev,)
         info = AppInfo()
         info.set("name", "Stoq")
         info.set("version", stoq_version)
+        info.set("ver", stoq_ver)
         info.set("log", self._log_filename)
         provide_utility(IAppInfo, info)
 
@@ -143,6 +151,8 @@ class Shell(object):
         check_dependencies()
 
     def _show_splash(self):
+        if not self._options.splashscreen:
+            return
         from stoqlib.gui.splash import show_splash
         show_splash()
 
@@ -232,7 +242,8 @@ class Shell(object):
         # 2) Depend on a stoqlib version with extra_version < 90
         #
         if stoq.stable:
-            if stoq.extra_version >= FIRST_UNSTABLE_EXTRA_VERSION:
+            if (stoq.extra_version >= FIRST_UNSTABLE_EXTRA_VERSION and
+                not 'rc' in stoq.extra_version):
                 raise SystemExit(
                     "Stable stoq release should set extra_version to %d or lower" % (
                     FIRST_UNSTABLE_EXTRA_VERSION, ))
@@ -334,20 +345,26 @@ class Shell(object):
         # 2 seconds) or creating the database
         try:
             setup(config, self._options, register_station=False,
-                  check_schema=True, load_plugins=False)
-        except DatabaseInconsistency as e:
-            error(_('The database version differs from your installed '
-                    'version.'), str(e))
-            raise SystemExit("Error: database inconsistency")
+                  check_schema=False, load_plugins=False)
         except (StoqlibError, PostgreSQLError) as e:
             error(_('Could not connect to the database'),
                   'error=%s uri=%s' % (str(e), conn_uri))
-            raise SystemExit("Error: bad connection settings provided")
+
+        from stoqlib.database.orm import orm_startup
+        orm_startup()
 
         from stoqlib.database.migration import needs_schema_update
         if needs_schema_update():
             self._run_update_wizard()
 
+        from stoqlib.database.migration import StoqlibSchemaMigration
+        migration = StoqlibSchemaMigration()
+        try:
+            migration.check()
+        except DatabaseInconsistency as e:
+            error(_('The database version differs from your installed '
+                    'version.'), str(e))
+
         from stoqlib.database.runtime import (get_connection,
                                               set_current_branch_station)
         conn = get_connection()
@@ -357,6 +374,13 @@ class Shell(object):
         manager = get_plugin_manager()
         manager.activate_installed_plugins()
 
+    def _check_locale(self):
+        if not self._locale_error:
+            return
+
+        from stoqlib.lib.message import warning
+        warning(self._locale_error[0], str(self._locale_error[1]))
+
     def _load_key_bindings(self):
         from stoqlib.gui.keybindings import load_user_keybindings
         load_user_keybindings()
@@ -378,17 +402,13 @@ class Shell(object):
     def _run_first_time_wizard(self, config=None):
         from stoqlib.gui.base.dialogs import run_dialog
         from stoq.gui.config import FirstTimeConfigWizard
-        from stoqlib.gui.splash import hide_splash
         self._ran_wizard = True
-        hide_splash()
         # This may run Stoq
         run_dialog(FirstTimeConfigWizard, None, self._options, config)
 
     def _run_update_wizard(self):
         from stoqlib.gui.base.dialogs import run_dialog
         from stoq.gui.update import SchemaUpdateWizard
-        from stoqlib.gui.splash import hide_splash
-        hide_splash()
         retval = run_dialog(SchemaUpdateWizard, None)
         if not retval:
             raise SystemExit()
@@ -402,7 +422,7 @@ class Shell(object):
             if not self.login():
                 return False
         except LoginError, e:
-            error(e)
+            error(str(e))
             return False
         self._check_param_main_branch()
         self._check_param_online_services()
@@ -484,9 +504,6 @@ class Shell(object):
             raise SystemExit("%s app misses a %r attribute" % (
                 appdesc.name, window))
 
-        from stoqlib.gui.splash import hide_splash
-        hide_splash()
-
         embedded = getattr(window_class, 'embedded', False)
         from stoq.gui.application import App
         app = App(window_class, self._login, self._options, self, embedded,
@@ -525,12 +542,6 @@ class Shell(object):
 
         return available_applications
 
-    def _get_current_username(self):
-        from stoqlib.api import api
-        conn = api.get_connection()
-        user = api.get_current_user(conn)
-        return user.username
-
     #
     # Global functions
     #
@@ -602,7 +613,7 @@ class Shell(object):
     # Public API
     #
 
-    def login(self, try_cookie=True):
+    def login(self):
         """
         Do a login
         @param try_cookie: Try to use a cookie if one is available
@@ -610,48 +621,18 @@ class Shell(object):
         """
         from stoqlib.exceptions import LoginError
         from stoqlib.lib.message import info
-        user = None
-        if try_cookie:
-            user = self._login.cookie_login()
+        user = self._login.cookie_login()
 
         if not user:
             try:
                 user = self._login.validate_user()
             except LoginError, e:
-                info(e)
+                info(str(e))
 
         if user:
             self._user = user
         return bool(user)
 
-    def relogin(self):
-        """
-        Do a relogin, eg switch users
-        """
-        if self._current_app:
-            self._current_app.hide()
-
-        old_user = self._get_current_username()
-
-        if not self.login(try_cookie=False):
-            return
-
-        # If the username is the same
-        if (old_user == self._get_current_username() and
-            self._current_app):
-            self._current_app.show()
-            return
-
-        # clear the cache, since we switched users
-        self._application_cache.clear()
-
-        from stoq.gui.launcher import Launcher
-        from stoqlib.gui.events import StartApplicationEvent
-        launcher = Launcher(self._options, self)
-        launcher.show()
-        app = launcher.app
-        StartApplicationEvent.emit(app.name, app)
-
     def get_app_by_name(self, appname):
         """
         @param appname: a string
