@@ -226,6 +226,10 @@ class StockApp(SearchableAppWindow):
                 SearchColumn('description', title=_("Description"),
                              data_type=str, expand=True,
                              ellipsize=pango.ELLIPSIZE_END),
+                SearchColumn('manufacturer', title=_("Manufacturer"),
+                             data_type=str, visible=False),
+                SearchColumn('model', title=_("Model"),
+                             data_type=str, visible=False),
                 SearchColumn('location', title=_("Location"), data_type=str,
                              width=100, visible=False),
                 SearchColumn('stock', title=_('Quantity'),
@@ -326,6 +330,7 @@ class StockApp(SearchableAppWindow):
     #
 
     def on_image_viewer_closed(self, window, event):
+        self.StockPictureViewer.props.active = False
         self.image_viewer = None
 
     def on_results__has_rows(self, results, product):
