@@ -29,7 +29,8 @@ from datetime import date
 
 import pango
 import gtk
-from kiwi.datatypes import currency, converter
+from kiwi.currency import currency
+from kiwi.datatypes import converter
 from kiwi.log import Logger
 from kiwi.enums import SearchFilterPosition
 from kiwi.python import Settable
@@ -297,9 +298,9 @@ class TillApp(SearchableAppWindow):
             else:
                 coupon.cancel()
         except SellError as err:
-            warning(err)
+            warning(str(err))
         except ModelDataError as err:
-            warning(err)
+            warning(str(err))
 
         trans.close()
 
@@ -387,7 +388,7 @@ class TillApp(SearchableAppWindow):
                 run_dialog(CashInEditor, self, trans)
             except TillError as err:
                 # Inform the error to the user instead of crashing
-                warning(err)
+                warning(str(err))
                 return
 
         if trans.committed:
@@ -513,8 +514,7 @@ class TillApp(SearchableAppWindow):
         self._run_search_dialog(SoldItemsByBranchSearch)
 
     def on_SearchTillHistory__activate(self, button):
-        dialog = TillHistoryDialog(self.conn)
-        self.run_dialog(dialog, self.conn)
+        self.run_dialog(TillHistoryDialog, self.conn)
 
     def on_SearchFiscalTillOperations__activate(self, button):
         self._run_search_dialog(TillFiscalOperationsSearch)
