@@ -27,24 +27,17 @@
 
 import gettext
 import os
-import socket
 import sys
 
 from kiwi.component import provide_utility
 from kiwi.log import Logger
-from stoqlib.database.admin import ensure_admin_user, initialize_system
 from stoqlib.database.database import check_version
 from stoqlib.database.migration import StoqlibSchemaMigration
 from stoqlib.database.orm import orm_enable_debugging, orm_startup
 from stoqlib.database.runtime import (get_connection,
-                                      set_current_branch_station,
-                                      new_transaction)
-from stoqlib.domain.profile import UserProfile
-from stoqlib.domain.profile import ProfileSettings
-from stoqlib.exceptions import (DatabaseError, StoqlibError,
-                                DatabaseInconsistency)
+                                      set_current_branch_station)
+from stoqlib.exceptions import DatabaseError
 from stoqlib.lib.configparser import register_config, StoqConfig
-from stoqlib.lib.crashreport import collect_traceback
 from stoqlib.lib.interfaces import  IApplicationDescriptions
 from stoqlib.lib.message import error
 from stoqlib.lib.osutils import read_registry_key
@@ -55,16 +48,6 @@ _ = gettext.gettext
 log = Logger('startup')
 
 
-def _check_tables():
-    # Check so SystemTable is present
-    conn = get_connection()
-    if not conn.tableExists('system_table'):
-        error(
-            _("Database schema error"),
-            _("Table 'system_table' does not exist.\n"
-              "Consult your database administrator to solve this problem."))
-
-
 def setup_path():
     import platform
     if platform.system() != 'Windows':
@@ -128,8 +111,12 @@ def setup(config=None, options=None, register_station=True, check_schema=True,
 
     register_config(config)
 
+    if options and options.sqldebug:
+        orm_enable_debugging()
+
     from stoq.lib.applist import ApplicationDescriptions
-    provide_utility(IApplicationDescriptions, ApplicationDescriptions())
+    provide_utility(IApplicationDescriptions, ApplicationDescriptions(),
+                    replace=True)
 
     if register_station:
         try:
@@ -138,14 +125,17 @@ def setup(config=None, options=None, register_station=True, check_schema=True,
             error(e.short, str(e.msg))
 
         check_version(conn)
+
+        if check_schema:
+            migration = StoqlibSchemaMigration()
+            migration.check()
+
         orm_startup()
-        # For LTSP systems we cannot use the hostname as stoq is run
-        # on a shared serve system. Instead the ip of the client system
-        # is available in the LTSP_CLIENT environment variable
-        station_name = os.environ.get('LTSP_CLIENT_HOSTNAME', None)
-        if station_name is None:
-            station_name = socket.gethostname()
-        set_current_branch_station(conn, station_name)
+
+        if options and options.sqldebug:
+            orm_enable_debugging()
+
+        set_current_branch_station(conn, station_name=None)
 
     if load_plugins:
         from stoqlib.lib.pluginmanager import get_plugin_manager
@@ -153,75 +143,15 @@ def setup(config=None, options=None, register_station=True, check_schema=True,
         manager.activate_installed_plugins()
 
     if check_schema:
-        _check_tables()
+        conn = get_connection()
+        if not conn.tableExists('system_table'):
+            error(
+                _("Database schema error"),
+                _("Table 'system_table' does not exist.\n"
+                  "Consult your database administrator to solve this problem."))
 
-        migration = StoqlibSchemaMigration()
-        if (not migration.check_uptodate() or
-            (load_plugins and not migration.check_plugins())):
-            error(_("Database schema error"),
-                  _("The database schema has changed, but the database has "
-                    "not been updated. Run 'stoqdbadmin updateschema` to "
-                    "update the schema  to the latest available version."))
+        if check_schema:
+            migration = StoqlibSchemaMigration()
+            migration.check()
 
         orm_startup()
-
-    if options:
-        if options.debug:
-            from gtk import keysyms
-            from stoqlib.gui.keyboardhandler import install_global_keyhandler
-            from stoqlib.gui.introspection import introspect_slaves
-            install_global_keyhandler(keysyms.F12, introspect_slaves)
-
-        if options.sqldebug:
-            orm_enable_debugging()
-
-    from stoqlib.gui.keybindings import load_user_keybindings
-    load_user_keybindings()
-
-
-def needs_schema_update():
-    try:
-        migration = StoqlibSchemaMigration()
-    except StoqlibError:
-        error(_("Update Error"),
-             _("You need to call setup() before checking the database "
-               "schema."))
-
-    try:
-        update = not (migration.check_uptodate() and migration.check_plugins())
-    except DatabaseInconsistency, e:
-        error(str(e))
-    return update
-
-
-def clean_database(config, options=None):
-    """Clean the database
-    @param config: a StoqConfig instance
-    @param options: a Optionparser instance
-    """
-    if not options:
-        password = ''
-    else:
-        password = options.password
-
-    try:
-        password = password or config.get_password()
-        initialize_system()
-        set_default_profile_settings()
-        ensure_admin_user(password)
-    except Exception:
-        collect_traceback(sys.exc_info(), submit=True)
-
-
-def set_default_profile_settings():
-    trans = new_transaction()
-    profile = UserProfile.selectOneBy(name=_('Salesperson'), connection=trans)
-    # Not sure what is happening. If it doesnt exist, check if it was not
-    # created in english. workaround for crash report 207 (bug 4587)
-    if not profile:
-        profile = UserProfile.selectOneBy(name='Salesperson', connection=trans)
-    assert profile
-    ProfileSettings.set_permission(trans, profile, 'pos', True)
-    ProfileSettings.set_permission(trans, profile, 'sales', True)
-    ProfileSettings.set_permission(trans, profile, 'till', True)
-    trans.commit(close=True)
