@@ -33,7 +33,7 @@ import os
 import sys
 
 from kiwi.component import get_utility, provide_utility
-from kiwi.datatypes import currency
+from kiwi.currency import currency
 from kiwi.environ import environ
 from kiwi.log import Logger
 
@@ -131,6 +131,20 @@ def create_main_branch(trans, name):
     return branch
 
 
+def populate_initial_data(trans):
+    from stoqlib.domain.system import SystemTable
+    generation = SystemTable.select(connection=trans).max('generation')
+    if generation < 4:
+        # FIXME: Initial data can (and needs to) only be sourced on schemas
+        #        greater or equal than 4. Remove this in the future.
+        return
+
+    log.info('Populating initial data')
+    initial_data = environ.find_resource('sql', 'initial.sql')
+    if execute_sql(initial_data) != 0:
+        error('Failed to populate initial data')
+
+
 def register_payment_methods(trans):
     """Registers the payment methods and creates persistent
     domain classes associated with them.
@@ -150,11 +164,8 @@ def register_payment_methods(trans):
         if pm is None:
             pm = PaymentMethod(connection=trans,
                                method_name=operation_name,
-                               description=None,
                                destination_account=account,
-                               max_installments=1)
-        pm.description = operation.description
-        pm.max_installments = operation.max_installments
+                               max_installments=operation.max_installments)
 
 
 def register_accounts(trans):
@@ -254,10 +265,10 @@ def ensure_sellable_constants():
 
 def user_has_usesuper(trans):
     """This method checks if the currently logged in postgres user has
-    `usesuper' access which is necessary for certain operations
+    ``usesuper`` access which is necessary for certain operations
 
     :param trans: a database connection
-    :returns: if the user has `usesuper' access
+    :returns: if the user has ``usesuper`` access
     """
 
     results = trans.queryOne(
@@ -367,6 +378,7 @@ def initialize_system(password=None, testsuite=False,
         create_base_schema()
         create_log("INIT START")
         trans = new_transaction()
+        populate_initial_data(trans)
         register_accounts(trans)
         register_payment_methods(trans)
         from stoqlib.domain.uiform import create_default_forms
