@@ -33,11 +33,12 @@ from stoqlib.lib.kiwilibrary import library
 library   # pyflakes
 
 from formencode.validators import Validator
-from kiwi.datatypes import currency
+from kiwi.currency import currency
 from kiwi.db.query import NumberQueryState, StringQueryState, \
      DateQueryState, DateIntervalQueryState, QueryExecuter, \
      NumberIntervalQueryState
 from kiwi.interfaces import ISearchFilter
+from kiwi.python import Settable
 from sqlobject.main import SQLObjectNotFound, SQLObjectIntegrityError
 from sqlobject.col import DateTimeCol as _DateTimeCol
 from sqlobject.col import (BoolCol, BLOBCol,
@@ -45,20 +46,22 @@ from sqlobject.col import (BoolCol, BLOBCol,
 from sqlobject.col import (Col, SOCol, SOBoolCol, SODateTimeCol, SODecimalCol,
                            SOForeignKey, SOIntCol, SOStringCol, SOUnicodeCol)
 from sqlobject.converters import registerConverter
+from sqlobject.dberrors import IntegrityError
 from sqlobject.dbconnection import connectionForURI, Transaction
 from sqlobject.joins import MultipleJoin as _MultipleJoin, SingleJoin
 from sqlobject.joins import SOSingleJoin, SOMultipleJoin
 from sqlobject.main import sqlhub, SQLObject
 from sqlobject.sqlbuilder import (AND, NOT, DESC, Alias, NOTIN, IN, INNERJOINOn,
                                   ISNOTNULL, LEFTJOINOn, LIKE, OR, Update, Field,
-                                  NoDefault, SQLExpression, const, sqlIdentifier, func)
+                                  NoDefault, SQLExpression, const, sqlIdentifier, func,
+                                  Select)
 from sqlobject.sresults import SelectResults
 from sqlobject.util.csvexport import export_csv
 from sqlobject.viewable import Viewable
 
-from stoqlib.database.exceptions import ORMTestError
 from stoqlib.lib.defaults import DECIMAL_PRECISION, QUANTITY_PRECISION
 
+
 # Currency
 
 
@@ -122,7 +125,9 @@ class PriceCol(DecimalCol):
 # MainObject
 
 class ORMObject(SQLObject):
-    pass
+
+    def get_connection(self):
+        return self._connection
 
 
 def orm_enable_debugging():
@@ -191,10 +196,40 @@ def orm_get_unittest_value(klass, test, tables_dict, name, column):
 
     return value
 
+
+class ORMTypeInfo(object):
+    def __init__(self, orm_type):
+        self.orm_type = orm_type
+
+    def get_columns(self):
+        return self.orm_type.sqlmeta.columns.values()
+
+    def get_column_names(self):
+        for c in self.get_columns():
+            yield c.name
+
+    def get_foreign_columns(self):
+        for column in self.get_columns():
+            if isinstance(column, SOForeignKey):
+                # Class of the column, name of the column in the obj
+                yield column.foreignName, column.foreignKey
+
+    def get_single_joins(self):
+        for column in self.orm_type.sqlmeta.joins:
+            if isinstance(column, (SOSingleJoin, SOMultipleJoin)):
+                yield column.joinMethodName, column.otherClassName,
+
+
 orm_name = 'sqlobject'
 
 # Exceptions
 
+
+class ORMTestError(Exception):
+    pass
+
+IntegrityError = IntegrityError
+
 # ORMObject.get raises this
 ORMObjectNotFound = SQLObjectNotFound
 # ORMObject.selectOneBy raises this
@@ -218,6 +253,7 @@ class ORMObjectQueryExecuter(QueryExecuter):
         self._filter_query_callbacks = {}
         self._query = self._default_query
         self._full_text_indexes = {}
+        self.post_result = None
 
     #
     # Public API
@@ -257,8 +293,9 @@ class ORMObjectQueryExecuter(QueryExecuter):
     def set_query(self, callback):
         """
         Overrides the default query mechanism.
+
         :param callback: a callable which till take two arguments:
-          (query, connection)
+          query and connection
         """
         if callback is None:
             callback = self._default_query
@@ -318,8 +355,15 @@ class ORMObjectQueryExecuter(QueryExecuter):
         if self._having:
             having = AND(self._having)
 
+        self.post_result = None
         result = self._query(query, having, self.conn)
-        return result.limit(self.get_limit())
+        if hasattr(self.table, 'post_search_callback'):
+            self.post_result = self._fetch_post_result(result)
+
+        limit = self.get_limit()
+        if limit != -1:
+            return result.limit(limit)
+        return result
 
     #
     # Private
@@ -455,6 +499,16 @@ class ORMObjectQueryExecuter(QueryExecuter):
         if queries:
             return AND(*queries)
 
+    def _fetch_post_result(self, result):
+        conn = result._getConnection()
+        descs, query = self.table.post_search_callback(conn, result)
+        values = conn.queryOne(query)
+        assert len(descs) == len(values), (descs, values)
+        data = {}
+        for desc, value in zip(descs, list(values)):
+            data[desc] = value
+        return Settable(**data)
+
 
 # Columns
 BLOBCol = BLOBCol
@@ -491,6 +545,10 @@ class MySOMultipleJoin(SOMultipleJoin):
 class MultipleJoin(_MultipleJoin):
     baseClass = MySOMultipleJoin
 
+    def __init__(self, otherClass, joinColumn=None, orderBy=None):
+        _MultipleJoin.__init__(self, otherClass, joinColumn=joinColumn,
+                               orderBy=orderBy)
+
 
 # Column classes
 Col = Col
@@ -532,6 +590,7 @@ Transaction = Transaction
 # Misc
 export_csv = export_csv
 SelectResults = SelectResults
+Select = Select
 NoDefault = NoDefault
 Update = Update
 Viewable = Viewable
