@@ -34,7 +34,7 @@ from stoqlib.database.interfaces import (
     IDatabaseSettings, IConnection, ITransaction, ICurrentBranch,
     ICurrentBranchStation, ICurrentUser)
 from stoqlib.database.orm import ORMObject, Transaction
-from stoqlib.database.orm import sqlIdentifier, const
+from stoqlib.database.orm import sqlIdentifier, const, orm_name
 from stoqlib.exceptions import LoginError, StoqlibError
 from stoqlib.lib.message import error, yesno
 from stoqlib.lib.translation import stoqlib_gettext
@@ -96,7 +96,10 @@ class StoqlibTransaction(Transaction):
             self._reset_pending_objs()
 
     def close(self):
-        self._connection.close()
+        if orm_name == 'sqlobject':
+            self._connection.close()
+        else:
+            self.store.close()
         self._obsolete = True
 
     def get(self, obj):
@@ -188,9 +191,13 @@ class StoqlibTransaction(Transaction):
                 # transactions
                 for trans in self._related_transactions:
                     klass = type(modified_obj)
-                    cache = trans.cache.tryGet(modified_obj.id, klass)
-                    if cache:
-                        cache.expire()
+                    # FIXME: This is sqlobject specific
+                    if orm_name == 'sqlobject':
+                        cache = trans.cache.tryGet(modified_obj.id, klass)
+                        if cache:
+                            cache.expire()
+                    else:
+                        trans.remove_from_cache(modified_obj)
 
     def _need_process_pending(self):
         return (any(self._created_object_sets) or
@@ -279,7 +286,7 @@ def _register_branch(conn, station_name):
     trans = new_transaction()
     if not sysparam(trans).DEMO_MODE:
         settings = get_utility(IDatabaseSettings)
-        if yesno(_("The computer <u>%s</u> is not registered to the Stoq "
+        if yesno(_("The computer '%s' is not registered to the Stoq "
                    "server at %s.\n\n"
                    "Do you want to register it "
                    "(requires administrator access) ?") %
@@ -294,7 +301,7 @@ def _register_branch(conn, station_name):
             user = h.validate_user()
         except LoginError, e:
             trans.close()
-            error(e)
+            error(str(e))
 
         if not user:
             trans.close()
