@@ -33,9 +33,10 @@ import socket
 from kiwi.log import Logger
 from zope.interface import implements
 
+from stoqlib.database.database import test_local_database
 from stoqlib.database.exceptions import OperationalError
 from stoqlib.database.interfaces import IDatabaseSettings
-from stoqlib.database.orm import connectionForURI
+from stoqlib.database.orm import connectionForURI, orm_name
 from stoqlib.exceptions import ConfigError, DatabaseError
 from stoqlib.lib.osutils import get_username
 from stoqlib.lib.translation import stoqlib_gettext
@@ -98,15 +99,13 @@ class DatabaseSettings(object):
             password = ""
         authority = '%s%s@%s:%s' % (
             self.username, password, self.address, self.port)
-        if dbname is None:
-            # postgres is a special database which is always present,
-            # it was added in 8.1 which is thus our requirement'
-            dbname = 'postgres'
 
         return '%s://%s/%s' % (self.rdbms, authority, dbname)
 
-    def _get_connection_internal(self, dbname):
-        conn_uri = self._build_uri(dbname)
+    def _get_connection_internal(self, dbname=None):
+        # postgres is a special database which is always present,
+        # it was added in 8.1 which is thus our requirement'
+        dbname = dbname or 'postgres'
 
         # Do not output the password in the logs
         if not self.first:
@@ -115,7 +114,37 @@ class DatabaseSettings(object):
             self.first = False
 
         try:
-            conn = connectionForURI(conn_uri)
+            host = None
+            port = None
+            if self.address == "":
+                pair = test_local_database()
+                if pair is None:
+                    raise DatabaseError(
+                        _("Could not find a database server on this computer"))
+                host, port = pair
+
+            if orm_name == 'storm':
+                if host is not None:
+                    self.address = host
+                if port is not None:
+                    self.port = port
+                from storm.uri import URI
+                conn_uri = URI(':')
+                conn_uri.database = dbname
+                conn_uri.scheme = self.rdbms
+                conn_uri.host = self.address
+                conn_uri.port = int(self.port)
+                conn_uri.username = self.username
+                conn_uri.password = self.password
+                conn_uri.options['isolation'] = 'read-committed'
+                conn = connectionForURI(conn_uri)
+            else:
+                conn_uri = self._build_uri(dbname)
+                conn = connectionForURI(conn_uri)
+                if host is not None:
+                    conn.dsn_dict['host'] = host
+                if port is not None:
+                    conn.dsn_dict['port'] = port
             conn.makeConnection()
         except OperationalError, e:
             log.info('OperationalError: %s' % e)
@@ -153,6 +182,14 @@ class DatabaseSettings(object):
         """
         return self._get_connection_internal(None)
 
+    def copy(self):
+        return DatabaseSettings(address=self.address,
+                                dbname=self.dbname,
+                                rdbms=self.rdbms,
+                                port=self.port,
+                                username=self.username,
+                                password=self.password)
+
     # FIXME: Remove/Rethink
     def check_database_address(self):
         if not self.address:
