@@ -37,9 +37,11 @@ import re
 import datetime
 import decimal
 import warnings
+from weakref import WeakValueDictionary
 
 from kiwi.db.stormintegration import StormQueryExecuter
-from kiwi.datatypes import currency
+from kiwi.currency import currency
+from psycopg2 import IntegrityError
 
 from storm import expr, Undef
 from storm.base import Storm
@@ -47,7 +49,7 @@ from storm.database import create_database
 from storm.exceptions import StormError, NotOneError
 from storm.expr import (
     SQL, SQLRaw, Desc, And, Or, Not, In, Like, AutoTables, LeftJoin,
-    Alias, Update, Join, NamedFunc)
+    Alias, Update, Join, NamedFunc, Select)
 from storm.info import get_cls_info, get_obj_info, ClassAlias
 from storm.properties import (
     RawStr, Int, Bool, Float, DateTime, Date, TimeDelta, Unicode,
@@ -61,8 +63,6 @@ from storm.variables import (Variable, BoolVariable, DateVariable,
                              DateTimeVariable, RawStrVariable, DecimalVariable,
                              IntVariable)
 
-from stoqlib.database.exceptions import ORMTestError
-
 _IGNORED = object()
 
 
@@ -140,6 +140,7 @@ class SQLObjectStyle(object):
 class _SQLMeta(object):
     def __init__(self, cls):
         self.soClass = cls
+        self.table = cls.__storm_table__
 
     @property
     def columnList(self):
@@ -334,13 +335,23 @@ class BoundDotQAlias(object):
             #self._alias.name + '.id'
             return
         else:
-            return getattr(self._alias, attr)
+            return getattr(self._alias.expr, attr)
 
 
-class Alias(Alias):
+class MyAlias(Alias):
     q = DotQAlias()
 
 
+def GetAlias(klass, name):
+    # If it is a viewable we should use our own Alias that handles it
+    # correctly. We cant use ClassAlias as that depends on __storm_id__ and
+    # __storm_table__
+    if issubclass(klass, Viewable):
+        return MyAlias(klass, name)
+    else:
+        return ClassAlias(klass, name)
+
+
 class SQLObjectBase(Storm):
     """The root class of all SQLObject-emulating classes in your application.
 
@@ -354,65 +365,86 @@ class SQLObjectBase(Storm):
     __metaclass__ = SQLObjectMeta
 
     q = DotQ()
-    _SO_creating = False
 
     def __init__(self, *args, **kwargs):
         self._connection = kwargs.get('connection')
         store = self._get_store()
         store.add(self)
         try:
-            self._create(None, **kwargs)
+            id_ = None
+            if kwargs.get('id'):
+                id_ = kwargs['id']
+                del kwargs['id']
+            self._create(id_, **kwargs)
         except:
             store.remove(self)
             raise
+        get_obj_info(self).event.hook('changed', self._on_object_changed)
+
+    # FIXME: Fix stoqlib.domain.base.Domain to not use this method
+    def _SO_setValue(self, name, value, from_, to):
+        pass
+
+    def _on_object_changed(self, obj_info, variable, old_value, new_value,
+                           fromdb):
+        if new_value is not AutoReload and not fromdb:
+            self._SO_setValue('foo', 'bar', 'bin', 'buz')
 
     def __storm_loaded__(self):
+        # When __storm_loaded__ is called, __init__ is not, but we still
+        # need a connection. Set it to None, and later it will be updated.
+        # This is the case when a object is restored from the database, and
+        # was not just created
+        self._connection = None
         self._init(None)
+        self.sqlmeta._creating = False
+        get_obj_info(self).event.hook('changed', self._on_object_changed)
 
     def _create(self, _id_, **kwargs):
-        store = self._get_store()
-        if self._connection is None:
-            self._connection = kwargs.pop('connection', store._connection)
-        self._SO_creating = True
-        self.set(**kwargs)
-        del self._SO_creating
-        self._init(None)
+        self.sqlmeta._creating = True
+        self.set(id=_id_, **kwargs)
+        self.sqlmeta._creating = False
+        self._init(_id_)
 
     def _init(self, id, *args, **kwargs):
-        self._connection = kwargs.get('connection',
-                                      getattr(self, '_connection', None))
         if self._connection is None:
-            self._get_store()
-
-        store = get_obj_info(self)['store']
-        if store.transactions:
-            self._connection = store.transactions[-1]
+            self._connection = STORE_TRANS_MAP[Store.of(self)]
 
     def set(self, **kwargs):
         for attr, value in kwargs.iteritems():
-            setattr(self, attr, value)
+            # FIXME: storm is not setting foreign keys correctly if the
+            # value is None (NULL)
+            if value is not None:
+                setattr(self, attr, value)
 
     def destroySelf(self):
         Store.of(self).remove(self)
 
-    @classmethod
-    def _get_store(cls):
-        from stoqlib.database.runtime import get_connection
-        cls._connection = cls.connection = get_connection()
-        return cls.connection.store
+    def _get_store(self):
+        # This happens then the object is restored from the database, so it
+        # should have a store
+        if not self._connection:
+            return Store.of(self)
+        return self._connection.store
+
+    def get_connection(self):
+        if not self._connection:
+            self._connection = STORE_TRANS_MAP[self._get_store()]
+
+        return self._connection
 
     @classmethod
     def delete(cls, id, connection=None):
         # destroySelf() should be extended to support cascading, so
         # we'll mimic what SQLObject does here, even if more expensive.
-        obj = cls.get(id)
+        obj = cls.get(id, connection=connection)
         obj.destroySelf()
 
     @classmethod
-    def get(cls, id, connection=None):
-        id = cls._idType(id)
-        store = cls._get_store()
-        obj = store.get(cls, id)
+    def get(cls, obj_id, connection=None):
+        obj_id = cls._idType(obj_id)
+        store = connection.store
+        obj = store.get(cls, obj_id)
         if obj is None:
             raise SQLObjectNotFound("Object not found")
         return obj
@@ -447,7 +479,7 @@ class SQLObjectBase(Storm):
         return SQLObjectResultSet(cls, *args, **kwargs)._one()
 
     @classmethod
-    def selectOneBy(cls, connection=None, **kwargs):
+    def selectOneBy(cls, connection, **kwargs):
         return SQLObjectResultSet(cls, by=kwargs,
                                   connection=connection)._one()
 
@@ -494,6 +526,9 @@ class SQLObjectResultSet(object):
         self._join = join
         self._distinct = distinct
         self._selectAlso = selectAlso
+        self._connection = connection
+        # FIXME: Fix stoqlib.api.for_combo to not use this property
+        self.sourceClass = cls
 
         # Parameters not mapping SQLObject:
         self._by = by
@@ -509,7 +544,7 @@ class SQLObjectResultSet(object):
         return copy
 
     def _prepare_result_set(self):
-        store = self._cls._get_store()
+        store = self._connection.store
 
         args = []
         if self._clause:
@@ -658,6 +693,12 @@ class SQLObjectResultSet(object):
         result_set = self._result_set
         return result_set.max(attribute)
 
+    def filterBy(self, **kwargs):
+        return self._copy(by=kwargs)
+
+    def filter(self, clause):
+        return self._copy(clause=clause)
+
 
 def detuplelize(item):
     """If item is a tuple, return first element, otherwise the item itself.
@@ -780,6 +821,8 @@ class SQLMultipleJoin(ReferenceSet):
 
     def __init__(self, otherClass=None, joinColumn=None,
                  intermediateTable=None, otherColumn=None, orderBy=None):
+        if joinColumn and joinColumn.endswith('_id'):
+            joinColumn = joinColumn[:-3] + 'ID'
         if intermediateTable:
             args = ("<primary key>",
                     "%s.%s" % (intermediateTable, joinColumn),
@@ -798,6 +841,7 @@ class SQLMultipleJoin(ReferenceSet):
         target_cls = bound_reference_set._target_cls
         where_clause = bound_reference_set._get_where_clause()
         return SQLObjectResultSet(target_cls, where_clause,
+                                  connection=obj.get_connection(),
                                   orderBy=self._orderBy)
 
     def _get_bound_reference_set(self, obj):
@@ -850,7 +894,9 @@ class SQLObjectView(object):
         if not attr in self.columns:
             raise AttributeError("%s object has no attribute %s" % (
                 self.cls.__name__, attr))
-        return self.columns[attr]
+        # This is an Alias, so we should return the original name (as this
+        # is used to construct queries clauses)
+        return self.columns[attr].expr
 
 
 class Viewable(Declarative):
@@ -859,32 +905,73 @@ class Viewable(Declarative):
 
     def __classinit__(cls, new_attrs):
         cols = new_attrs.get('columns')
+        if not cols and hasattr(cls, 'columns'):
+            cols = cls.columns
         if not cols:
             return
 
+        hidden_columns = new_attrs.get('hidden_columns', [])
         group_by = []
+        needs_group_by = False
         for name, col in cols.items():
-            if has_sql_call(col):
-                col = cols[name] = expr.Alias(col, name)
-            else:
-                group_by.append(col)
+            if name in hidden_columns:
+                del cols[name]
+                continue
 
+            if isinstance(col, expr.Alias):
+                col = col.expr
+
+            if not has_sql_call(col):
+                group_by.append(col)
+            else:
+                needs_group_by = True
+
+            col = cols[name] = expr.Alias(col, name)
             setattr(cls, name, col)
-        cls.group_by = group_by
+
+        if needs_group_by:
+            cls.group_by = group_by
+        else:
+            cls.group_by = []
 
         cls.q = SQLObjectView(cls, cols)
 
-        tables = [cols['id'].table]
-        for join in new_attrs.get('joins', []):
-            tables.append(join)
+        if isinstance(cols['id'], expr.Alias):
+            first_table = cols['id'].expr.table
+        else:
+            first_table = cols['id'].table
 
-        cls.tables = tables
+        if 'joins' not in new_attrs and hasattr(cls, 'joins'):
+            # Joins are not defined for this class, but are defined in the base
+            # class. We should not reconstruct the list of queries
+            tables = []
+        else:
+            # Joins is defined in this class, but not in the base class. So we
+            # should build the list of tables to be used here
+            tables = [first_table]
+
+            for join in new_attrs.get('joins', []):
+                # If the table is actually another Viewable, join with a Subselect
+                table = join.right
+                if isinstance(table, MyAlias) and issubclass(table.expr, Viewable):
+                    subselect = table.expr.get_select()
+                    subselect = expr.Alias(subselect, table.name)
+                    join = join.__class__(subselect, join.on)
+                tables.append(join)
+
+            cls.tables = tables
 
     def get_connection(self):
-        return None
+        return self._connection
 
     @classmethod
-    def select(cls, clause=None, having=None, connection=None):
+    def get_select(cls):
+        attributes, columns = zip(*cls.columns.items())
+        return Select(columns, cls.clause or Undef, cls.tables,
+                      group_by=cls.group_by or Undef)
+
+    @classmethod
+    def select(cls, clause=None, having=None, connection=None, orderBy=None):
         attributes, columns = zip(*cls.columns.items())
 
         if connection is None:
@@ -903,6 +990,7 @@ class Viewable(Declarative):
 
         def _load_view_objects(result, values):
             instance = cls()
+            instance._connection = connection
             for attribute, value in zip(attributes, values):
                 # Convert values according to the column specification
                 if hasattr(cls.columns[attribute], 'variable_factory'):
@@ -915,8 +1003,12 @@ class Viewable(Declarative):
         results = store.using(*cls.tables).find(columns, *clauses)
         if cls.group_by:
             results = results.group_by(*cls.group_by)
+        if orderBy:
+            results = results.order_by(orderBy)
 
         results._load_objects = _load_view_objects
+        # FIXME: Fix the callsites of orderBy
+        results.orderBy = results.order_by
         return results
 
 
@@ -947,6 +1039,10 @@ class QuantityCol(DecimalCol):
     variable_class = QuantityVariable
 
 
+class PercentCol(DecimalCol):
+    pass
+
+
 class MyDateTimeVariable(DateTimeVariable, DateVariable):
     def parse_set(self, value, from_db):
         if isinstance(value, datetime.date):
@@ -967,15 +1063,23 @@ class ConstantSpace(object):
         return type(attr, (NamedFunc, ), {'name': attr})
 
 
+STORE_TRANS_MAP = WeakValueDictionary()
+
+
 class Transaction(object):
     def __init__(self, conn):
         # FIXME: s.d.runtime uses this
         self._connection = conn
-        self.store = conn.store
-        self.store.transactions.append(self)
+        #self.store = conn.store
+        self.store = Store(self._connection.db)
+        STORE_TRANS_MAP[self.store] = self
+        #self.store.transactions.append(self)
 
     def query(self, stmt):
-        return self._connection.execute(stmt)
+        return self.store.execute(stmt)
+
+    def queryOne(self, stmt):
+        return self.store.execute(stmt).get_one()
 
     def queryAll(self, query):
         res = self.store.execute(
@@ -983,13 +1087,15 @@ class Transaction(object):
         return res.get_all()
 
     def commit(self, close=False):
-        self._connection.commit()
+        self.store.commit()
         if close:
-            self._connection.close()
-            self.store.transactions.remove(self)
+            self.store.close()
+            #self.store.transactions.remove(self)
 
     def rollback(self):
-        self._connection.rollback()
+        self.store.rollback()
+        # sqlobject closes the connection after a rollback
+        self.store.close()
 
     def begin(self):
         pass
@@ -1014,6 +1120,10 @@ class Transaction(object):
     def unblock_implicit_flushes(self):
         self.store.unblock_implicit_flushes()
 
+    def remove_from_cache(self, obj):
+        info = get_obj_info(obj)
+        self.store._cache.remove(info)
+
 
 class Connection(object):
     def __init__(self, db):
@@ -1021,6 +1131,7 @@ class Connection(object):
         self.store = None
 
     def dbVersion(self):
+        # FIXME
         return (8, 3)
 
     def queryOne(self, query):
@@ -1041,6 +1152,7 @@ class Connection(object):
 
     def makeConnection(self):
         self.store = Store(self.db)
+        STORE_TRANS_MAP[self.store] = self
         if not hasattr(self.store, 'transactions'):
             self.store.transactions = []
 
@@ -1050,7 +1162,8 @@ class Connection(object):
     def tableExists(self, tableName):
         res = self.store.execute(
             SQL("SELECT COUNT(relname) FROM pg_class WHERE relname = ?",
-                (tableName, )))
+                # FIXME: Figure out why this is not comming as unicode
+                (unicode(tableName), )))
         return res.get_one()[0]
 
     viewExists = tableExists
@@ -1072,7 +1185,7 @@ class Connection(object):
                    attname=?""", (table_name, column_name)))
         return bool(res.get_one())
 
-    def createDatabase(self, name, ifNotExists=False):
+    def createEmptyDatabase(self, name, ifNotExists=False):
         #print 'Connection.createDatabase(%r, %r)' % (name, ifNotExists)
         if ifNotExists and self.databaseExists(name):
             return False
@@ -1110,7 +1223,7 @@ class Connection(object):
     def databaseExists(self, name):
         res = self.execute(
             SQL("SELECT COUNT(*) FROM pg_database WHERE datname=?",
-                (name, )))
+                (unicode(name), )))
         return res.get_one()[0]
 
     def commit(self):
@@ -1141,8 +1254,11 @@ def has_sql_call(column):
         return False
 
     if isinstance(column, expr.NamedFunc):
-        if column.name in ('SUM', 'AVG', 'MIN', 'MAX'):
+        if column.name in ('SUM', 'AVG', 'MIN', 'MAX', 'COUNT'):
             return True
+        for e in column.args:
+            if has_sql_call(e):
+                return True
 
     elif isinstance(column, expr.CompoundExpr):
         for e in column.exprs:
@@ -1153,6 +1269,10 @@ def has_sql_call(column):
         if has_sql_call(column.expr1) or has_sql_call(column.expr2):
             return True
 
+    elif isinstance(column, expr.Alias):
+        if has_sql_call(column.expr):
+            return True
+
     return False
 
 
@@ -1230,18 +1350,53 @@ def orm_get_unittest_value(klass, test, tables_dict, name, column):
             raise ORMTestError("No example for %s" % cls)
     return value
 
+
+class ORMTypeInfo(object):
+    def __init__(self, orm_type):
+        self.orm_type = orm_type
+
+    def get_column_names(self):
+        info = get_cls_info(self.orm_type)
+        for name, attr in info.attributes.items():
+            yield name
+
+    def get_foreign_columns(self):
+        info = get_cls_info(self.orm_type)
+        for name, attr in info.attributes.items():
+            if not name.endswith('ID'):
+                continue
+
+            name = name[:-2]
+            ref = getattr(self.orm_type, name)
+            other_class = ref._remote_key.split('.')[0]
+            yield name, other_class
+
+    def get_single_joins(self):
+
+        for name, v in self.orm_type._attr_to_prop.items():
+            if not isinstance(v, Reference):
+                continue
+            other_class = v._remote_key.split('.')[0]
+            yield name, other_class
+
+
 orm_name = 'storm'
 
 #debug(True)
 
 # Exceptions
 
+
+class ORMTestError(Exception):
+    pass
+
 # ORMObject.get raises this
 ORMObjectNotFound = SQLObjectNotFound
 # ORMObject.selectOneBy raises this
 ORMObjectIntegrityError = NotOneError
 
 ORMObjectQueryExecuter = StormQueryExecuter
+IntegrityError = IntegrityError
 
 # Columns
 BLOBCol = BLOBCol
@@ -1277,7 +1432,9 @@ def MyLeftJoin(table1, table2, clause):
 
 # SQLBuilder
 const = ConstantSpace()
-Alias = ClassAlias
+func = const
+#Alias = ClassAlias
+Alias = GetAlias
 AND = And
 IN = In
 INNERJOINOn = MyJoin
@@ -1286,8 +1443,14 @@ INNERJOINOn = MyJoin
 def ISNOTNULL(arg):
     return arg != None
 
+
+class ILike(Like):
+    oper = ' ILIKE '
+
+
 LEFTJOINOn = MyLeftJoin
 LIKE = Like
+ILIKE = ILike
 NOT = Not
 OR = Or
 DESC = Desc
