@@ -36,13 +36,12 @@ from stoqlib.database.admin import create_base_schema
 from stoqlib.database.database import dump_table
 from stoqlib.database.interfaces import (ICurrentBranchStation, ICurrentBranch,
                                          IDatabaseSettings)
-from stoqlib.database.orm import ORMObject, ORMObjectNotFound, const
+from stoqlib.database.orm import ORMObjectNotFound, const
 from stoqlib.database.runtime import (get_connection, new_transaction,
                                       get_current_branch)
 from stoqlib.database.policy import get_policy_by_name
 from stoqlib.database.tables import get_table_type_by_name
-from stoqlib.domain.base import AdaptableORMObject
-from stoqlib.domain.person import PersonAdaptToUser
+from stoqlib.domain.person import LoginUser
 from stoqlib.domain.station import BranchStation
 from stoqlib.domain.synchronization import BranchSynchronization
 from stoqlib.domain.system import TransactionEntry
@@ -80,23 +79,16 @@ def _collect_table(tables, table):
 
     tables.append(table)
 
-    if issubclass(table, AdaptableORMObject):
-        # FIXME: Remove this and put the adapter tables in
-        #        the policy list directly instead
-        for facet_type in table.getFacetTypes():
-            if issubclass(facet_type, ORMObject):
-                _collect_table(tables, facet_type)
-
 
 def get_tables(policy, pfilter=None):
     """Fetches a list of tables given a specific policy.
     A pfilter can optionally be specified to filter out tables
     which does not match a specific state.
 
-    @param policy: a SynchronizationPolicy
-    @param pfilter: a sequence of states to skip or None to fetch all
-    @returns: a list of tables
-    @rtype: list of sqlobject tables
+    :param policy: a SynchronizationPolicy
+    :param pfilter: a sequence of states to skip or None to fetch all
+    :returns: a list of tables
+    :rtype: list of sqlobject tables
     """
     tables = []
     for table_name, table_policy in policy.tables:
@@ -225,14 +217,14 @@ class SynchronizationService(XMLRPCService):
     def get_station_name(self):
         """
         Gets the name of the station.
-        @returns: the name of the station.
+        :returns: the name of the station.
         """
         return socket.gethostname()
 
     def set_station_by_name(self, name):
         """
         Set the currently station by given name.
-        @param name: name of the station
+        :param name: name of the station
         """
         station = BranchStation.selectOneBy(name=name, connection=self.conn)
 
@@ -252,7 +244,7 @@ class SynchronizationService(XMLRPCService):
     def sql_prepare(self):
         """
         Gets an integer that represents the database insert.
-        @returns: an integer representing the insert
+        :returns: an integer representing the insert
         """
         log.info('service.sql_prepare()')
         settings = get_utility(IDatabaseSettings)
@@ -287,8 +279,8 @@ class SynchronizationService(XMLRPCService):
     def sql_insert(self, sid, data):
         """
         Insert sid and date.
-        @param sid:
-        @param data:
+        :param sid:
+        :param data:
         """
         # XXX: rewrite the docstring
         # XMLRPC sends us unicode, postgres/subprocess expects utf-8
@@ -302,8 +294,8 @@ class SynchronizationService(XMLRPCService):
     def sql_finish(self, sid):
         """
         Finish an sql process.
-        @param sid:
-        @returns: None if successful, otherwise a string
+        :param sid:
+        :returns: None if successful, otherwise a string
         """
         # XXX: rewrite the docstring
         log.info('service.sql_finish(%d)' % (sid, ))
@@ -407,10 +399,10 @@ class SynchronizationClient(object):
         if combined:
             yield combined
 
-        # PersonAdaptToUser and BranchStation are now copied, add back the
+        # LoginUser and BranchStation are now copied, add back the
         # constraints on the TransactionEntry table.
         if TransactionEntry in tables:
-            assert PersonAdaptToUser in tables
+            assert LoginUser in tables
             assert BranchStation in tables
             yield '''ALTER TABLE %(t)s
               ADD CONSTRAINT %(t)s_user_id_fkey FOREIGN KEY(user_id)
@@ -541,7 +533,7 @@ class SynchronizationClient(object):
     def update(self, station_name):
         """
         Update client.
-        @param station_name:
+        :param station_name:
         """
         # XXX: Rewrite docstring
         policy = self._get_policy('shop')
@@ -604,7 +596,7 @@ class SynchronizationClient(object):
         """Clones the database of the current machine and sends over the complete
         state to the client as raw SQL commands.
 
-        @param station_name:
+        :param station_name:
         """
         policy = self._get_policy('shop')
         if not transaction:
