@@ -146,17 +146,19 @@ class DeviceSettings(Domain):
 class FiscalDayTax(Domain):
     """This represents the information that needs to be used to
     generate a Sintegra file of type 60M.
-    :cvar code: four bytes, either the percental of the tax, 1800 for 18%
-    or one of::
-       - I: Isento
-       - F: Substitucao
-       - N: Nao tributado
-       - ISS: ISS
-       - CANC: Cancelled
-       - DESC: Discount
     """
     fiscal_day_history = ForeignKey('FiscalDayHistory')
+
+    #: four bytes, either the percental of the tax, 1800 for 18% or one of:
+    #:
+    #: * ``I``: Isento
+    #: * ``F``: Substitucao
+    #: * ``N``: Nao tributado
+    #: * ``ISS``: ISS
+    #: * ``CANC``: Cancelled
+    #: * ``DESC``: Discount
     code = StringCol()
+
     value = PriceCol()
     type = StringCol()
 
@@ -175,5 +177,5 @@ class FiscalDayHistory(Domain):
     crz = IntCol()
     period_total = PriceCol()
     total = PriceCol()
-    taxes = MultipleJoin('FiscalDayTax')
+    taxes = MultipleJoin('FiscalDayTax', 'fiscal_day_history_id')
     reduction_date = DateTimeCol()
