@@ -405,13 +405,13 @@ class ExampleCreator(object):
                     connection=self.trans,
                     **extra_args)
 
-    def create_sale_item(self):
+    def create_sale_item(self, sale=None):
         from stoqlib.domain.sale import SaleItem
         sellable = self.create_sellable()
         return SaleItem(connection=self.trans,
                         quantity=1,
                         price=100,
-                        sale=self.create_sale(),
+                        sale=sale or self.create_sale(),
                         sellable=sellable)
 
     def create_sale_item_icms(self):
@@ -675,7 +675,8 @@ class ExampleCreator(object):
                               short_name='Velec',
                               open_contract_date=datetime.date(2006, 01, 01))
 
-    def create_payment(self, payment_type=None, date=None):
+    def create_payment(self, payment_type=None, date=None,
+                       value=None, method=None):
         from stoqlib.domain.payment.payment import Payment
         if payment_type is None:
             payment_type = Payment.TYPE_OUT
@@ -686,7 +687,7 @@ class ExampleCreator(object):
                        due_date=date,
                        value=Decimal(10),
                        till=None,
-                       method=self.get_payment_method(),
+                       method=method or self.get_payment_method(),
                        category=None,
                        connection=self.trans,
                        payment_type=payment_type)
@@ -760,12 +761,18 @@ class ExampleCreator(object):
     def create_loan(self):
         from stoqlib.domain.loan import Loan
         user = self.create_user()
-        return Loan(responsible=user, connection=self.trans)
+        return Loan(responsible=user,
+                    branch=self.create_branch(),
+                    connection=self.trans)
 
     def create_loan_item(self):
         from stoqlib.domain.loan import LoanItem
+        from stoqlib.domain.product import Storable
         loan = self.create_loan()
         sellable = self.create_sellable()
+        storable = Storable(product=sellable.product,
+                            connection=self.trans)
+        storable.increase_stock(10, loan.branch)
         return LoanItem(loan=loan, sellable=sellable, price=10,
                         quantity=1, connection=self.trans)
 
