@@ -21,13 +21,20 @@
 ##
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
-""" Loan object and related objects implementation """
+
+"""
+
+This module contains classes for working with loans.
+
+The main class is :class:`Loan` which can hold a
+set of :class:`LoanItem`.
+"""
 
 import datetime
 from decimal import Decimal
 
 from kiwi.argcheck import argcheck
-from kiwi.datatypes import currency
+from kiwi.currency import currency
 from zope.interface import implements
 
 from stoqlib.database.orm import ForeignKey, UnicodeCol, DateTimeCol, IntCol
@@ -42,48 +49,97 @@ _ = stoqlib_gettext
 
 
 class LoanItem(Domain):
-    """An item in a loan.
+    """An item in a :class:`loan <Loan>`
+
+    Note that when changing :obj:`~.quantity`, :obj:`~.return_quantity`
+    or :obj:`~.sale_quantity` you will need to call :meth:`.sync_stock`
+    to synchronize the stock (increase or decrease it).
+
+    See also:
+    `schema <http://doc.stoq.com.br/schema/tables/loan_item.html>`__
 
-    :param sellable: the kind of item
-    :param loan: the same
-    :param quantity: the quantity of the of sold item in this loan
-    :param price: the price of each individual item
     """
+    # FIXME: Implement lazy updates in here to avoid all the _set_* bellow
+
+    #: The total quantity that was loaned. The product stock for this
+    #: will be decreased when the loan stock is synchonized
     quantity = QuantityCol()
+
+    #: The loadned quantity that was sold. Will increase stock so
+    #: it's decreased correctly when the
+    #: :class:`sale <stoqlib.domain.sale.Sale>` is confirmed
     sale_quantity = QuantityCol(default=Decimal(0))
+
+    #: The loaned quantity that was returned. Will increase stock
     return_quantity = QuantityCol(default=Decimal(0))
+
+    #: price to use for this :obj:`~.sellable` when creating
+    #: a :class:`sale <stoqlib.domain.sale.Sale>`
     price = PriceCol()
-    sellable = ForeignKey('Sellable')
+
+    #: :class:`sellable <stoqlib.domain.sellable.Sellable>` that is loaned
+    #: cannot be *None*
+    sellable = ForeignKey('Sellable', notNull=True)
+
+    #: :class:`loan <Loan>` this item belongs to
     loan = ForeignKey('Loan')
 
-    def _create(self, id, **kw):
-        if not 'kw' in kw:
-            if not 'sellable' in kw:
-                raise TypeError('You must provide a sellable argument')
-        Domain._create(self, id, **kw)
+    def __init__(self, *args, **kwargs):
+        self._diff_quantity = 0
+        super(LoanItem, self).__init__(*args, **kwargs)
 
-    def do_loan(self, branch):
-        """Performs the loan of the product. The quantity requested of the
-        product will be out of stock of the given branch.
-        """
-        storable = self.sellable.product_storable
-        if storable is not None:
-            storable.decrease_stock(self.quantity, branch)
+    @property
+    def branch(self):
+        return self.loan.branch
 
-    def return_product(self, quantity):
-        """Returns a certain quantity of the loan product to stock. The
-        quantity returned should be lesser or equal than the total quantity.
-        """
-        assert quantity <= self.quantity
-        storable = self.sellable.product_storable
-        if storable is not None:
-            branch = self.loan.branch
-            storable.increase_stock(quantity, branch)
+    @property
+    def storable(self):
+        return self.sellable.product_storable
 
     #
-    # Accessors
+    # ORMObject
     #
 
+    def _set_quantity(self, quantity):
+        diff_quantity = getattr(self, 'quantity', 0) - quantity
+
+        self._diff_quantity += diff_quantity
+        self._SO_set_quantity(quantity)
+
+    def _set_return_quantity(self, quantity):
+        diff_quantity = quantity - getattr(self, 'return_quantity', 0)
+
+        self._diff_quantity += diff_quantity
+        self._SO_set_return_quantity(quantity)
+
+    def _set_sale_quantity(self, quantity):
+        diff_quantity = quantity - getattr(self, 'sale_quantity', 0)
+
+        self._diff_quantity += diff_quantity
+        self._SO_set_sale_quantity(quantity)
+
+    #
+    # Public API
+    #
+
+    def sync_stock(self):
+        """Synchronizes the stock, increasing/decreasing it accordingly
+
+        When setting :obj:`~.quantity`, :obj:`~.return_quantity`
+        or :obj:`~.sale_quantity` be sure to call this to properly
+        synchronize the stock (increase or decrease it). That counts
+        for object creation too.
+        """
+        diff_quantity = self._diff_quantity
+
+        if diff_quantity > 0:
+            self.storable.increase_stock(diff_quantity, self.branch)
+        elif diff_quantity < 0:
+            diff_quantity = - diff_quantity
+            self.storable.decrease_stock(diff_quantity, self.branch)
+
+        self._diff_quantity = 0
+
     def get_quantity_unit_string(self):
         return "%s %s" % (self.quantity,
                           self.sellable.get_unit_description())
@@ -93,38 +149,63 @@ class LoanItem(Domain):
 
 
 class Loan(Domain):
-    """Loan object implementation.
+    """
+    A loan is a collection of sellable items that is being loaned
+    to a client, the items are expected to be returned at some
+    point in the future.
 
-    :cvar STATUS_OPEN: The loan is opened, products or other sellable items
-      might have been added and might not be in stock.
-    :cvar STATUS_CLOSED: All the products or other sellable items have been
-    returned and are available in stock.
-    :attribute status: status of the loan
-    :attribute client: who we loan
-    :attribute responsinble: who is responsible for this loan
-    :attribute branch: branch where the loan was done
-    :attribute open_date: the date loan was created
-    :attribute close_date: the date loan was closed
-    :attribute expire_return_date: the expected date loan will return
-    :attribute notes: Some optional additional information related to this loan.
+    A loan that can hold a set of :class:`loan items <LoanItem>`
+
+    See also:
+    `schema <http://doc.stoq.com.br/schema/tables/loan.html>`__
+    `manual <http://doc.stoq.com.br/manual/loan.html>`__
     """
 
     implements(IContainer)
 
-    (STATUS_OPEN,
-     STATUS_CLOSED) = range(2)
+    #: The request for a loan has been added to the system,
+    #: we know which of the items the client wishes to loan,
+    #: it's not defined if the client has actually picked up
+    #: the items.
+    STATUS_OPEN = 0
 
+    #: All the products or other sellable items have been
+    #: returned and are available in stock.
+    STATUS_CLOSED = 1
+
+    # FIXME: This is missing a few states,
+    #        STATUS_LOANED: stock is completely synchronized
     statuses = {STATUS_OPEN: _(u'Opened'),
                 STATUS_CLOSED: _(u'Closed')}
 
+    #: status of the loan
     status = IntCol(default=STATUS_OPEN)
+
+    #: notes related to this loan.
     notes = UnicodeCol(default='')
+
+    #: date loan was opened
     open_date = DateTimeCol(default=datetime.datetime.now)
+
+    #: date loan was closed
     close_date = DateTimeCol(default=None)
+
+    #: loan expires on this date, we expect the items to
+    #: to be returned by this date
     expire_date = DateTimeCol(default=None)
+
     removed_by = UnicodeCol(default='')
+
+    #: branch where the loan was done
     branch = ForeignKey('Branch', default=None)
+
+    #: :class:`user <stoqlib.domain.person.LoginUser>` of the system
+    #: that made the loan
+    # FIXME: Should probably be a SalesPerson, we can find the
+    #        LoginUser via te_created.user
     responsible = ForeignKey('LoginUser')
+
+    #: client that loaned the items
     client = ForeignKey('Client', default=None)
 
     #
@@ -153,8 +234,13 @@ class Loan(Domain):
     def remove_item(self, loan_item):
         LoanItem.delete(loan_item.id, connection=self.get_connection())
 
+    #
+    # Public API
+    #
+
     def add_sellable(self, sellable, quantity=1, price=None):
         """Adds a new sellable item to a loan
+
         :param sellable: the sellable
         :param quantity: quantity to add, defaults to 1
         :param price: optional, the price, it not set the price
@@ -173,7 +259,9 @@ class Loan(Domain):
 
     def get_total_amount(self):
         """
-        Fetches the total value  paid by the client.
+        Fetches the total value of the loan, that is to be paid by
+        the client.
+
         It can be calculated as::
 
             Sale total = Sum(product and service prices) + surcharge +
@@ -205,6 +293,16 @@ class Loan(Domain):
     # Public API
     #
 
+    def sync_stock(self):
+        """Synchronizes the stock of *self*'s :class:`loan items <LoanItem>`
+
+        Just a shortcut to call :meth:`LoanItem.sync_stock` of all of
+        *self*'s :class:`loan items <LoanItem>` instead of having
+        to do that one by one.
+        """
+        for loan_item in self.get_items():
+            loan_item.sync_stock()
+
     def can_close(self):
         """Checks if the loan can be closed. A loan can be closed if it is
         opened and all the items have been returned or sold.
@@ -221,5 +319,5 @@ class Loan(Domain):
         """Closes the loan. At this point, all the loan items have been
         returned to stock or sold."""
         assert self.can_close()
-        self.close_date = datetime.date.today()
+        self.close_date = datetime.datetime.now()
         self.status = Loan.STATUS_CLOSED
