@@ -32,7 +32,7 @@ from kiwi.argcheck import argcheck
 from zope.interface import implements
 
 from stoqlib.database.orm import PercentCol, PriceCol
-from stoqlib.database.orm import IntCol, ForeignKey, BoolCol, StringCol, UnicodeCol
+from stoqlib.database.orm import IntCol, ForeignKey, BoolCol, StringCol
 from stoqlib.database.orm import const, AND
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IActive, IDescribable
@@ -53,28 +53,17 @@ _ = stoqlib_gettext
 class CheckData(Domain):
     """Stores check informations and also a history of possible
     devolutions.
-
-    :attribute bank_data: information about the bank account of this check.
-    :attribute payment: the payment object.
     """
+
+    #: the :class:`payment <stoqlib.domain.payment.Payment>`
     payment = ForeignKey('Payment')
+
+    #: the :class:`bank account <stoqlib.domain.account.BankAccount>`
     bank_account = ForeignKey('BankAccount')
 
 
 class CreditCardData(Domain):
     """Stores CreditCard specific state related to a payment
-
-    :attribute payment: the payment
-    :type payment: :class:`Payment`
-    :attribute card_type:
-    :type card_type: int, > 0, < 3
-    :attribute provider:
-    :type provider: :class:`CreditProvider`
-    :attribute installments: the installments number
-    :type installments: int, >= 1
-    :attribute entrance_value: the value of the first installment
-                          (when installments > 1)
-    :type entrance_value: currency
     """
     (TYPE_CREDIT,
      TYPE_DEBIT,
@@ -91,48 +80,59 @@ class CreditCardData(Domain):
         TYPE_DEBIT_PRE_DATED: _('Debit Card Pre-dated'),
         }
 
+    #: the :class:`payment <stoqlib.domain.payment.Payment>`
     payment = ForeignKey('Payment')
+
+    #: int, > 0, < 3
     card_type = IntCol(default=TYPE_CREDIT)
+
+    # the :class:`credit provider <CreditProvider>` for this class
     provider = ForeignKey('CreditProvider', default=None)
     fee = PercentCol(default=0)
     fee_value = PriceCol(default=0)
     nsu = IntCol(default=None)
     auth = IntCol(default=None)
+
+    #: the number of installments
     installments = IntCol(default=1)
+
+    #: the value of the first installment (when installments > 1)
     entrance_value = PriceCol(default=0)
 
 
 class PaymentMethod(Domain):
     """A PaymentMethod controls how a payments is paid. Example of payment
-    methods are: money, bill, check and credit card.
+    methods are::
+
+    * money
+    * bill
+    * check
+    * credit card
+
     This class consists of the persistent part of a payment method.
     The logic itself for the various different methods are in the
-    PaymentMethodOperation classes. Each PaymentMethod has a PaymentMethodOperation
-    associated.
-    :attribute name:
-    :attribute description:
-    :attribute is_active:
-    :attribute daily_penalty:
-    :attribute interest: a value for the interest. It must always be in the format:
-       0 <= interest <= 100
-    :attribute payment_day: which day in the month is the credit provider going
-      to pay the store? Usually they pay in the same day
-      every month.
-    :attribute closing_day: which day the credit provider stoq counting sales
-      to pay in the payment_day? Sales after this day
-      will be paid only in the next month.
-    :attribute account_destination: destination account for payment
-      methods which creates transactions
+    PaymentMethodOperation classes. Each :class:`PaymentMethod` has a
+    PaymentMethodOperation associated.
     """
 
     implements(IActive, IDescribable)
 
     method_name = StringCol()
     is_active = BoolCol(default=True)
-    description = UnicodeCol()
     daily_penalty = PercentCol(default=0)
+
+    #: a value for the interest. It must always be in the format::
+    #:
+    #:  0 <= interest <= 100
+    #:
     interest = PercentCol(default=0)
+
+    #: which day in the month is the credit provider going to pay the store?
+    #: Usually they pay in the same day every month.
     payment_day = IntCol(default=None)
+
+    #: which day the credit provider stoq counting sales to pay in the
+    #: payment_day? Sales after this day will be paid only in the next month.
     closing_day = IntCol(default=None)
     max_installments = IntCol(default=1)
     destination_account = ForeignKey('Account', default=None)
@@ -165,11 +165,16 @@ class PaymentMethod(Domain):
     # Properties
     #
 
+    @property
+    def description(self):
+        return self.operation.description
+
     @property
     def operation(self):
         """Get the operation for this method.
         The operation contains method specific logic when
         creating/deleting a payment.
+
         :return: the operation associated with the method
         :rtype: object implementing IPaymentOperation
         """
@@ -229,6 +234,7 @@ class PaymentMethod(Domain):
                        description=None, base_value=None, till=ValueUnset,
                        payment_number=None):
         """Creates a new payment according to a payment method interface
+
         :param payment_type: the kind of payment, in or out
         :param payment_group: a :class:`PaymentGroup` subclass
         :param value: value of payment
@@ -238,7 +244,7 @@ class PaymentMethod(Domain):
         :param base_value: optional
         :param till: optional
         :param payment_number: optional
-        :returns: a :class:`Payment`
+        :returns: a :class:`payment <stoqlib.domain.payment.Payment>`
         """
         conn = self.get_connection()
 
@@ -248,7 +254,8 @@ class PaymentMethod(Domain):
         if payment_type == Payment.TYPE_IN:
             query = AND(Payment.q.groupID == payment_group.id,
                         Payment.q.methodID == self.id,
-                        Payment.q.payment_type == Payment.TYPE_IN)
+                        Payment.q.payment_type == Payment.TYPE_IN,
+                        Payment.q.status != Payment.STATUS_CANCELLED)
             payment_count = Payment.select(query,
                                 connection=self.get_connection()).count()
             if payment_count == self.max_installments:
@@ -295,11 +302,12 @@ class PaymentMethod(Domain):
         the value and dividing it by the number of payments.
         The number of payments is determined by the length of the due_dates
         sequence.
+
         :param payment_type: the kind of payment, in or out
         :param payment_group: a :class:`PaymentGroup` subclass
         :param value: value of payment
         :param due_dates: a list of datetime objects
-        :returns: a list of :class:`Payment`
+        :returns: a list of :class:`payments <stoqlib.domain.payment.Payment>`
         """
         installments = len(due_dates)
         interest = Decimal(0)
@@ -350,13 +358,14 @@ class PaymentMethod(Domain):
     def create_inpayment(self, payment_group, value, due_date=None,
                          description=None, base_value=None, till=ValueUnset):
         """Creates a new inpayment
+
         :param payment_group: a :class:`PaymentGroup` subclass
         :param value: value of payment
         :param due_date: optional, due date of payment
         :param description: optional, description of the payment
         :param base_value: optional
         :param till: optional
-        :returns: a :class:`Payment`
+        :returns: a :class:`payment <stoqlib.domain.payment.Payment>`
         """
         return self.create_payment(Payment.TYPE_IN, payment_group,
                                    value, due_date,
@@ -367,13 +376,14 @@ class PaymentMethod(Domain):
     def create_outpayment(self, payment_group, value, due_date=None,
                           description=None, base_value=None, till=ValueUnset):
         """Creates a new outpayment
+
         :param payment_group: a :class:`PaymentGroup` subclass
         :param value: value of payment
         :param due_date: optional, due date of payment
         :param description: optional, description of the payment
         :param base_value: optional
         :param till: optional
-        :returns: a :class:`Payment`
+        :returns: a :class:`payment <stoqlib.domain.payment.Payment>`
         """
         return self.create_payment(Payment.TYPE_OUT, payment_group,
                                    value, due_date,
@@ -386,10 +396,11 @@ class PaymentMethod(Domain):
         the number of payments.
         The number of payments is determined by the length of the due_dates
         sequence.
+
         :param payment_group: a :class:`PaymentGroup` subclass
         :param value: total value of all payments
         :param due_dates: a list of datetime objects
-        :returns: a list of :class:`Payment`
+        :returns: a list of :class:`payments <stoqlib.domain.payment.Payment>`
         """
         return self.create_payments(Payment.TYPE_IN, payment_group,
                                     value, due_dates)
@@ -401,10 +412,11 @@ class PaymentMethod(Domain):
         the number of payments.
         The number of payments is determined by the length of the due_dates
         sequence.
+
         :param payment_group: a :class:`PaymentGroup` subclass
         :param value: total value of all payments
         :param due_dates: a list of datetime objects
-        :returns: a list of :class:`Payment`
+        :returns: a list of :class:`payments <stoqlib.domain.payment.Payment>`
         """
         return self.create_payments(Payment.TYPE_OUT, payment_group,
                                     value, due_dates)
@@ -413,15 +425,17 @@ class PaymentMethod(Domain):
     def get_active_methods(cls, conn):
         """Returns a list of active payment methods
         """
-        return PaymentMethod.selectBy(is_active=True,
-                                      connection=conn).orderBy('description')
+        methods = PaymentMethod.selectBy(is_active=True,
+                                         connection=conn)
+        return locale_sorted(methods,
+                             key=operator.attrgetter('description'))
 
     @classmethod
     def get_by_name(cls, conn, name):
         """Returns the Payment method associated by the nmae
+
         :param name: name of a payment method
-        :returns: the payment method class
-        :rtype: :class:`PaymentMethod` instance
+        :returns: a :class:`payment methods <PaymentMethod>`
         """
         return PaymentMethod.selectOneBy(connection=conn,
                                          method_name=name)
@@ -430,7 +444,8 @@ class PaymentMethod(Domain):
     def get_creatable_methods(cls, conn, payment_type, separate):
         """Gets a list of methods that are creatable.
         Eg, you can use them to create new payments.
-        :returns: a list of :class:`PaymentMethod` instances
+
+        :returns: a list of :class:`payment methods <PaymentMethod>`
         """
         methods = []
         for method in cls.get_active_methods(conn):
@@ -438,12 +453,27 @@ class PaymentMethod(Domain):
                                               separate):
                 continue
             methods.append(method)
+        return methods
+
+    @classmethod
+    def get_editable_methods(cls, conn):
+        """Gets a list of methods that are editable
+        Eg, you can change the details such as maximum installments etc.
+
+        :returns: a list of :class:`payment methods <PaymentMethod>`
+        """
+        # FIXME: Dont let users see online payments for now, to avoid
+        #        confusions with active state. online is an exception to that
+        #        logic.
+        methods = cls.select(connection=conn,
+                             clause=cls.q.method_name != 'online')
         return locale_sorted(methods,
                              key=operator.attrgetter('description'))
 
     def selectable(self):
         """Finds out if the method is selectable, eg
         if the user can select it when doing a sale.
-        :returns: True if selectable, otherwise False
+
+        :returns: ``True`` if selectable
         """
         return self.operation.selectable(self)
