@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2008 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2005-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -21,12 +21,21 @@
 ##
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
-""" Payment management implementations."""
+"""Payment management implementations.
+
+This module is centered around payments.
+
+The main payment class is :class:`Payment` which is a transfer of money, to/from
+a :class:`branch <stoqlib.domain.person.Branch>`.
+
+Certain changes to a payment is saved in :class:`PaymentChangeHistory` and
+:class:`PaymentFlowHistory`.
+"""
 
 import datetime
 from decimal import Decimal
 
-from kiwi.datatypes import currency
+from kiwi.currency import currency
 from kiwi.log import Logger
 
 from stoqlib.database.orm import (IntCol, DateTimeCol, UnicodeCol, ForeignKey,
@@ -44,41 +53,87 @@ log = Logger('stoqlib.domain.payment.payment')
 
 
 class Payment(Domain):
-    """ The payment representation in Stoq.
+    """Payment, a transfer of money between a :class:`branch <stoqlib.domain.person.Branch>`
+    and :class:`client <stoqlib.domain.person.Client>` or a
+    :class:`supplier <stoqlib.domain.person.Supplier>`
 
-    B{Importante attributes}:
-        - I{interest}: the absolute value for the interest associated with
-                       this payment.
-        - I{discount}: the absolute value for the discount associated with
-                       this payment.
-        - I{penalty}: the absolute value for the penalty associated with
-                       this payment.
+    Payments between:
+
+    * a client and a branch are :obj:`.TYPE_IN`, has a
+      :class:`sale <stoqlib.domain.sale.Sale>` associated.
+    * branch and a supplier are :obj:`.TYPE_OUT`, has a
+      :class:`purchase order <stoqlib.domain.purchase.PurchaseOrder>` associated.
+
+    Payments are sometimes referred to as *installements*.
+
+    Sales and purchase orders can be accessed via the
+    :obj:`payment group <.group>`
+
+    +-------------------------+-------------------------+
+    | **Status**              | **Can be set to**       |
+    +-------------------------+-------------------------+
+    | :obj:`STATUS_PREVIEW`   | :obj:`STATUS_PENDING`   |
+    +-------------------------+-------------------------+
+    | :obj:`STATUS_PENDING`   | :obj:`STATUS_PAID`,     |
+    |                         | :obj:`STATUS_CANCELLED` |
+    +-------------------------+-------------------------+
+    | :obj:`STATUS_PAID`      | :obj:`STATUS_PENDING`,  |
+    |                         | :obj:`STATUS_CANCELLED` |
+    +-------------------------+-------------------------+
+    | :obj:`STATUS_CANCELLED` | None                    |
+    +-------------------------+-------------------------+
+
+    .. graphviz::
+
+       digraph status {
+         STATUS_PREVIEW -> STATUS_PENDING;
+         STATUS_PENDING -> STATUS_PAID;
+         STATUS_PENDING -> STATUS_CANCELLED;
+         STATUS_PAID -> STATUS_PENDING;
+         STATUS_PAID -> STATUS_CANCELLED;
+       }
+
+    Simple sale workflow:
+
+    * Creating a sale, status is set to :obj:`STATUS_PREVIEW`
+    * Confirming the sale, status is set to :obj:`STATUS_PENDING`
+    * Paying the installment, status is set to :obj:`STATUS_PAID`
+    * Cancelling the payment, status is set to :obj:`STATUS_CANCELLED`
+
+    See also:
+    `schema <http://doc.stoq.com.br/schema/tables/payment.html>`__
     """
 
-    # Payment type
-    # IN = incoming to the company, accounts receivable
-    # OUT = outgoing from the company, accounts payable
+    #: incoming to the company, accounts receivable, payment from
+    #: a :class:`~stoqlib.domain.person.Client` to
+    #: a :class:`~stoqlib.domain.person.Branch`.
+    TYPE_IN = 0
 
-    (TYPE_IN,
-     TYPE_OUT) = range(2)
+    #: outgoing from the company, accounts payable, a payment from
+    #: a :class:`~stoqlib.domain.person.Branch` to
+    #: a :class:`~stoqlib.domain.person.Supplier`
+    TYPE_OUT = 1
 
-    # Status description
-    # Sale: (PENDING, PAID, CANCELLED)
-    # A payment is created in STATUS_PREVIEW
-    # When you confirm a sale or a purchase, the status is modified to PENDING
-    # If you pay with money, status is set to STATUS_PAID
-    # Otherwise it's left as pending until the money is received.
-    # Finally if you cancel the payment
-    # the status is set to STATUS_CANCELLED
+    #: payment group this payment belongs to hasn't been confirmed,
+    # should normally be filtered when showing a payment list
+    STATUS_PREVIEW = 0
 
-    # Purchase: (PENDING, PAID, REVIEWING, CONFIRMED, CANCELLED)
-    # TODO
-    (STATUS_PREVIEW,
-     STATUS_PENDING,
-     STATUS_PAID,
-     STATUS_REVIEWING, # Looks like this two statuses are not
-     STATUS_CONFIRMED, # used anymore
-     STATUS_CANCELLED) = range(6)
+    #: payment group has been confirmed and the payment has not been received
+    STATUS_PENDING = 1
+
+    #: the payment has been received
+    STATUS_PAID = 2
+
+    # FIXME: Remove these two
+    #: Unused.
+    STATUS_REVIEWING = 3
+
+    #: Unused.
+    STATUS_CONFIRMED = 4
+
+    #: payment was cancelled, for instance the payments of the group was changed, or
+    #: the group was cancelled.
+    STATUS_CANCELLED = 5
 
     statuses = {STATUS_PREVIEW: _(u'Preview'),
                 STATUS_PENDING: _(u'To Pay'),
@@ -87,26 +142,75 @@ class Payment(Domain):
                 STATUS_CONFIRMED: _(u'Confirmed'),
                 STATUS_CANCELLED: _(u'Cancelled')}
 
+    #: type of payment :obj:`.TYPE_IN` or :obj:`.TYPE_OUT`
     payment_type = IntCol()
+
+    #: status, see :class:`Payment` for more information.
     status = IntCol(default=STATUS_PREVIEW)
-    open_date = DateTimeCol(default=datetime.datetime.now)
-    due_date = DateTimeCol()
-    paid_date = DateTimeCol(default=None)
-    cancel_date = DateTimeCol(default=None)
-    paid_value = PriceCol(default=None)
-    base_value = PriceCol(default=None)
-    value = PriceCol()
-    interest = PriceCol(default=0)
-    discount = PriceCol(default=0)
-    penalty = PriceCol(default=0)
+
+    #: description payment, usually something like "1/3 Money for Sale 1234"
     description = UnicodeCol(default=None)
+
+    # FIXME: use const.NOW() instead to avoid server/client date
+    #        inconsistencies
+
+    #: when this payment was opened
+    open_date = DateTimeCol(default=datetime.datetime.now)
+
+    #: when this payment is due
+    due_date = DateTimeCol()
+
+    #: when this payment was paid
+    paid_date = DateTimeCol(default=None)
+
+    #: when this payment was cancelled
+    cancel_date = DateTimeCol(default=None)
+
+    # FIXME: Figure out when and why this differs from value
+    #: base value
+    base_value = PriceCol(default=None)
+
+    #: value of the payment
+    value = PriceCol()
+
+    #: the actual amount that was paid, including penalties, interest, discount etc.
+    paid_value = PriceCol(default=None)
+
+    #: interest of this payment
+    interest = PriceCol(default=0)
+
+    #: discount, an absolute value with the difference between the
+    #: sales price and :obj:`.value`
+    discount = PriceCol(default=0)
+
+    #: penalty of the payment
+    penalty = PriceCol(default=0)
+
+    # FIXME: Figure out what this is used for
+    #: number of the payment
     payment_number = UnicodeCol(default=None)
+
+    #: :class:`payment method <stoqlib.domain.payment.method.PaymentMethod>` for this
+    #: payment
     method = ForeignKey('PaymentMethod')
+
+    #: :class:`group <stoqlib.domain.payment.group.PaymentGroup>` for this
+    #: payment
     group = ForeignKey('PaymentGroup')
+
+    #: :class:`till <stoqlib.domain.till.Till>` that this payment belongs to
     till = ForeignKey('Till')
+
+    #: :class:`category <stoqlib.domain.payment.category.PaymentCategory>` this
+    #: payment belongs to, can be None
     category = ForeignKey('PaymentCategory')
 
-    comments = MultipleJoin('PaymentComment')
+    #: list of :class:`comments <stoqlib.domain.payment.comments.PaymentComment>` for
+    #: this payment
+    comments = MultipleJoin('PaymentComment', 'payment_id')
+
+    #: list of :class:`check data <stoqlib.domain.payment.method.CheckData>` for
+    #: this payment
     check_data = SingleJoin('CheckData', joinColumn='payment_id')
 
     def _check_status(self, status, operation_name):
@@ -140,10 +244,12 @@ class Payment(Domain):
 
     @property
     def comments_number(self):
+        """The number of :class:`comments <stoqlib.domain.payment.comments.PaymentComment>` for this payment"""
         return self.comments.count()
 
     @property
     def bank_account_number(self):
+        """For check payments, the :class:`bank account <BankAccount>` number"""
         # This is used by test_payment_method, and is a convenience
         # property, ideally we should move it to payment operation
         # somehow
@@ -154,12 +260,17 @@ class Payment(Domain):
                 return bank_account.bank_number
 
     def get_status_str(self):
+        """The :obj:`.status` as a translated string"""
         if not self.status in self.statuses:
             raise DatabaseInconsistency('Invalid status for Payment '
                                         'instance, got %d' % self.status)
         return self.statuses[self.status]
 
     def get_days_late(self):
+        """For due payments, the number of days late this payment is
+
+        :returns: the number of days late
+        """
         if self.status == Payment.STATUS_PAID:
             return 0
 
@@ -170,8 +281,9 @@ class Payment(Domain):
         return days_late.days
 
     def set_pending(self):
-        """Set a STATUS_PREVIEW payment as STATUS_PENDING. This also means
-        that this is valid payment and its owner actually can charge it
+        """Set a :obj:`.STATUS_PREVIEW` payment as :obj:`.STATUS_PENDING`.
+        This also means that this is valid payment and its owner
+        actually can charge it
         """
         self._check_status(self.STATUS_PREVIEW, 'set_pending')
         self.status = self.STATUS_PENDING
@@ -179,11 +291,11 @@ class Payment(Domain):
         PaymentFlowHistory.add_payment(self.get_connection(), self)
 
     def set_not_paid(self, change_entry):
-        """Set a STATUS_PAID payment as STATUS_PENDING. This requires clearing
-        paid_date and paid_value
+        """Set a :obj:`.STATUS_PAID` payment as :obj:`.STATUS_PENDING`.
+        This requires clearing paid_date and paid_value
 
-        :param change_entry: an PaymentChangeHistory object, that will hold the changes
-        information
+        :param change_entry: a :class:`PaymentChangeHistory` object,
+          that will hold the changes information
         """
         self._check_status(self.STATUS_PAID, 'set_not_paid')
 
@@ -198,7 +310,7 @@ class Payment(Domain):
         self.paid_value = None
 
     def pay(self, paid_date=None, paid_value=None, account=None):
-        """Pay the current payment set its status as STATUS_PAID"""
+        """Pay the current payment set its status as :obj:`.STATUS_PAID`"""
         if self.status != Payment.STATUS_PENDING:
             raise ValueError(_("This payment is already paid."))
         self._check_status(self.STATUS_PENDING, 'pay')
@@ -229,6 +341,8 @@ class Payment(Domain):
         Event.log(Event.TYPE_PAYMENT, msg.capitalize())
 
     def cancel(self, change_entry=None):
+        """Cancel the payment, set it's status to :obj:`.STATUS_CANCELLED`
+        """
         # TODO Check for till entries here and call cancel_till_entry if
         # it's possible. Bug 2598
         if self.status not in [Payment.STATUS_PREVIEW, Payment.STATUS_PENDING,
@@ -269,15 +383,22 @@ class Payment(Domain):
         self.due_date = new_due_date
 
     def update_value(self, new_value):
+        """Update the payment value.
+
+        This will update the logging of the
+        :class:`payment flow history <PaymentFlowHistory>` as well.
+        """
         conn = self.get_connection()
         PaymentFlowHistory.remove_payment(conn, self, self.due_date)
         self.value = new_value
         PaymentFlowHistory.add_payment(conn, self, self.due_date)
 
     def get_payable_value(self):
-        """ Returns the calculated payment value with the daily penalty.
-            Note that the payment group daily_penalty must be
-            between 0 and 100.
+        """Returns the calculated payment value with the daily penalty.
+
+        Note that the payment group daily_penalty must be between 0 and 100.
+
+        :returns: the payable value
         """
         if self.status in [self.STATUS_PREVIEW, self.STATUS_CANCELLED]:
             return self.value
@@ -289,9 +410,10 @@ class Payment(Domain):
 
     def get_penalty(self, date=None):
         """Calculate the penalty in an absolute value
+
         :param date: date of payment
         :returns: penalty
-        :rtype: currency
+        :rtype: :class:`kiwi.currency.currency`
         """
         if not date:
             date = datetime.date.today()
@@ -311,9 +433,10 @@ class Payment(Domain):
 
     def get_interest(self, date=None):
         """Calculate the interest in an absolute value
+
         :param date: date of payment
         :returns: interest
-        :rtype: currency
+        :rtype: :class:`kiwi.currency.currency`
         """
         if not date:
             date = datetime.date.today()
@@ -332,32 +455,36 @@ class Payment(Domain):
 
     def is_paid(self):
         """Check if the payment is paid.
-        :returns: True if the payment is paid, otherwise False
+
+        :returns: ``True`` if the payment is paid
         """
         return self.status == Payment.STATUS_PAID
 
     def is_pending(self):
         """Check if the payment is pending.
-        :returns: True if the payment is pending, otherwise False
+
+        :returns: ``True`` if the payment is pending
         """
         return self.status == Payment.STATUS_PENDING
 
     def is_preview(self):
         """Check if the payment is in preview state
-        :returns: True if the payment is paid, otherwise False
+
+        :returns: ``True`` if the payment is paid
         """
         return self.status == Payment.STATUS_PREVIEW
 
     def is_cancelled(self):
         """Check if the payment was cancelled.
-        :returns: True if the payment was cancelled, otherwise False.
+
+        :returns: ``True`` if the payment was cancelled
         """
         return self.status == Payment.STATUS_CANCELLED
 
     def get_paid_date_string(self):
         """Get a paid date string
-        :returns: the paid date string or PAID DATE if the payment isn't
-        paid
+
+        :returns: the paid date string or PAID DATE if the payment isn't paid
         """
         if self.paid_date:
             return self.paid_date.date().strftime('%x')
@@ -365,6 +492,7 @@ class Payment(Domain):
 
     def get_open_date_string(self):
         """Get a open date string
+
         :returns: the open date string or empty string
         """
         if self.open_date:
@@ -375,16 +503,25 @@ class Payment(Domain):
         return u'%05d' % self.id
 
     def is_inpayment(self):
-        """Find out if a payment is incoming
-        :returns: True if it's incoming"""
+        """Find out if a payment is :obj:`incoming <.TYPE_IN>`
+
+        :returns: ``True`` if it's incoming
+        """
         return self.payment_type == self.TYPE_IN
 
     def is_outpayment(self):
-        """Find out if a payment is outgoing
-        :returns: True if it's outgoing"""
+        """Find out if a payment is :obj:`outgoing <.TYPE_OUT>`
+
+        :returns: ``True`` if it's outgoing
+        """
         return self.payment_type == self.TYPE_OUT
 
     def is_separate_payment(self):
+        """Find out if this payment is created separately from a
+        sale, purchase or renegotiation
+        :returns: ``True`` if it's separate.
+        """
+
         # FIXME: This is a hack, we should rather store a flag
         #        in the database that tells us how the payment was
         #        created.
@@ -404,7 +541,8 @@ class Payment(Domain):
 
     def is_money(self):
         """Find out if the payment was made with money
-        :returns: True if it's a money payment
+
+        :returns: ``True`` if it's a money payment
         """
         return self.method.method_name == 'money'
 
@@ -415,50 +553,74 @@ class PaymentChangeHistory(Domain):
     Only one tuple (last_due_date, new_due_date) or (last_status, new_status)
     should be non-null at a time.
 
-    :param payment: the payment changed
-    :param change_reason: the reason of the due date change
-    :param last_due_date: the due date that was set before the changed
-    :param new_due_date: the due date that was set after changed
-    :param last_status: status before the change
-    :param new_status: status after change
+    See also:
+    `schema <http://doc.stoq.com.br/schema/tables/payment_change_history.html>`__
     """
+
+    #: the changed :class:`payment <stoqlib.domain.payment.payment.Payment>`
     payment = ForeignKey('Payment')
+
+    #: the reason of the change
     change_reason = UnicodeCol(default=None)
+
+    #: when the changed happened
     change_date = DateTimeCol(default=datetime.datetime.now)
+
+    #: the due date that was set before the changed
     last_due_date = DateTimeCol(default=None)
+
+    #: the due date that was set after changed
     new_due_date = DateTimeCol(default=None)
+
+    #: status before the change
     last_status = IntCol(default=None)
+
+    #: status after change
     new_status = IntCol(default=None)
 
 
 class PaymentFlowHistory(Domain):
-    """A class to hold information about the financial flow.
+    """The flow of payments during a day.
 
-    :param history_date: the date when payments were registered.
-    :param to_receive: the amount scheduled to be received in the
-                       history_date.
-    :param received: the amount received in the history_date.
-    :param to_pay: the amount scheduled to be paid in the history_date.
-    :param paid: the amount paid in the history_date.
-    :param balance_expected: the balance of the last day plus the amount to be
-                             received minus the amount to be paid.
-    :param balance_real: the balance of the last day plus the amount received
-                         minus the amount paid.
+    See also:
+    `schema <http://doc.stoq.com.br/schema/tables/payment_flow_history.html>`__
     """
 
+    # FIXME: this class really needs a branch, it doesn't make sense
+    #        without one.
+
+    #: date this entry represent
     history_date = DateTimeCol(default=datetime.datetime.now)
 
+    #: the amount scheduled to be received
     to_receive = PriceCol(default=Decimal(0))
+
+    #: the amount received
     received = PriceCol(default=Decimal(0))
+
+    #: the amount scheduled to be paid
     to_pay = PriceCol(default=Decimal(0))
+
+    #: the amount paid
     paid = PriceCol(default=Decimal(0))
 
+    #: the balance of the last day plus the amount to be received minus
+    #: the amount to be paid.
     balance_expected = PriceCol(default=Decimal(0))
+
+    #: the balance of the last day plus the amount received minus the amount paid.
     balance_real = PriceCol(default=Decimal(0))
 
+    #: number of payments to receive
     to_receive_payments = IntCol(default=0)
+
+    #: number of payments received
     received_payments = IntCol(default=0)
+
+    #: payments to pay
     to_pay_payments = IntCol(default=0)
+
+    #: payments paid
     paid_payments = IntCol(default=0)
 
     #
@@ -477,13 +639,14 @@ class PaymentFlowHistory(Domain):
 
     def get_divergent_payments(self):
         """Returns a :class:`Payment` sequence that meet to following requirements:
-            - The payment due date, paid date or cancel date is the current
-              PaymentFlowHistory date.
-            - The payment was paid/received with different values (eg with
-              discount or surcharges).
-            - The payment was scheduled to be paid/received in the current,
-              but it was not.
-            - The payment was not expected to be paid/received the current date.
+
+        * The payment due date, paid date or cancel date is the current
+          PaymentFlowHistory date.
+        * The payment was paid/received with different values (eg with
+          discount or surcharges).
+        * The payment was scheduled to be paid/received in the current,
+          but it was not.
+        * The payment was not expected to be paid/received the current date.
         """
         date = self.history_date
         query = AND(OR(const.DATE(Payment.q.due_date) == date,
@@ -502,8 +665,10 @@ class PaymentFlowHistory(Domain):
     def _update_balance(self):
         """Updates the balance_expected and balance_real values following this
         rule:
-            - balance_expected: last_day_balance + to_receive - to_pay
-            - balance_real: last_day_balance + received - paid
+
+        * :obj:`.balance_expected`: last_day_balance + to_receive - to_pay
+        * :obj:`.balance_real`: last_day_balance + received - paid
+
         """
         last_day = self.get_last_day_real_balance()
         old_balance_real = self.balance_real
@@ -520,15 +685,14 @@ class PaymentFlowHistory(Domain):
 
     def _update_registers(self, payment, value, accomplished=True):
         """Updates the :class:`PaymentFlowHistory` attributes according to the
-        payment facet, value and if the payment was accomplished or not.
+        :class:`payment <Payment>`, value and if the payment was accomplished or not.
 
         :param payment: the payment that will be registered.
         :param value: the value that will be used to update history
-                      attributes.
+          attributes.
         :param accomplished: indicates if we should update the attributes that
-                             holds information about the accomplished payments
-                             or attributes related to payments that will be
-                             accomplished later.
+          holds information about the accomplished payments or attributes
+          related to payments that will be accomplished later.
         """
         if value > 0:
             payment_qty = 1
@@ -591,7 +755,7 @@ class PaymentFlowHistory(Domain):
         specified, the referente date will be the current date.
 
         :param reference_date: the reference date to use when querying the
-                               next day.
+          next day.
         :param conn: a database connection.
         """
         if reference_date is None:
@@ -609,7 +773,7 @@ class PaymentFlowHistory(Domain):
 
         :param conn: a database connection.
         :param date: the date of the :class:`PaymentFlowHistory` we want to
-                     retrieve or create.
+          retrieve or create.
         """
         if isinstance(date, datetime.datetime):
             date = date.date()
@@ -627,8 +791,7 @@ class PaymentFlowHistory(Domain):
         :param conn: a database connection.
         :param payment: the payment to be added in the registry.
         :param reference_date: the reference date to use when add the payment,
-                               if not specified, the reference will be the
-                               payment due date.
+          if not specified, the reference will be the payment due date.
         """
         if reference_date is None and payment.due_date:
             reference_date = payment.due_date.date()
@@ -644,8 +807,7 @@ class PaymentFlowHistory(Domain):
         :param conn: a database connection.
         :param payment: the paid payment to be added in the registry.
         :param reference_date: the reference date to use when add the paid
-                               payment, if not specified, the reference will
-                               be the current date.
+          payment, if not specified, the reference will be the current date.
         """
         if reference_date is None:
             reference_date = datetime.date.today()
@@ -661,8 +823,7 @@ class PaymentFlowHistory(Domain):
         :param conn: a database connection.
         :param payment: the payment to be removed in the registry.
         :param reference_date: the reference date to use when remove the
-                               payment, if not specified, the reference will
-                               be the payment due date.
+          payment, if not specified, the reference will be the payment due date.
         """
         if reference_date is None:
             reference_date = payment.due_date.date()
@@ -679,8 +840,7 @@ class PaymentFlowHistory(Domain):
         :param conn: a database connection.
         :param payment: the paid payment to be removed in the registry.
         :param reference_date: the reference date to use when remove the paid
-                               payment, if not specified, the reference will
-                               be the current date.
+          payment, if not specified, the reference will be the current date.
         """
         if reference_date is None:
             reference_date = datetime.date.today()
