@@ -35,8 +35,8 @@ from stoqlib.database.orm import const, AND, LEFTJOINOn
 from stoqlib.domain.base import Domain
 from stoqlib.domain.events import (ProductCreateEvent, ProductEditEvent,
                                    ProductRemoveEvent, ProductStockUpdateEvent)
-from stoqlib.domain.person import Person
 from stoqlib.domain.interfaces import IDescribable
+from stoqlib.domain.person import Person
 from stoqlib.exceptions import StockError
 from stoqlib.lib.translation import stoqlib_gettext
 
@@ -148,19 +148,20 @@ class Product(Domain):
     """
 
     sellable = ForeignKey('Sellable')
-    suppliers = MultipleJoin('ProductSupplierInfo')
+    suppliers = MultipleJoin('ProductSupplierInfo', 'product_id')
     consignment = BoolCol(default=False)
 
     # Production
     is_composed = BoolCol(default=False)
     location = UnicodeCol(default='')
-    manufacturer = UnicodeCol(default='')
+    manufacturer = ForeignKey('ProductManufacturer', default=None)
+    model = UnicodeCol(default='')
     part_number = UnicodeCol(default='')
     width = DecimalCol(default=0)
     height = DecimalCol(default=0)
     depth = DecimalCol(default=0)
     weight = DecimalCol(default=0)
-    quality_tests = MultipleJoin('ProductQualityTest')
+    quality_tests = MultipleJoin('ProductQualityTest', 'product_id')
     production_time = IntCol(default=1)
 
     # Tax details
@@ -314,6 +315,7 @@ class Product(Domain):
 
     def get_production_cost(self):
         """ Return the production cost of one unit of the Product.
+
         :returns: the production cost
         """
         return self.sellable.cost
@@ -331,7 +333,7 @@ class Product(Domain):
 
         :param product: a possible component of this product
         :returns: True if the given product is one of our component or a
-        component of our components, otherwise False.
+          component of our components, otherwise False.
         """
         for component in self.get_components():
             if product is component.component:
@@ -363,6 +365,33 @@ class Product(Domain):
         self._emitted_trans_list = emitted_trans_list
 
 
+class ProductManufacturer(Domain):
+    """Product manufacturer.
+
+    :attribute name: manufacturer's name
+    """
+
+    implements(IDescribable)
+
+    name = UnicodeCol(unique=True)
+
+    #
+    # IDescribable
+    #
+
+    def get_description(self):
+        return self.name
+
+    def can_remove(self):
+        """ Check if the manufacturer is used in some product."""
+        return not Product.selectBy(manufacturer=self,
+                                    connection=self.get_connection()).count()
+
+    def remove(self):
+        """Remove this registry from the database."""
+        self.delete(self.id, self.get_connection())
+
+
 class ProductHistory(Domain):
     """Stores product history, such as sold, received, transfered and
     decreased quantities.
@@ -534,6 +563,7 @@ class Storable(Domain):
     def increase_stock(self, quantity, branch, unit_cost=None):
         """When receiving a product, update the stock reference for this new
         item on a specific branch company.
+
         :param quantity: amount to increase
         :param branch: a branch
         :param cost: optional parameter indicating the unit cost of the new
@@ -574,6 +604,7 @@ class Storable(Domain):
         """When receiving a product, update the stock reference for the sold item
         this on a specific branch company. Returns the stock item that was
         decreased.
+
         :param quantity: amount to decrease
         :param branch: a branch
         """
@@ -606,6 +637,7 @@ class Storable(Domain):
 
     def get_balance_for_branch(self, branch):
         """Return the stock balance for the product in a branch.
+
         :param branch: the branch to get the stock balance for
         :returns: the amount of stock available in the branch
         """
@@ -617,6 +649,7 @@ class Storable(Domain):
 
     def get_stock_items(self):
         """Fetches the stock items available for all branches.
+
         :returns: a sequence of stock items
         """
         return ProductStockItem.selectBy(storable=self,
@@ -624,6 +657,7 @@ class Storable(Domain):
 
     def get_stock_item(self, branch):
         """Fetch a stock item for a specific branch
+
         :returns: a stock item
         """
         return ProductStockItem.selectOneBy(branch=branch,
@@ -697,3 +731,10 @@ class ProductQualityTest(Domain):
         else:
             a, b = self.get_range_value()
             return a <= value <= b
+
+    def can_remove(self):
+        from stoqlib.domain.production import ProductionItemQualityResult
+        if ProductionItemQualityResult.selectBy(quality_test=self,
+                    connection=self.get_connection()).count():
+            return False
+        return True
