@@ -26,7 +26,7 @@
 
 from kiwi.component import get_utility
 
-from stoqlib.database.orm import (orm_name, UnicodeCol, ForeignKey,
+from stoqlib.database.orm import (UnicodeCol, ForeignKey,
                                   MultipleJoin, BoolCol)
 from stoqlib.domain.base import Domain
 from stoqlib.lib.interfaces import IApplicationDescriptions
@@ -61,10 +61,7 @@ class UserProfile(Domain):
     """User profile definition."""
 
     name = UnicodeCol()
-    if orm_name == 'storm':
-        profile_settings = MultipleJoin('ProfileSettings', 'user_profileID')
-    else:
-        profile_settings = MultipleJoin('ProfileSettings')
+    profile_settings = MultipleJoin('ProfileSettings', 'user_profile_id')
 
     @classmethod
     def create_profile_template(cls, conn, name,
