@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2009 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2005-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -21,20 +21,23 @@
 ##
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
-""" Sale object and related objects implementation """
+"""
+Domain objects related to the sale process in Stoq.
+
+Sale object and related objects implementation """
 
 import datetime
 from decimal import Decimal
 
 from kiwi.argcheck import argcheck
-from kiwi.datatypes import currency
+from kiwi.currency import currency
 from kiwi.python import Settable
 from stoqdrivers.enum import TaxType
 from zope.interface import implements
 
 from stoqlib.database.orm import (ForeignKey, UnicodeCol, DateTimeCol, IntCol,
                                   PriceCol, QuantityCol, MultipleJoin)
-from stoqlib.database.orm import AND, const
+from stoqlib.database.orm import AND, const, Field
 from stoqlib.database.orm import Viewable, Alias, LEFTJOINOn, INNERJOINOn
 from stoqlib.database.runtime import (get_current_user,
                                       get_current_branch)
@@ -70,34 +73,55 @@ _ = stoqlib_gettext
 
 
 class SaleItem(Domain):
-    """An item in a sale.
+    """An item of a :class:`sellable <stoqlib.domain.sellable.Sellable>`
+    within a :class:`sale <Sale>`.
 
-    :param sellable: the kind of item
-    :param sale: the same
-    :param quantity: the quantity of the of sold item in this sale
-    :param price: the price of each individual item
-    :param base_price: original value the *product* had when adding the
-                       sale item
-    :param notes:
-    :param estimated_fix_date:
-    :param completion_date:
+    Different from :class:`sellable <stoqlib.domain.sellable.Sellable>`
+    which contains information about the base price, tax, etc, this
+    contains the price in which *self* was sold, it's taxes, the
+    quantity, etc.
     """
+
+    #: the quantity of the of sold item in this sale
     quantity = QuantityCol()
+
+    #: original value the :class:`sellable <stoqlib.domain.sellable.Sellable>`
+    # had when adding the sale item
     base_price = PriceCol()
+
+    #: averiage cost of the items in this item
     average_cost = PriceCol(default=0)
+
+    #: price of this item
     price = PriceCol()
+
+    #: :class:`sale <Sale>` for this item
     sale = ForeignKey('Sale')
+
+    #: :class:`sellable <stoqlib.domain.sellable.Sellable>` for this item
     sellable = ForeignKey('Sellable')
+
+    #: :class:`delivery <Delivery>` or None
     delivery = ForeignKey('Delivery', default=None)
+
+    #: :class:`fiscal entry <stoqlib.domain.fiscal.CfopData>`
     cfop = ForeignKey('CfopData', default=None)
 
-    # This is currently only used by services
+    #: user defined notes, currently only used by services
     notes = UnicodeCol(default=None)
+
+    #: estimated date that *self* will be fixed, currently
+    #: only used by services
     estimated_fix_date = DateTimeCol(default=datetime.datetime.now)
+
+    # FIXME: This doesn't appear to be used anywhere. Maybe we
+    #        should remove it from the database
     completion_date = DateTimeCol(default=None)
 
-    # Taxes
+    #: the :class:`stoqlib.domain.taxes.SaleItemIcms` tax for *self*
     icms_info = ForeignKey('SaleItemIcms')
+
+    #: the :class:`stoqlib.domain.taxes.SaleItemIpi` tax for *self*
     ipi_info = ForeignKey('SaleItemIpi')
 
     def _create(self, id, **kw):
@@ -162,6 +186,11 @@ class SaleItem(Domain):
         return self.sellable.get_description()
 
     def is_service(self):
+        """If this sale item contains a
+        :class:`service <stoqlib.domain.service.Service>`
+
+        :returns: ``True`` if it's a service
+        """
         service = Service.selectOneBy(sellable=self.sellable,
                                       connection=self.get_connection())
         return service is not None
@@ -171,22 +200,30 @@ class SaleItem(Domain):
 
         If the sale was also printed on a coupon, then we cannot add icms
         details to the NF-e (or at least, we should modify then accordingly)
+
+        :returns: the :class:`icms info <stoqlib.domain.taxes.SaleItemIcms>`
+            or *None*, if a coupon has been printed for this Sale
         """
-        # If the sale was printed on a
         if self.sale.coupon_id:
             return None
 
         return self.icms_info
 
     def get_nfe_ipi_info(self):
+        """IPI details for this SaleItem
+
+        :returns: the :class:`ipi info <stoqlib.domain.taxes.SaleItemIpip>`
+        """
         return self.ipi_info
 
     def get_nfe_cfop_code(self):
         """Returns the cfop code to be used on the NF-e
 
         If the sale was also printed on a ECF, then the cfop should be 5.929
-        (if sold to a client in the same state) or 6-929 (if sold to a
-        client on a different state).
+        (if sold to a :class:`client <stoqlib.domain.person.Client>`
+        in the same state) or 6-929 (if sold to a client on a different state).
+
+        :returns: the cfop code
         """
         if self.sale.coupon_id:
             # find out if the client is in the same state as we are.
@@ -211,44 +248,56 @@ class SaleItem(Domain):
 
 
 class Delivery(Domain):
-    """Delivery implementation
+    """Delivery, transporting a set of sale items for sale.
 
-    :cvar STATUS_INITIAL: The delivery was created
-    :cvar STATUS_SENT: The delivery was sent to deliver
-    :cvar STATUS_RECEIVED: The delivery was received by the client
+    Involves a :class:`transporter <stoqlib.domain.person.Transporter>` transporting
+    a set of :class:`sale items <SaleItem>` to a receival
+    :class:`address <stoqlib.domain.address.Address>`.
 
-    :attribute status: the delivery status
-    :attribute open_date: the date which the delivery was created
-    :attribute deliver_date: the date which the delivery sent to deliver
-    :attribute receive_date: the date which the delivery received by
-        the client
-    :attribute tracking_code: the delivery tracking code
-    :attribute address: the delivery address
-    :attribute transporter: the delivery
-        :class:`stoqlib.domain.person.PersonAdaptToTransporter`
-    :attrribute delivery_items: list of :class:`SaleItem` which will
-        be delivered
+    Optionally a :obj:`.tracking_code` can be set to track the items.
     """
 
     implements(IContainer)
 
-    (STATUS_INITIAL,
-     STATUS_SENT,
-     STATUS_RECEIVED) = range(3)
+    #: The delivery was created
+    STATUS_INITIAL = 0
+
+    #: sent to deliver
+    STATUS_SENT = 1
+
+    #: received by the :class:`client <stoqlib.domain.person.Client>`
+    STATUS_RECEIVED = 2
 
     statuses = {STATUS_INITIAL: _("Waiting"),
                 STATUS_SENT: _("Sent"),
                 STATUS_RECEIVED: _("Received")}
 
+    #: the delivery status
     status = IntCol(default=STATUS_INITIAL)
+
+    #: the date which the delivery was created
     open_date = DateTimeCol(default=None)
+
+    #: the date which the delivery sent to deliver
     deliver_date = DateTimeCol(default=None)
+
+    #: the date which the delivery received by the :class:`client <stoqlib.domain.person.Client>`
     receive_date = DateTimeCol(default=None)
+
+    #: the delivery tracking code, a transporter specific identifer that
+    #: can be used to look up the status of the delivery
     tracking_code = UnicodeCol(default='')
+
+    #: the :class:`address <stoqlib.domain.address.Address>` to deliver to
     address = ForeignKey('Address', default=None)
+
+    # :class:`transporter <stoqlib.domain.person.Transporter>` for this delivery
     transporter = ForeignKey('Transporter', default=None)
+
+    #: :class:`sale item <SaleItem>` for the delivery itself
     service_item = ForeignKey('SaleItem', default=None)
 
+    #: :class:`sale items <SaleItem>` for the items to deliver
     delivery_items = MultipleJoin('SaleItem', joinColumn='delivery_id')
 
     #
@@ -321,58 +370,99 @@ class Delivery(Domain):
 
 
 class Sale(Domain, Adaptable):
-    """Sale object implementation.
+    """Sale logic, the process of selling a :class:`sellable <stoqlib.domain.sellable.Sellable>` to a :class:`client <stoqlib.domain.person.Client>`.
+
+    A large part of the payment processing logic is done via
+    the :class:`SaleAdaptToPaymentTransaction` adapter.
+
+    * calculates the sale price including discount/interest/markup
+    * creates payments
+    * decreases the stock for products
+    * creates a delivery (optional)
+    * verifies that the client is suitable
+    * creates commissions to the sales person
+    * add money to the till (if paid with money)
+    * calculate taxes and fiscal book entries
+
+    +----------------------------+----------------------------+
+    | **Status**                 | **Can be set to**          |
+    +----------------------------+----------------------------+
+    | :obj:`STATUS_QUOTE`        | :obj:`STATUS_INITIAL`      |
+    +----------------------------+----------------------------+
+    | :obj:`STATUS_INITIAL`      | :obj:`STATUS_ORDERED`,     |
+    +----------------------------+----------------------------+
+    | :obj:`STATUS_ORDERED`      | :obj:`STATUS_PAID`,        |
+    |                            | :obj:`STATUS_CONFIRMED`    |
+    |                            | :obj:`STATUS_CANCELLED`    |
+    +----------------------------+----------------------------+
+    | :obj:`STATUS_CONFIRMED`    | :obj:`STATUS_PAID`         |
+    |                            | :obj:`STATUS_RENEGOTIATED` |
+    +----------------------------+----------------------------+
+    | :obj:`STATUS_CANCELLED`    | None                       |
+    +----------------------------+----------------------------+
+    | :obj:`STATUS_PAID`         | None                       |
+    +----------------------------+----------------------------+
+    | :obj:`STATUS_RENEGOTIATED` | None                       |
+    +----------------------------+----------------------------+
+    | :obj:`STATUS_RETURNED`     | None                       |
+    +----------------------------+----------------------------+
+
+    .. graphviz::
+
+       digraph sale_status {
+         STATUS_QUOTE -> STATUS_INITIAL;
+         STATUS_INITIAL -> STATUS_ORDERED;
+         STATUS_ORDERED -> STATUS_PAID;
+         STATUS_ORDERED -> STATUS_CONFIRMED;
+         STATUS_ORDERED -> STATUS_CANCELLED;
+         STATUS_CONFIRMED -> STATUS_PAID;
+         STATUS_CONFIRMED -> STATUS_CANCELLED;
+         STATUS_PAID -> STATUS_RETURNED;
+         STATUS_CONFIRMED -> STATUS_RENEGOTIATED;
+       }
 
-    :cvar STATUS_INITIAL: The sale is opened, products or other sellable items
-      might have been added.
-    :cvar STATUS_ORDERED: The sale is orded, it has sellable items but not any
-      payments yet. This state is mainly used when the parameter
-      CONFIRM_SALES_AT_TILL is enabled.
-    :cvar STATUS_CONFIRMED: The sale has been confirmed and all payments
-      have been registered, but not necessarily paid.
-    :cvar STATUS_CLOSED: All the payments of the sale has been confirmed
-      and the client does not owe anything to us.
-    :cvar STATUS_CANCELLED: The sale has been canceled, this can only happen
-      to an sale which has not yet reached the SALE_CONFIRMED status.
-    :cvar STATUS_RETURNED: The sale has been returned, all the payments made
-      have been canceled and the client has been compensated for
-      everything already paid.
-    :cvar CLIENT_INDIVIDUAL: The sale was done by an individual
-    :cvar CLIENT_COMPANY: The sale was done by a company
-    :attribute status: status of the sale
-    :attribute client: who we sold the sale to
-    :attribute salesperson: who sold the sale
-    :attribute branch: branch where the sale was done
-    :attribute till: The Till operation where this sale lives. Note that every
-       sale and payment generated are always in a till operation
-       which defines a financial history of a store.
-    :attribute open_date: the date sale was created
-    :attribute close_date: the date sale was closed
-    :attribute confirm_date: the date sale was confirmed
-    :attribute cancel_date: the date sale was cancelled
-    :attribute return_date: the date sale was returned
-    :attribute discount_value:
-    :attribute surcharge_value:
-    :attribute total_amount: the total value of all the items in the same
-    :attribute notes: Some optional additional information related to this sale.
-    :attribute coupon_id: the id of the coupon printed by the ECF.
-    :attribute service_invoice_number:
-    :attribute cfop:
-    :attribute invoice_number: the sale invoice number.
-    :attribute client_category: The :class:`ClientCategory` that was used for price
-        determination.
     """
 
     implements(IContainer)
 
-    (STATUS_INITIAL,
-     STATUS_CONFIRMED,
-     STATUS_PAID,
-     STATUS_CANCELLED,
-     STATUS_ORDERED,
-     STATUS_RETURNED,
-     STATUS_QUOTE,
-     STATUS_RENEGOTIATED) = range(8)
+    #: The sale is opened, products or other
+    #: :class:`sellable <stoqlib.domain.sellable.Sellable>` items might have
+    #: been added.
+    STATUS_INITIAL = 0
+
+    #: The sale has been confirmed and all payments have been registered,
+    #: but not necessarily paid.
+    STATUS_CONFIRMED = 1
+
+    #: All the payments of the sale has been confirmed and
+    #: the :class:`client <stoqlib.domain.person.Client>` does not owe
+    #: anything to us. The product stock has been decreased and the items
+    #: delivered.
+    STATUS_PAID = 2
+
+    #: The sale has been canceled, this can only happen
+    #: to an sale which has not yet reached the SALE_CONFIRMED status.
+    STATUS_CANCELLED = 3
+
+    #: The sale is orded, it has sellable items but not any payments yet.
+    #: This state is mainly used when the parameter CONFIRM_SALES_AT_TILL
+    #: is enabled.
+    STATUS_ORDERED = 4
+
+    #: The sale has been returned, all the payments made
+    #: have been canceled and the
+    #: :class:`client <stoqlib.domain.person.Client>` has been compensated for
+    #: everything already paid.
+    STATUS_RETURNED = 5
+
+    #: When asking for sale quote this is the initial state that is set before
+    #: reaching the initial state
+    STATUS_QUOTE = 6
+
+    #: A sale that is closed as renegotiated, all payments for this sale
+    #: should be canceled at list point. Another new sale is created with
+    #: the new, renegotiated payments.
+    STATUS_RENEGOTIATED = 7
 
     statuses = {STATUS_INITIAL: _(u'Opened'),
                 STATUS_CONFIRMED: _(u'Confirmed'),
@@ -383,28 +473,87 @@ class Sale(Domain, Adaptable):
                 STATUS_RENEGOTIATED: _(u'Renegotiated'),
                 STATUS_QUOTE: _(u'Quoting')}
 
+    #: status of the sale
     status = IntCol(default=STATUS_INITIAL)
+
+    # FIXME: this doesn't really belong to the sale
+    #: identifier for the coupon of this sale, used by a ECF printer
     coupon_id = IntCol()
+
+    # FIXME: This doesn't appear to be used anywhere.
+    #        Maybe we should remove it from the database.
     service_invoice_number = IntCol(default=None)
+
+    #: Some optional additional information related to this sale.
     notes = UnicodeCol(default='')
+
+    #: the date sale was created, this is always set
     open_date = DateTimeCol(default=datetime.datetime.now)
+
+    #: the date sale was confirmed, or None if it hasn't been confirmed
     confirm_date = DateTimeCol(default=None)
+
+    #: the date sale was paid, or None if it hasn't be paid
     close_date = DateTimeCol(default=None)
+
+    #: the date sale was confirmed, or None if it hasn't been cancelled
     cancel_date = DateTimeCol(default=None)
+
+    #: the date sale was confirmed, or None if it hasn't been returned
     return_date = DateTimeCol(default=None)
+
+    #: date when this sale expires, used by quotes
     expire_date = DateTimeCol(default=None)
+
+    #: discount of the sale, in absolute value, for instance::
+    #:
+    #:    sale.total_sale_amount = 150
+    #:    sale.discount_value = 18
+    #:    # the price of the sale will now be 132
+    #:
     discount_value = PriceCol(default=0)
+
+    #: surcharge of the sale, in absolute value, for instance::
+    #:
+    #:    sale.total_sale_amount = 150
+    #:    sale.surcharge_value = 18
+    #:    # the price of the sale will now be 168
+    #:
     surcharge_value = PriceCol(default=0)
+
+    #: the total value of all the items in the same, this is set when
+    #: a sale is confirmed, this is the same as calling
+    #: :obj:`Sale.get_total_sale_amount()` at the time of confirming the sale,
     total_amount = PriceCol(default=0)
+
+    #: invoice number for this sale, appears on bills etc.
     invoice_number = IntCol(default=None)
     operation_nature = UnicodeCol(default='')
+
+    #: the :class:`fiscal entry <stoqlib.domain.fiscal.CfopData>`
     cfop = ForeignKey("CfopData")
+
+    #: :class:`client <stoqlib.domain.person.Client>` who this sale was sold to
     client = ForeignKey('Client', default=None)
+
+    #: :class:`sales person <stoqlib.domain.person.SalesPerson>`
+    #: who sold the sale
     salesperson = ForeignKey('SalesPerson')
+
+    #: :class:`branch <stoqlib.domain.person.Branch>` this sale belongs to
     branch = ForeignKey('Branch', default=None)
+
     # FIXME: transporter should only be used on Delivery.
+    #: :class:`transporter <stoqlib.domain.person.Transporter>` transporting
+    #: this sale, in case of a delivery
     transporter = ForeignKey('Transporter', default=None)
+
+    #: the :class:`payment group <stoqlib.domain.payment.group.PaymentGroup>`
+    #: of this sale
     group = ForeignKey('PaymentGroup')
+
+    #: the :class:`client category <stoqlib.domain.person.ClientCategory>`
+    #: used for price determination.
     client_category = ForeignKey('ClientCategory', default=None)
 
     def __init__(self, *args, **kwargs):
@@ -426,6 +575,7 @@ class Sale(Domain, Adaptable):
 
     @classmethod
     def get_status_name(cls, status):
+        """The :obj:`.status` as a translated string"""
         if not status in cls.statuses:
             raise DatabaseInconsistency(_("Invalid status %d") % status)
         return cls.statuses[status]
@@ -474,33 +624,38 @@ class Sale(Domain, Adaptable):
 
     def can_order(self):
         """Only newly created sales can be ordered
-        :returns: True if the sale can be ordered, otherwise False
+
+        :returns: ``True`` if the sale can be ordered
         """
         return (self.status == Sale.STATUS_INITIAL or
                 self.status == Sale.STATUS_QUOTE)
 
     def can_confirm(self):
         """Only ordered sales can be confirmed
-        :returns: True if the sale can be confirmed, otherwise False
+
+        :returns: ``True`` if the sale can be confirmed
         """
         return (self.status == Sale.STATUS_ORDERED or
                 self.status == Sale.STATUS_QUOTE)
 
     def can_set_paid(self):
         """Only confirmed sales can be paid
-        :returns: True if the sale can be set as paid, otherwise False
+
+        :returns: ``True`` if the sale can be set as paid
         """
         return self.status == Sale.STATUS_CONFIRMED
 
     def can_set_not_paid(self):
         """Only confirmed sales can be paid
-        :returns: True if the sale can be set as paid, otherwise False
+
+        :returns: ``True`` if the sale can be set as paid
         """
         return self.status == Sale.STATUS_PAID
 
     def can_set_renegotiated(self):
         """Only sales with status confirmed can be renegotiated.
-        :returns: True if the sale can be renegotiated, False otherwise.
+
+        :returns: ``True`` if the sale can be renegotiated
         """
         # This should be as simple as:
         # return self.status == Sale.STATUS_CONFIRMED
@@ -510,25 +665,35 @@ class Sale(Domain, Adaptable):
 
     def can_cancel(self):
         """Only ordered, confirmed, paid and quoting sales can be cancelled.
-        :returns: True if the sale can be cancelled, otherwise False
+
+        :returns: ``True`` if the sale can be cancelled
         """
         return self.status in (Sale.STATUS_CONFIRMED, Sale.STATUS_PAID,
                                Sale.STATUS_ORDERED, Sale.STATUS_QUOTE)
 
     def can_return(self):
         """Only confirmed or paid sales can be returned
-        :returns: True if the sale can be returned, otherwise False
+
+        :returns: ``True`` if the sale can be returned
         """
         return (self.status == Sale.STATUS_CONFIRMED or
                 self.status == Sale.STATUS_PAID)
 
+    def can_edit(self):
+        """Only quoting sales can be edited.
+
+        :returns: ``True`` if the sale can be edited
+        """
+        return self.status == Sale.STATUS_QUOTE
+
     def order(self):
         """Orders the sale
 
         Ordering a sale is the first step done after creating it.
         The state of the sale will change to Sale.STATUS_ORDERED.
         To order a sale you need to add sale items to it.
-        A client might also be set for the sale, but it is not necessary.
+        A :class:`client <stoqlib.domain.person.Client>` might also
+        be set for the sale, but it is not necessary.
         """
         assert self.can_order()
 
@@ -632,8 +797,8 @@ class Sale(Domain, Adaptable):
         """Mark a sale as not paid. This happens when the user sets a
         previously paid payment as not paid.
 
-        In this case, if the sale status is PAID, it should be set back to
-        CONFIRMED
+        In this case, if the sale status is :obj:`.STATUS_PAID`,
+        it should be set back to :obj:`.STATUS_CONFIRMED`.
         """
         assert self.can_set_not_paid()
 
@@ -642,7 +807,8 @@ class Sale(Domain, Adaptable):
 
     def set_renegotiated(self):
         """Set the sale as renegotiated. The sale payments have been
-        renegotiated and the operations will be done in other payment group."""
+        renegotiated and the operations will be done in other
+        :class:`payment group <stoqlib.domain.payment.group.PaymentGroup>`."""
         assert self.can_set_renegotiated()
 
         self.close_date = const.NOW()
@@ -651,6 +817,7 @@ class Sale(Domain, Adaptable):
     def cancel(self):
         """Cancel the sale
         You can only cancel an ordered sale.
+        This does not cancel the payments, only the sale items.
         """
         assert self.can_cancel()
 
@@ -703,7 +870,7 @@ class Sale(Domain, Adaptable):
 
     def get_total_sale_amount(self):
         """
-        Fetches the total value  paid by the client.
+        Fetches the total value  paid by the :class:`client <stoqlib.domain.person.Client>`.
         It can be calculated as::
 
             Sale total = Sum(product and service prices) + surcharge +
@@ -719,7 +886,8 @@ class Sale(Domain, Adaptable):
 
     def get_sale_subtotal(self):
         """Fetch the subtotal for the sale, eg the sum of the
-        prices for of all items
+        prices for of all items.
+
         :returns: subtotal
         """
         total = 0
@@ -730,6 +898,7 @@ class Sale(Domain, Adaptable):
 
     def get_items_total_quantity(self):
         """Fetches the total number of items in the sale
+
         :returns: number of items
         """
         return self.get_items().sum('quantity') or Decimal(0)
@@ -738,6 +907,7 @@ class Sale(Domain, Adaptable):
         """Returns the sale details. The details are composed by the sale
         notes, the items notes, the delivery address and the estimated fix
         date.
+
         :returns: the sale details string.
         """
         details = []
@@ -770,18 +940,29 @@ class Sale(Domain, Adaptable):
         return u'%05d' % self.id
 
     def get_salesperson_name(self):
+        """
+        :returns: the sales person name
+        """
         return self.salesperson.get_description()
 
     def get_client_name(self):
+        """Returns the client name, if a
+        :class:`client <stoqlib.domain.person.Client>` has been provided for
+        this sale
+
+        :returns: the client name of a place holder string for sales without
+           clients set.
+        """
         if not self.client:
             return _(u'Not Specified')
         return self.client.get_name()
 
+    # FIXME: move over to client or person
     def get_client_role(self):
         """Fetches the client role
 
-        :returns: the client role (a Individual or a
-        Company) instance or None if the sale haven't a client.
+        :returns: the client role (a Individual or a Company) instance or
+          None if the sale haven't a :class:`client <stoqlib.domain.person.Client>`.
         """
         if not self.client:
             return None
@@ -797,8 +978,8 @@ class Sale(Domain, Adaptable):
 
     def only_paid_with_money(self):
         """Find out if the sale is paid using money
-        :returns: True if the sale was paid with money, otherwise False
-        :rtype: bool
+
+        :returns: ``True`` if the sale was paid with money
         """
         if not self.payments:
             return False
@@ -810,11 +991,15 @@ class Sale(Domain, Adaptable):
                 payment.pay()
 
     def add_sellable(self, sellable, quantity=1, price=None):
-        """Adds a new sellable item to a sale
+        """Adds a new :class:`sellable <stoqlib.domain.sellable.Sellable>`
+        item to a sale
+
         :param sellable: the sellable
         :param quantity: quantity to add, defaults to 1
         :param price: optional, the price, it not set the price
           from the sellable will be used
+        :returns: a :class:`sale item <SaleItem>` for representing the
+          sellable within this sale.
         """
         price = price or sellable.price
         return SaleItem(connection=self.get_connection(),
@@ -844,6 +1029,9 @@ class Sale(Domain, Adaptable):
 
     @property
     def products(self):
+        """All :class:`sale items <SaleItem>` of this sale that contain
+        :class:`products <stoqlib.domain.product.Product>`.
+        """
         return SaleItem.select(
             AND(SaleItem.q.saleID == self.id,
                 SaleItem.q.sellableID == Product.q.sellableID),
@@ -851,6 +1039,9 @@ class Sale(Domain, Adaptable):
 
     @property
     def services(self):
+        """All :class:`sale items <SaleItem>` of this sale that contain
+        :class:`services <stoqlib.domain.service.Service>`.
+        """
         return SaleItem.select(
             AND(SaleItem.q.saleID == self.id,
                 SaleItem.q.sellableID == Service.q.sellableID),
@@ -861,10 +1052,12 @@ class Sale(Domain, Adaptable):
         """Returns all valid payments for this sale
 
         This will return a list of valid payments for this sale, that
-        is, all payments on the payment group that were not cancelled.
-        If you need to get the cancelled too, use self.group.payments.
+        is, all payments on the
+        :class:`payment group <stoqlib.domain.payment.group.PaymentGroup>`
+        that were not cancelled.
+        If you need to get the cancelled too, use :obj:`.group.payments`.
 
-        :returns: a list of :class:`stoqlib.domain.payment.payment.Payment`
+        :returns: a list of :class:`~stoqlib.domain.payment.payment.Payment`
         """
         return self.group.get_valid_payments()
 
@@ -886,9 +1079,13 @@ class Sale(Domain, Adaptable):
                                    _set_discount_by_percentage,
                                    doc=(
         """Sets a discount by percentage.
-        Note that percentage must be added as an absolute value not as a
-        factor like 1.05 = 5 % of surcharge
-        The correct form is 'percentage = 3' for a discount of 3 %"""
+        Note that percentage must be added as an absolute value, in other
+        words::
+
+            sale.total_sale_amount = 200
+            sale.discount_percentage = 5
+            # the price of the sale will now be be `190`
+        """
         ))
 
     def _get_surcharge_by_percentage(self):
@@ -908,10 +1105,15 @@ class Sale(Domain, Adaptable):
     surcharge_percentage = property(_get_surcharge_by_percentage,
                                     _set_surcharge_by_percentage,
                                     doc=(
-        """Sets a surcharge by percentage.
-        Note that surcharge must be added as an absolute value not as a
-        factor like 0.97 = 3 % of discount.
-        The correct form is 'percentage = 3' for a surcharge of 3 %"""
+        """Sets a discount by percentage.
+        Note that percentage must be added as an absolute value, in other
+        words::
+
+            sale.total_sale_amount = 200
+            sale.surcharge_percentage = 5
+            # the price of the sale will now be `210`
+
+        """
         ))
 
     #
@@ -1193,6 +1395,20 @@ Sale.registerFacet(SaleAdaptToPaymentTransaction, IPaymentTransaction)
 # Views
 #
 
+class _SaleItemSummary(Viewable):
+    columns = dict(
+        id=SaleItem.q.saleID,
+        v_ipi=const.SUM(SaleItemIpi.q.v_ipi),
+        total_quantity=const.SUM(SaleItem.q.quantity),
+        subtotal=const.SUM(SaleItem.q.quantity * SaleItem.q.price),
+    )
+
+    joins = [
+        LEFTJOINOn(None, SaleItemIpi,
+                   SaleItemIpi.q.id == SaleItem.q.ipi_infoID),
+    ]
+
+
 class SaleView(Viewable):
     """Stores general informatios about sales
 
@@ -1206,7 +1422,7 @@ class SaleView(Viewable):
     :cvar status: the sale status
     :cvar salesperson_name: the salesperson name
     :cvar client_name: the sale client name
-    :cvar client_id: the if of the client table
+    :cvar client_id: the if of the :class:`client <stoqlib.domain.person.Client>` table
     :cvar subtotal: the sum of all items in the sale
     :cvar surcharge_value: the sale surcharge value
     :cvar discount_value: the sale discount value
@@ -1217,6 +1433,7 @@ class SaleView(Viewable):
 
     Person_Client = Alias(Person, 'person_client')
     Person_SalesPerson = Alias(Person, 'person_sales_person')
+    SaleItemSummary = Alias(_SaleItemSummary, '_sale_item')
 
     columns = dict(
         id=Sale.q.id,
@@ -1235,17 +1452,16 @@ class SaleView(Viewable):
         client_id=Client.q.id,
         salesperson_name=Person_SalesPerson.q.name,
         client_name=Person_Client.q.name,
-        v_ipi=const.SUM(SaleItemIpi.q.v_ipi),
-        total_quantity=const.SUM(SaleItem.q.quantity),
-        subtotal=const.SUM(SaleItem.q.quantity * SaleItem.q.price),
-        total=const.SUM(SaleItem.q.price * SaleItem.q.quantity) - \
+        v_ipi=Field('_sale_item', 'v_ipi'),
+        subtotal=Field('_sale_item', 'subtotal'),
+        total_quantity=Field('_sale_item', 'total_quantity'),
+        total=Field('_sale_item', 'subtotal') - \
               Sale.q.discount_value + Sale.q.surcharge_value
     )
 
     joins = [
-        INNERJOINOn(None, SaleItem,
-                    Sale.q.id == SaleItem.q.saleID),
-
+        INNERJOINOn(None, SaleItemSummary,
+                    Field('_sale_item', 'id') == Sale.q.id),
         LEFTJOINOn(None, Client,
                    Sale.q.clientID == Client.q.id),
         LEFTJOINOn(None, SalesPerson,
@@ -1255,9 +1471,6 @@ class SaleView(Viewable):
                    Client.q.personID == Person_Client.q.id),
         LEFTJOINOn(None, Person_SalesPerson,
                    SalesPerson.q.personID == Person_SalesPerson.q.id),
-
-        LEFTJOINOn(None, SaleItemIpi,
-                   SaleItemIpi.q.id == SaleItem.q.ipi_infoID),
     ]
 
     #
