@@ -31,7 +31,7 @@ from zope.interface import implements
 from stoqlib.database.orm import ForeignKey, UnicodeCol, DateTimeCol, IntCol
 from stoqlib.database.orm import QuantityCol
 from stoqlib.domain.base import Domain
-from stoqlib.domain.interfaces import IContainer, IStorable
+from stoqlib.domain.interfaces import IContainer
 from stoqlib.domain.product import ProductHistory
 from stoqlib.exceptions import DatabaseInconsistency
 from stoqlib.lib.translation import stoqlib_gettext
@@ -47,9 +47,9 @@ _ = stoqlib_gettext
 class StockDecreaseItem(Domain):
     """An item in a stock decrease object.
 
-    @param sellable: the kind of item
-    @param stock_decrease: the same
-    @param quantity: the quantity decreased for this item
+    :param sellable: the kind of item
+    :param stock_decrease: the same
+    :param quantity: the quantity decreased for this item
     """
     stock_decrease = ForeignKey('StockDecrease', default=None)
     sellable = ForeignKey('Sellable')
@@ -64,7 +64,7 @@ class StockDecreaseItem(Domain):
     def decrease(self, branch):
         assert branch
 
-        storable = IStorable(self.sellable.product, None)
+        storable = self.sellable.product_storable
         if storable:
             storable.decrease_stock(self.quantity, branch)
 
@@ -86,14 +86,14 @@ class StockDecrease(Domain):
     quantity, for some reason that is not a sale, transfer or other cases
     already covered in stoqlib.
 
-    @cvar STATUS_INITIAL: Stock Decrease is still being edited
-    @cvar STATUS_CONFIRMED: Stock Decrease is confirmed and stock items have
+    :cvar STATUS_INITIAL: Stock Decrease is still being edited
+    :cvar STATUS_CONFIRMED: Stock Decrease is confirmed and stock items have
                             been decreased.
-    @ivar status: status of the sale
-    @ivar responsible: who should be blamed for this
-    @ivar branch: branch where the sale was done
-    @ivar confirm_date: the date sale was created
-    @ivar notes: Some optional additional information related to this sale.
+    :attribute status: status of the sale
+    :attribute responsible: who should be blamed for this
+    :attribute branch: branch where the sale was done
+    :attribute confirm_date: the date sale was created
+    :attribute notes: Some optional additional information related to this sale.
     """
 
     implements(IContainer)
@@ -108,9 +108,9 @@ class StockDecrease(Domain):
     reason = UnicodeCol(default='')
     notes = UnicodeCol(default='')
     confirm_date = DateTimeCol(default=datetime.datetime.now)
-    responsible = ForeignKey('PersonAdaptToUser')
-    removed_by = ForeignKey('PersonAdaptToEmployee')
-    branch = ForeignKey('PersonAdaptToBranch', default=None)
+    responsible = ForeignKey('LoginUser')
+    removed_by = ForeignKey('Employee')
+    branch = ForeignKey('Branch', default=None)
     cfop = ForeignKey('CfopData')
 
     #
@@ -140,7 +140,7 @@ class StockDecrease(Domain):
 
     def can_confirm(self):
         """Only ordered sales can be confirmed
-        @returns: True if the sale can be confirmed, otherwise False
+        :returns: True if the sale can be confirmed, otherwise False
         """
         return self.status == StockDecrease.STATUS_INITIAL
 
@@ -190,8 +190,8 @@ class StockDecrease(Domain):
     def add_sellable(self, sellable, quantity=1):
         """Adds a new sellable item to a stock decrease
 
-        @param sellable: the sellable
-        @param quantity: quantity to add, defaults to 1
+        :param sellable: the sellable
+        :param quantity: quantity to add, defaults to 1
         """
         return StockDecreaseItem(connection=self.get_connection(),
                                  quantity=quantity,
