@@ -47,8 +47,15 @@ class BaseTax(Domain):
             return
 
         for column in template.sqlmeta.columnList:
-            if column.name in ('te_createdID', 'te_modifiedID',
-                               'product_tax_templateID'):
+            if column.name in [
+                'product_tax_template_id',
+                'te_created_id',
+                'te_modified_id',
+                # FIXME: SQLObject only, remove post storm migration
+                'te_createdID',
+                'te_modifiedID',
+                'product_tax_templateID',
+                ]:
                 continue
 
             value = getattr(template, column.name)
@@ -171,7 +178,7 @@ class SaleItemIcms(BaseICMS):
     v_icms_st_ret = PriceCol(default=None)
 
     def _calc_cred_icms_sn(self, sale_item):
-        if self.p_cred_sn > 0:
+        if self.p_cred_sn >= 0:
             self.v_cred_icms_sn = sale_item.get_total() * self.p_cred_sn / 100
 
     def _calc_st(self, sale_item):
@@ -245,6 +252,8 @@ class SaleItemIcms(BaseICMS):
             self.v_icms_st_ret = 0
 
         if self.csosn in [101, 201]:
+            if self.p_cred_sn is None:
+                self.p_cred_sn = Decimal(0)
             self._calc_cred_icms_sn(sale_item)
 
     def update_values(self):
