@@ -23,7 +23,8 @@
 ##
 
 from stoqlib.domain.account import (Account, AccountTransaction,
-                                    AccountTransactionView)
+                                    AccountTransactionView,
+                                    BillOption)
 from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.domain.interfaces import IDescribable
 from stoqlib.exceptions import PaymentError
@@ -132,6 +133,15 @@ class TestAccount(DomainTest):
         self.assertEquals(t1.account, imbalance_account)
         self.assertEquals(t2.source_account, imbalance_account)
 
+    def testAccountRemoveWithBankAccount(self):
+        account = self.create_account()
+        bank = self.create_bank_account(account=account)
+        BillOption(option='foo',
+                   value='bar',
+                   bank_account=bank,
+                   connection=self.trans)
+        account.remove(self.trans)
+
     def testHasChildAccounts(self):
         a1 = self.create_account()
         a2 = self.create_account()
@@ -213,7 +223,7 @@ class TestAccountTransaction(DomainTest):
     def testCreateFromPayment(self):
         sale = self.create_sale()
         self.add_product(sale)
-        payment = self.add_payments(sale, method_type='check').payment
+        payment = self.add_payments(sale, method_type='check')
         sale.order()
         sale.confirm()
         account = self.create_account()
