@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2006-2007 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2006-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -23,20 +23,23 @@
 ##
 """ This module test all class in stoqlib/domain/product.py """
 
-import decimal
+from decimal import Decimal
+import datetime
 
+# Import domaintest first so that externals is setup properly
+from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.database.runtime import get_current_branch, new_transaction
 from stoqlib.domain.events import (ProductCreateEvent, ProductEditEvent,
                                    ProductRemoveEvent)
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.product import (ProductSupplierInfo, Product,
                                     ProductHistory, ProductComponent,
-                                    Storable)
+                                    ProductQualityTest, Storable)
+from stoqlib.domain.production import (ProductionProducedItem,
+                                       ProductionItemQualityResult)
 from stoqlib.domain.purchase import PurchaseOrder
 from stoqlib.domain.sellable import Sellable
 
-from stoqlib.domain.test.domaintest import DomainTest
-
 
 class TestProductSupplierInfo(DomainTest):
 
@@ -380,10 +383,6 @@ class TestProductHistory(DomainTest):
         self.assertEqual(prod_hist.quantity_transfered, qty)
 
 
-from stoqlib.domain.product import ProductQualityTest
-from decimal import Decimal
-
-
 class TestProductQuality(DomainTest):
 
     def test_quality_tests(self):
@@ -455,6 +454,32 @@ class TestProductQuality(DomainTest):
 
         self.assertRaises(AssertionError, test.get_boolean_value)
 
+    def test_can_remove(self):
+        product = self.create_product()
+        test = ProductQualityTest(connection=self.trans, product=product)
+
+        # Test has never been used
+        self.assertTrue(test.can_remove())
+
+        order = self.create_production_order()
+        user = self.create_user()
+        item = ProductionProducedItem(product=product,
+                                      order=order,
+                                      produced_by=user,
+                                      produced_date=datetime.date.today(),
+                                      serial_number=1,
+                                      connection=self.trans)
+        self.assertTrue(test.can_remove())
+
+        # Test has been used in a production
+        ProductionItemQualityResult(produced_item=item,
+                                    quality_test=test,
+                                    tested_by=user,
+                                    result_value='True',
+                                    test_passed=True,
+                                    connection=self.trans)
+        self.assertFalse(test.can_remove())
+
 
 class TestProductEvent(DomainTest):
     def testCreateEvent(self):
@@ -464,96 +489,98 @@ class TestProductEvent(DomainTest):
         ProductEditEvent.connect(p_data.on_edit)
         ProductRemoveEvent.connect(p_data.on_delete)
 
-        # Test product being created
-        trans = new_transaction()
-        trans_list.append(trans)
-        sellable = Sellable(
-            connection=trans,
-            description='Test 1234',
-            price=decimal.Decimal(2),
-            )
-        product = Product(
-            connection=trans,
-            sellable=sellable,
-            )
-        trans.commit()
-        self.assertTrue(p_data.was_created)
-        self.assertFalse(p_data.was_edited)
-        self.assertFalse(p_data.was_deleted)
-        self.assertEqual(p_data.product, product)
-        p_data.reset()
+        try:
+            # Test product being created
+            trans = new_transaction()
+            trans_list.append(trans)
+            sellable = Sellable(
+                connection=trans,
+                description='Test 1234',
+                price=Decimal(2),
+                )
+            product = Product(
+                connection=trans,
+                sellable=sellable,
+                )
+            trans.commit()
+            self.assertTrue(p_data.was_created)
+            self.assertFalse(p_data.was_edited)
+            self.assertFalse(p_data.was_deleted)
+            self.assertEqual(p_data.product, product)
+            p_data.reset()
 
-        # Test product being edited and emmiting the event just once
-        trans = new_transaction()
-        trans_list.append(trans)
-        sellable = trans.get(sellable)
-        product = trans.get(product)
-        sellable.notes = 'Notes'
-        sellable.description = 'Test 666'
-        product.weight = decimal.Decimal(10)
-        trans.commit()
-        self.assertTrue(p_data.was_edited)
-        self.assertFalse(p_data.was_created)
-        self.assertFalse(p_data.was_deleted)
-        self.assertEqual(p_data.product, product)
-        self.assertEqual(p_data.emmit_count, 1)
-        p_data.reset()
+            # Test product being edited and emmiting the event just once
+            trans = new_transaction()
+            trans_list.append(trans)
+            sellable = trans.get(sellable)
+            product = trans.get(product)
+            sellable.notes = 'Notes'
+            sellable.description = 'Test 666'
+            product.weight = Decimal(10)
+            trans.commit()
+            self.assertTrue(p_data.was_edited)
+            self.assertFalse(p_data.was_created)
+            self.assertFalse(p_data.was_deleted)
+            self.assertEqual(p_data.product, product)
+            self.assertEqual(p_data.emmit_count, 1)
+            p_data.reset()
 
-        # Test product being edited, editing Sellable
-        trans = new_transaction()
-        trans_list.append(trans)
-        sellable = trans.get(sellable)
-        product = trans.get(product)
-        sellable.notes = 'Notes for test'
-        trans.commit()
-        self.assertTrue(p_data.was_edited)
-        self.assertFalse(p_data.was_created)
-        self.assertFalse(p_data.was_deleted)
-        self.assertEqual(p_data.product, product)
-        self.assertEqual(p_data.emmit_count, 1)
-        p_data.reset()
+            # Test product being edited, editing Sellable
+            trans = new_transaction()
+            trans_list.append(trans)
+            sellable = trans.get(sellable)
+            product = trans.get(product)
+            sellable.notes = 'Notes for test'
+            trans.commit()
+            self.assertTrue(p_data.was_edited)
+            self.assertFalse(p_data.was_created)
+            self.assertFalse(p_data.was_deleted)
+            self.assertEqual(p_data.product, product)
+            self.assertEqual(p_data.emmit_count, 1)
+            p_data.reset()
 
-        # Test product being edited, editing Product itself
-        trans = new_transaction()
-        trans_list.append(trans)
-        sellable = trans.get(sellable)
-        product = trans.get(product)
-        product.weight = decimal.Decimal(1)
-        trans.commit()
-        self.assertTrue(p_data.was_edited)
-        self.assertFalse(p_data.was_created)
-        self.assertFalse(p_data.was_deleted)
-        self.assertEqual(p_data.product, product)
-        self.assertEqual(p_data.emmit_count, 1)
-        p_data.reset()
+            # Test product being edited, editing Product itself
+            trans = new_transaction()
+            trans_list.append(trans)
+            sellable = trans.get(sellable)
+            product = trans.get(product)
+            product.weight = Decimal(1)
+            trans.commit()
+            self.assertTrue(p_data.was_edited)
+            self.assertFalse(p_data.was_created)
+            self.assertFalse(p_data.was_deleted)
+            self.assertEqual(p_data.product, product)
+            self.assertEqual(p_data.emmit_count, 1)
+            p_data.reset()
 
-        # Test product being edited, editing Product itself
-        trans = new_transaction()
-        trans_list.append(trans)
-        sellable = trans.get(sellable)
-        product = trans.get(product)
-        product.weight = decimal.Decimal(1)
-        trans.commit()
-        self.assertTrue(p_data.was_edited)
-        self.assertFalse(p_data.was_created)
-        self.assertFalse(p_data.was_deleted)
-        self.assertEqual(p_data.product, product)
-        self.assertEqual(p_data.emmit_count, 1)
-        p_data.reset()
+            # Test product being edited, editing Product itself
+            trans = new_transaction()
+            trans_list.append(trans)
+            sellable = trans.get(sellable)
+            product = trans.get(product)
+            product.weight = Decimal(1)
+            trans.commit()
+            self.assertTrue(p_data.was_edited)
+            self.assertFalse(p_data.was_created)
+            self.assertFalse(p_data.was_deleted)
+            self.assertEqual(p_data.product, product)
+            self.assertEqual(p_data.emmit_count, 1)
+            p_data.reset()
 
-        # Test product being removed
-        trans = new_transaction()
-        trans_list.append(trans)
-        sellable = trans.get(sellable)
-        product = trans.get(product)
-        sellable.remove()
-        trans.commit()
-        self.assertTrue(p_data.was_deleted)
-        self.assertFalse(p_data.was_created)
-        self.assertFalse(p_data.was_edited)
-        self.assertEqual(p_data.product, product)
-        self.assertEqual(p_data.emmit_count, 1)
-        p_data.reset()
+        finally:
+            # Test product being removed
+            trans = new_transaction()
+            trans_list.append(trans)
+            sellable = trans.get(sellable)
+            product = trans.get(product)
+            sellable.remove()
+            trans.commit()
+            self.assertTrue(p_data.was_deleted)
+            self.assertFalse(p_data.was_created)
+            self.assertFalse(p_data.was_edited)
+            self.assertEqual(p_data.product, product)
+            self.assertEqual(p_data.emmit_count, 1)
+            p_data.reset()
 
-        for trans in trans_list:
-            trans.close()
+            for trans in trans_list:
+                trans.close()
