@@ -22,6 +22,8 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
+import datetime
+
 from stoqlib.database.orm import const, AND, INNERJOINOn, LEFTJOINOn, OR
 from stoqlib.database.orm import Viewable, Field, Alias
 from stoqlib.domain.account import Account, AccountTransaction
@@ -34,6 +36,7 @@ from stoqlib.domain.product import (Product,
                                     ProductStockItem,
                                     ProductHistory,
                                     ProductComponent,
+                                    ProductManufacturer,
                                     Storable)
 from stoqlib.domain.production import ProductionOrder, ProductionItem
 from stoqlib.domain.purchase import (Quotation, QuoteGroup, PurchaseOrder,
@@ -44,8 +47,8 @@ from stoqlib.domain.sellable import (Sellable, SellableUnit,
                                      SellableCategory,
                                      SellableTaxConstant)
 from stoqlib.domain.stockdecrease import (StockDecrease, StockDecreaseItem)
-
 from stoqlib.lib.decorators import cached_property
+from stoqlib.lib.validators import is_date_in_interval
 
 
 class ProductFullStockView(Viewable):
@@ -73,8 +76,14 @@ class ProductFullStockView(Viewable):
         cost=Sellable.q.cost,
         description=Sellable.q.description,
         image_id=Sellable.q.imageID,
+        base_price=Sellable.q.base_price,
+        on_sale_price=Sellable.q.on_sale_price,
+        on_sale_start_date=Sellable.q.on_sale_start_date,
+        on_sale_end_date=Sellable.q.on_sale_end_date,
         product_id=Product.q.id,
         location=Product.q.location,
+        manufacturer=ProductManufacturer.q.name,
+        model=Product.q.model,
         tax_description=SellableTaxConstant.q.description,
         category_description=SellableCategory.q.description,
         total_stock_cost=const.SUM(
@@ -101,6 +110,9 @@ class ProductFullStockView(Viewable):
                    Storable.q.productID == Product.q.id),
         LEFTJOINOn(None, ProductStockItem,
                    ProductStockItem.q.storableID == Storable.q.id),
+        # Manufacturer
+        LEFTJOINOn(None, ProductManufacturer,
+                   Product.q.manufacturerID == ProductManufacturer.q.id),
         ]
 
     clause = Sellable.q.status != Sellable.STATUS_CLOSED
@@ -153,11 +165,14 @@ class ProductFullStockView(Viewable):
 
     @property
     def price(self):
-        # This property is needed because the price value in the view column
-        # might not be the price used (check on_sale_* properties on Sellable).
-        # FIXME: This could be done here, without the extra query
-        sellable = Sellable.get(self.id, connection=self.get_connection())
-        return sellable.price
+        # See Sellable.price property
+        if self.on_sale_price:
+            today = datetime.datetime.today()
+            start_date = self.on_sale_start_date
+            end_date = self.on_sale_end_date
+            if is_date_in_interval(today, start_date, end_date):
+                return self.on_sale_price
+        return self.base_price
 
     @property
     def has_image(self):
@@ -316,8 +331,13 @@ class SellableFullStockView(Viewable):
         status=Sellable.q.status,
         cost=Sellable.q.cost,
         description=Sellable.q.description,
+        on_sale_price=Sellable.q.on_sale_price,
+        on_sale_start_date=Sellable.q.on_sale_start_date,
+        on_sale_end_date=Sellable.q.on_sale_end_date,
         unit=SellableUnit.q.description,
         product_id=Product.q.id,
+        manufacturer=ProductManufacturer.q.name,
+        model=Product.q.model,
         category_description=SellableCategory.q.description,
         base_price=Sellable.q.base_price,
         max_discount=Sellable.q.max_discount,
@@ -339,6 +359,9 @@ class SellableFullStockView(Viewable):
                    Storable.q.productID == Product.q.id),
         LEFTJOINOn(None, ProductStockItem,
                    ProductStockItem.q.storableID == Storable.q.id),
+        # Manufacturer
+        LEFTJOINOn(None, ProductManufacturer,
+                   Product.q.manufacturerID == ProductManufacturer.q.id),
         ]
 
     @classmethod
@@ -360,11 +383,14 @@ class SellableFullStockView(Viewable):
 
     @property
     def price(self):
-        # This property is needed because the price value in the view column
-        # might not be the price used (check on_sale_* properties on Sellable).
-        # FIXME: This could be done here, without the extra query
-        sellable = Sellable.get(self.id, connection=self.get_connection())
-        return sellable.price
+        # See Sellable.price property
+        if self.on_sale_price:
+            today = datetime.datetime.today()
+            start_date = self.on_sale_start_date
+            end_date = self.on_sale_end_date
+            if is_date_in_interval(today, start_date, end_date):
+                return self.on_sale_price
+        return self.base_price
 
 
 class SellableCategoryView(Viewable):
@@ -460,6 +486,8 @@ class QuotationView(Viewable):
     )
 
     joins = [
+        INNERJOINOn(None, QuoteGroup,
+                    QuoteGroup.q.id == Quotation.q.groupID),
         LEFTJOINOn(None, PurchaseOrder,
                    PurchaseOrder.q.id == Quotation.q.purchaseID),
         LEFTJOINOn(None, Supplier,
@@ -468,8 +496,6 @@ class QuotationView(Viewable):
                    Supplier.q.personID),
     ]
 
-    clause = QuoteGroup.q.id == Quotation.q.groupID
-
     @property
     def group(self):
         return QuoteGroup.get(self.group_id, connection=self.get_connection())
@@ -616,7 +642,7 @@ class PurchasedItemAndStockView(Viewable):
     )
 
     joins = [
-        LEFTJOINOn(None, PurchaseItem,
+        LEFTJOINOn(None, PurchaseOrder,
                    PurchaseItem.q.orderID == PurchaseOrder.q.id),
         LEFTJOINOn(None, Sellable,
                     Sellable.q.id == PurchaseItem.q.sellableID),
@@ -840,6 +866,10 @@ class LoanView(Viewable):
                    Client.q.personID == PersonClient.q.id),
     ]
 
+    @property
+    def loan(self):
+        return Loan.get(self.id, connection=self.get_connection())
+
 
 class LoanItemView(Viewable):
     columns = dict(id=LoanItem.q.id,
