@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2007 Async Open Source
+## Copyright (C) 2005-2012 Async Open Source
 ##
 ## This program is free software; you can redistribute it and/or
 ## modify it under the terms of the GNU Lesser General Public License
@@ -29,15 +29,15 @@ import gtk
 from gtk import keysyms
 from kiwi.log import Logger
 from kiwi.ui.dialogs import error, warning, info, yesno
-from kiwi.ui.delegates import GladeSlaveDelegate, GladeDelegate
+from kiwi.ui.delegates import GladeDelegate
 from kiwi.ui.views import BaseView
 from kiwi.utils import gsignal
 from zope.interface import implements
 
-from stoqlib.exceptions import ModelDataError
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.interfaces import ISystemNotifier
 from stoqlib.gui.base.gtkadds import change_button_appearance
+from stoqlib.gui.base.messagebar import MessageBar
 from stoqlib.gui.events import DialogCreateEvent
 
 _ = stoqlib_gettext
@@ -50,35 +50,6 @@ log = Logger('stoqlib.dialogs')
 #
 
 
-class Warnbox(GladeSlaveDelegate):
-    def __init__(self):
-        GladeSlaveDelegate.__init__(self, gladefile='Warnbox')
-
-    def setup_label(self, message):
-        self.label.set_bold(True)
-        self.label.set_color('red')
-        self.label.set_justify(gtk.JUSTIFY_LEFT)
-        self.label.set_text(message)
-
-    def error(self, message):
-        self.alert_icon.hide()
-        self.error_icon.show()
-        self.setup_label(message)
-        self.get_toplevel().show()
-
-    def alert(self, message):
-        self.alert_icon.show()
-        self.error_icon.hide()
-        self.setup_label(message)
-        self.get_toplevel().show()
-
-    def clear_notices(self):
-        # Don't hide warnbox or the vbox collapses it
-        self.alert_icon.hide()
-        self.error_icon.hide()
-        self.label.set_text("")
-
-
 class RunnableView:
     """A mixin class for any View or GladeDelegate that offers run/close"""
     retval = None
@@ -97,38 +68,140 @@ class RunnableView:
         """
         self.show()
 
-#
-# Abstract classes: inherit only, do not use.
-#
+    def get_current_toplevel(self):
+        return self.get_toplevel()
+
+    def set_transient_for(self, window):
+        self.get_toplevel().set_transient_for(window)
 
 
-class AbstractDialog(GladeDelegate, RunnableView):
-    """Abstract Dialog class that defines a simple run API."""
-    gladefile = None
+class BasicDialog(GladeDelegate, RunnableView):
+    """Abstract class that offers a Dialog with two buttons. It should be
+    subclassed and customized.
+    """
     help_section = None
+    gsignal('confirm', object, retval=bool)
+    gsignal('cancel', object)
 
-    def __init__(self, delete_handler=None):
-        if not delete_handler:
-            delete_handler = self.close
-
-        self.setup_keyactions()
-        GladeDelegate.__init__(self, gladefile=self.gladefile,
-                               delete_handler=delete_handler,
+    def __init__(self, main_label_text=None, title=" ",
+                 header_text="", size=None, hide_footer=False,
+                 delete_handler=None, help_section=None):
+        self.enable_confirm_validation = False
+        self._message_bar = None
+        self._create_dialog_ui()
+        self._setup_keyactions()
+        if delete_handler is None:
+            delete_handler = self._delete_handler
+        GladeDelegate.__init__(self, delete_handler=delete_handler,
+                               gladefile=self.gladefile,
                                keyactions=self.keyactions)
+        help_section = help_section or self.help_section
+        if help_section:
+            self._add_help_button(help_section)
 
-        if self.help_section:
-            self._add_help_button(self.help_section)
+        # FIXME: Create more widgets lazily when needed
+        self.set_title(title)
+        if size:
+            self.get_toplevel().set_size_request(*size)
+        if main_label_text:
+            self.main_label.set_text(main_label_text)
+        if header_text:
+            header_label = gtk.Label()
+            header_label.set_markup(header_text)
+            self.header.add(header_label)
+            header_label.show()
+        if hide_footer:
+            self.hide_footer()
+
+        DialogCreateEvent.emit(self)
 
     #
-    #  Public API
+    # Private
     #
 
-    def setup_keyactions(self):
-        self.keyactions = {}
+    def _create_dialog_ui(self):
+        self.toplevel = gtk.Dialog()
+        self._main_vbox = self.toplevel.get_content_area()
 
-    #
-    #  Private
-    #
+        self.vbox = gtk.VBox()
+        self._main_vbox.pack_start(self.vbox, True, True)
+        self.vbox.show()
+
+        # FIXME
+        # stoqlib/gui/base/search.py - hides the header
+        self.header = gtk.EventBox()
+        self.vbox.pack_start(self.header, False, False)
+        self.header.show()
+
+        self.main = gtk.EventBox()
+        self.vbox.pack_start(self.main)
+        self.main.show()
+
+        # FIXME
+        # stoqlib/gui/dialogs/importerdialog.py - setting
+        # stoqlib/gui/base/lists.py - removes the label
+        # stoqlib/gui/base/search.py - removes the label
+        # plugins/ecf/deviceconstanteditor.py - removes the label
+        self.main_label = gtk.Label()
+        self.main.add(self.main_label)
+        self.main_label.show()
+
+        hbox1 = gtk.HBox()
+        self.vbox.pack_start(hbox1, False)
+        hbox1.show()
+
+        # FIXME
+        # stoqlib/gui/dialogs/paymentmethod.py
+        # stoqlib/gui/search/salesearch.py
+        self.extra_holder = gtk.EventBox()
+        hbox1.pack_start(self.extra_holder, True, True)
+        self.extra_holder.show()
+
+        # FIXME
+        # stoqlib/gui/search/productsearch.py
+        # stoqlib/gui/search/servicesearch.py
+        self.print_holder = gtk.EventBox()
+        hbox1.pack_start(self.print_holder, True, True)
+        self.print_holder.show()
+
+        # FIXME
+        # stoqlib/gui/base/search.py
+        # stoqlib/gui/slaves/productslave.py
+        self.details_holder = gtk.EventBox()
+        hbox1.pack_end(self.details_holder, False, False)
+        self.details_holder.show()
+
+        # FIXME
+        # stoqlib/gui/dialogs/quotedialog.py
+        self.notice = gtk.EventBox()
+        hbox1.pack_start(self.notice, False)
+        self.notice.show()
+
+        action_area = self.toplevel.get_action_area()
+        action_area.set_border_width(6)
+        action_area.set_layout(gtk.BUTTONBOX_END)
+
+        self.cancel_button = gtk.Button(stock=gtk.STOCK_CANCEL)
+        action_area.pack_start(self.cancel_button, True, True)
+        self.cancel_button.show()
+
+        self.ok_button = gtk.Button(stock=gtk.STOCK_OK)
+        self.ok_button.set_use_underline(True)
+        action_area.pack_start(self.ok_button, True, True)
+        self.ok_button.show()
+
+    def _setup_keyactions(self):
+        self.keyactions = {keysyms.Escape: self.cancel}
+
+    def _try_confirm(self, *args):
+        """Only confirm if ok button is actually enabled.
+
+        This is so that this dialog doesn't get confirmed in case the ok
+        button was specifically disabled.
+        """
+        # FIXME: There should be a better way to findout valid status
+        if self.ok_button.get_sensitive():
+            self.confirm()
 
     def _add_help_button(self, section):
         def on_help__clicked(button):
@@ -142,68 +215,26 @@ class AbstractDialog(GladeDelegate, RunnableView):
         self.action_area.set_child_secondary(button, True)
         button.show()
 
-#
-# Special note for BasicDialog and BasicPluggableDialog: if you inherit
-# from this class, you *must* call Basic*Dialog._initialize() right after
-# calling Basic*Dialog.__init__() or the dialog will not be set up
-# correctly. Initialization has been broken into two steps to allow it to
-# be called conveniently from a consumer refresh() method. See
-# NotifyDialog/PluggableNotifyDialog for an example of how __init__ should
-# behave.
-#
+    #
+    # Public API
+    #
 
-
-class BasicDialog(AbstractDialog):
-    """Abstract class that offers a Dialog with two buttons. It should be
-    subclassed and customized.
-    """
-    gladefile = "BasicDialog"
-
-    def __init__(self, delete_handler=None):
-        if not delete_handler:
-            delete_handler = self.cancel
-        AbstractDialog.__init__(self, delete_handler=delete_handler)
-
-    # Yes, title=" ". Use a single space to work around *cough* BROKEN
-    # window managers that want to set the title as Unnamed or ? when an
-    # empty string is set to it.
-    def _initialize(self, main_label_text=None, title=" ",
-                    header_text="", size=None, hide_footer=False):
-        self.set_title(title)
-        if size:
-            self.get_toplevel().set_size_request(*size)
-        if main_label_text:
-            self.main_label.set_text(main_label_text)
-        if header_text:
-            self.header_label.set_text(header_text)
-        else:
-            self.header_label.hide()
-            self.top_separator.hide()
-        if hide_footer:
-            self.hide_footer()
-        self.ok_button.set_use_underline(True)
-
-        DialogCreateEvent.emit(self)
-
-    def _try_confirm(self, *args):
-        """Only confirm if ok button is actually enabled.
-
-        This is so that this dialog doesn't get confirmed in case the ok
-        button was specifically disabled.
-        """
-        # FIXME: There should be a better way to findout valid status
-        if self.ok_button.get_sensitive():
-            self.confirm()
-
-    def setup_keyactions(self):
-        self.keyactions = {keysyms.Escape: self.cancel}
-
-    def confirm(self, *args):
+    def confirm(self):
+        # SearchDialog and SellableSearch overrides this
         self.retval = True
+        # FIXME: Confirm validation should be enabled by default,
+        #        but we need to change the dialog API and existing
+        #        callsites for that to work.
+        if (self.enable_confirm_validation and not
+            self.emit('confirm', self.retval)):
+            return
+
         self.close()
 
-    def cancel(self, *args):
+    def cancel(self):
+        # SearchDialog overrides this
         self.retval = False
+        self.emit('cancel', self.retval)
         self.close()
 
     def hide_footer(self):
@@ -221,9 +252,8 @@ class BasicDialog(AbstractDialog):
             icon = gtk.STOCK_OK
         change_button_appearance(self.ok_button, icon, text)
 
-    def set_cancel_label(self, text):
-        self.cancel_button.set_label(text)
-
+    # FIXME: Remove
+    # Callsites: stoqlib/gui/dialogs/sintegradialog.py
     def justify_label(self, just):
         self.main_label.set_justify(just)
 
@@ -238,17 +268,6 @@ class BasicDialog(AbstractDialog):
                 dialog, widget))
         widget.connect('activate', self._try_confirm)
 
-    def set_cancel_widget(self, widget):
-        """Enables widget as a cancel widget, the dialog will be closed as
-        canceled if the widget is activated.
-        :param widget: a widget
-        """
-        dialog = self.get_toplevel()
-        if not widget.is_ancestor(dialog):
-            raise ValueError("dialog %r is not an ancestor of widget %r" % (
-                dialog, widget))
-        widget.connect('activate', self.cancel)
-
     def add(self, widget):
         for child in self.main.get_children():
             self.main.remove(child)
@@ -258,6 +277,22 @@ class BasicDialog(AbstractDialog):
     def action_area(self):
         return self.get_toplevel().action_area
 
+    def set_message(self, message, message_type=gtk.MESSAGE_INFO):
+        """Sets a message for this editor
+        :param message: message to add or None to remove previous message
+        :param message_type: type of message to add
+        """
+        if self._message_bar is not None:
+            self._message_bar.destroy()
+            self._message_bar = None
+        if message is None:
+            return
+        self._message_bar = MessageBar(message, message_type)
+        self._main_vbox.pack_start(self._message_bar, False, False)
+        self._main_vbox.reorder_child(self._message_bar, 0)
+        self._message_bar.show_all()
+        return self._message_bar
+
     #
     # Kiwi handlers
     #
@@ -268,132 +303,8 @@ class BasicDialog(AbstractDialog):
     def on_cancel_button__clicked(self, button):
         self.cancel()
 
-#
-# Main classes start here. There are two basic types: Notify and
-# Confirm dialogs, the only difference between them being that Notify
-# offers only an OK button and Confirm offering both OK and Cancel. The
-# second set offers a pluggable slave area.
-#
-
-
-class BasicPluggableDialog(BasicDialog):
-    """Abstract class for Pluggable*Dialog; two buttons and a slave area"""
-    warnbox = None
-    slave = None
-    gsignal('confirm', object)
-
-    def _initialize(self, slave, title=" ", header_text="", size=None,
-                    hide_footer=False):
-        """May be called by refresh by subdialogs, as necessary"""
-        if self.slave:
-            log.warn("%s had self.slave set to %s!" % (self, self.slave))
-        self.slave = slave
-        self.attach_slave("main", slave)
-        if self.warnbox:
-            self.clear_notices()
-            self.warnbox = None
-        BasicDialog._initialize(self, title=title, header_text=header_text,
-                                size=size, hide_footer=hide_footer)
-
-    def enable_notices(self):
-        """Enables display of notice messages with icons using alert() and
-        error().
-        """
-        self.warnbox = Warnbox()
-        self.clear_notices()
-        self.attach_slave('notice', self.warnbox)
-        self.warnbox.get_toplevel().hide()
-
-    def clear_notices(self):
-        self.warnbox.clear_notices()
-
-    def error(self, message):
-        if not self.warnbox:
-            raise AssertionError
-        self.warnbox.error(message)
-
-    def alert(self, message):
-        if not self.warnbox:
-            raise AssertionError
-        self.warnbox.alert(message)
-
-    def confirm(self, *args):
-        if not self.slave.validate_confirm():
-            return
-
-        # self.slave.on_confirm() should return a considered success
-        # value. It can be an integer or a model object.
-        self.retval = self.slave.on_confirm()
-        self.close()
-        self.emit('confirm', self.retval)
-
-        log.info("%s: Closed (confirmed), retval=%r" % (
-            self.slave.__class__.__name__, self.retval))
-
-    def cancel(self, *args):
-        # self.slave.on_cancel() should return a considered failure
-        # value
-        self.retval = self.slave.on_cancel()
-        self.close()
-
-        log.info("%s: Closed (cancelled), retval=%r" % (
-            self.slave.__class__.__name__, self.retval))
-
-#
-# Wrapping variants, which take a slave as a parameter and set it up to
-# have a "normal" dialog API, which follows the BasicPluggableDialog
-# interface for stoqlib.services run_dialog compatibility.
-#
-
-
-class BasicWrappingDialog(BasicPluggableDialog):
-    """ Abstract class for Wrapping*Dialog; run and set_transient_for to
-    the wrapped slave and ok_button sensitivity control """
-    def __init__(self, slave, title=" ", header_text="", size=None,
-                 hide_footer=False):
-        BasicPluggableDialog.__init__(self)
-        BasicPluggableDialog._initialize(self, slave, title, header_text,
-                                         size, hide_footer=hide_footer)
-        # This helps kiwis ui test, set the name of ourselves to
-        # the classname of the slave, which is much more helpful than
-        # just "BasicWrappingDialog"
-        self.get_toplevel().set_name(slave.__class__.__name__)
-        slave.run = self.run
-        slave.set_transient_for = self.set_transient_for
-
-
-class ConfirmDialog(BasicDialog):
-    """Dialog offers an option to confirm or cancel an event. It prints text
-    in a label and offers OK/Cancel buttons.
-    """
-
-    title = _('Confirmation')
-
-    def __init__(self, text='', title=None, size=None, ok_label=None):
-        BasicDialog.__init__(self)
-        self.justify_label(gtk.JUSTIFY_CENTER)
-        BasicDialog._initialize(self, text,
-                                title=title or self.title, size=size)
-        if ok_label:
-            self.set_ok_label(ok_label)
-
-    def setup_keyactions(self):
-        self.keyactions = {keysyms.Escape: self.cancel,
-                           keysyms.Return: self.confirm,
-                           keysyms.KP_Enter: self.confirm}
-
-
-class NotifyDialog(ConfirmDialog):
-    """Dialog that notifies an event. It prints text in a label and offers a
-    single OK button.
-    """
-
-    title = _('Notification')
-
-    def __init__(self, text, title=None, size=None, ok_label=None):
-        ConfirmDialog.__init__(self, text, title, size=size,
-                               ok_label=ok_label)
-        self.cancel_button.hide()
+    def _delete_handler(self, window, event):
+        self.cancel()
 
 
 #
@@ -415,11 +326,12 @@ def _pop_current_toplevel():
 
 
 def get_dialog(parent, dialog, *args, **kwargs):
-    """ Returns a dialog.
-    - parent: the window which is opening the dialog;
-    - dialog: the dialog class or instance;
-    - *args, **kwargs: the arguments which should be used on dialog
-      instantiation;
+    """Returns a dialog.
+
+    :param parent: the window which is opening the dialog
+    :param dialog: the dialog class or instance
+    :param args: custom positional arguments
+    :param kwargs: custom keyword arguments
     """
     if callable(dialog):
         dialog = dialog(*args, **kwargs)
@@ -437,15 +349,20 @@ def run_dialog(dialog, parent=None, *args, **kwargs):
     """Runs a dialog and return the return value of it.
     If dialog is a class it will be instantiated before running the dialog.
 
-    :param dialog: the dialog, could be a class or instance
+    :param dialog: the dialog class
     :param parent: parent of the dialog
-    :param args: custom positional argument
+    :param args: custom positional arguments
     :param kwargs: custom keyword arguments
     """
 
     if dialog is None:
         raise TypeError("dialog cannot be None")
 
+    if not issubclass(dialog, RunnableView):
+        raise TypeError("dialog %r must be subclass of RunnableView" % (
+            dialog, ))
+
+    # FIXME: Move this into RunnableView
     parent = getattr(parent, 'main_dialog', parent)
     parent = parent or get_current_toplevel()
     if inspect.isclass(dialog):
@@ -455,10 +372,7 @@ def run_dialog(dialog, parent=None, *args, **kwargs):
 
     dialog = get_dialog(parent, dialog, *args, **kwargs)
     orig_dialog = dialog
-    if hasattr(dialog, 'main_dialog'):
-        dialog = dialog.main_dialog
-
-    toplevel = dialog.get_toplevel()
+    toplevel = dialog.get_current_toplevel()
     add_current_toplevel(toplevel)
 
     if _fullscreen is not None:
@@ -467,7 +381,12 @@ def run_dialog(dialog, parent=None, *args, **kwargs):
         toplevel.set_transient_for(parent)
         toplevel.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
     else:
-        toplevel.set_position(gtk.WIN_POS_CENTER)
+        toplevel.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
+        # FIXME: This should not be necessary, but gnome shell hides window
+        # decorations for HINT_DIALOG. We should study what dialogs should
+        # have HINT_NORMAL (with window decorations) and what can have
+        # HINT_DIALOG
+        toplevel.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_NORMAL)
 
     if hasattr(parent, 'on_dialog__opened'):
         parent.on_dialog__opened(orig_dialog)
@@ -478,7 +397,7 @@ def run_dialog(dialog, parent=None, *args, **kwargs):
     # See http://stackoverflow.com/questions/3504739/twisted-gtk-should-i-run-gui-things-in-threads-or-in-the-reactor-thread
     toplevel.run()
 
-    retval = getattr(dialog, 'retval', None)
+    retval = dialog.retval
     dialog.destroy()
 
     _pop_current_toplevel()
@@ -497,16 +416,6 @@ def pop_fullscreen(window):
     _fullscreen = None
 
 
-def notify_if_raises(win, check_func, exceptions=ModelDataError,
-                     text="An error ocurred: %s"):
-    try:
-        check_func()
-    except exceptions, e:
-        warning(text % e)
-        return True
-    return False
-
-
 class DialogSystemNotifier:
     implements(ISystemNotifier)
 
