@@ -41,7 +41,6 @@ from stoqlib.database.orm import ORMObject, ORMObjectQueryExecuter
 from stoqlib.exceptions import DatabaseInconsistency
 from stoqlib.gui.base.dialogs import BasicDialog, run_dialog
 from stoqlib.gui.base.gtkadds import button_set_image_with_label
-from stoqlib.gui.base.messagebar import MessageBar
 from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.lib.defaults import get_weekday_start
 from stoqlib.lib.osutils import get_application_dir
@@ -226,13 +225,16 @@ class SearchDialog(BasicDialog):
         self.summary_label = None
         self.double_click_confirm = double_click_confirm
 
-        BasicDialog.__init__(self)
-        BasicDialog._initialize(self, hide_footer=hide_footer,
-                                main_label_text=self.main_label_text,
-                                title=title or self.title,
-                                size=self.size)
+        BasicDialog.__init__(self, hide_footer=hide_footer,
+                             main_label_text=self.main_label_text,
+                             title=title or self.title,
+                             size=self.size)
 
         self.executer = ORMObjectQueryExecuter(api.get_connection())
+        # FIXME: Remove this limit, but we need to migrate all existing
+        #        searches to use lazy lists first. That in turn require
+        #        us to rewrite the queries in such a way that count(*)
+        #        will work properly.
         self.executer.set_limit(sysparam(self.conn).MAX_SEARCH_RESULTS)
         self.set_table(self.search_table)
 
@@ -354,11 +356,13 @@ class SearchDialog(BasicDialog):
             retval = self.get_selection()
         self.retval = retval
         self.search.save_columns()
+        # FIXME: This should chain up so the "confirm" signal gets emitted
         self.close()
 
     def cancel(self, *args):
         self.retval = []
         self.search.save_columns()
+        # FIXME: This should chain up so the "cancel" signal gets emitted
         self.close()
 
     def set_table(self, table):
@@ -619,27 +623,6 @@ class SearchEditor(SearchDialog):
 
     # Public API
 
-    def add_message_bar(self, message, message_type=gtk.MESSAGE_INFO):
-        """Adds a message bar to the top of the search results
-        :param message: message to add
-        :param message_type: type of message to add
-        """
-        self._message_bar = MessageBar(message, message_type)
-        self.main_vbox.pack_start(self._message_bar, False, False)
-        self.main_vbox.reorder_child(self._message_bar, 0)
-        self._message_bar.show_all()
-        return self._message_bar
-
-    def remove_message_bar(self):
-        """Removes the message bar if there was one added"""
-        if not self._message_bar:
-            return
-        self._message_bar.destroy()
-        self._message_bar = None
-
-    def has_message_bar(self):
-        return self._message_bar is not None
-
     @argcheck(bool)
     def set_edit_button_sensitive(self, value):
         """Control sensitivity of button edit"""
