@@ -27,8 +27,8 @@
 import datetime
 
 import gtk
+from kiwi.currency import currency
 from kiwi.ui.objectlist import Column, ColoredColumn
-from kiwi.datatypes import currency
 from kiwi.ui.widgets.list import SummaryLabel
 
 from stoqlib.api import api
@@ -77,7 +77,7 @@ class ClientDetailsDialog(BaseEditor):
         self.calls_list.add_list(self.model.person.calls)
 
         value_format = '<b>%s</b>'
-        total_label = "<b>%s</b>" % _("Total:")
+        total_label = "<b>%s</b>" % api.escape(_("Total:"))
         sales_summary_label = SummaryLabel(klist=self.sales_list,
                                               column='total',
                                               label=total_label,
@@ -172,3 +172,4 @@ class ClientDetailsDialog(BaseEditor):
         run_person_role_dialog(ClientEditor, self, trans,
                                self.model, visual_mode=True)
         api.finish_transaction(trans, False)
+        trans.close()
