@@ -38,8 +38,7 @@ class ImporterDialog(BasicDialog):
     title = _("Importer Dialog")
 
     def __init__(self, format, filename):
-        BasicDialog.__init__(self)
-        self._initialize(size=self.size, title=self.title)
+        BasicDialog.__init__(self, size=self.size, title=self.title)
 
         self.format = format
         self.filename = filename
@@ -117,13 +116,3 @@ class ImporterDialog(BasicDialog):
 
     def _on_processview__finished(self, view, returncode):
         self._finish(returncode)
-
-
-class ImporterProgressDialog(object):
-    """ Progress Dialog for importing items """
-
-    def __init__(self, format, filename):
-        self.format = format
-        self.filename = filename
-
-        self._build_ui()
