@@ -50,12 +50,13 @@ class PaymentMethodsDialog(BasicDialog):
                       'money': MoneyPaymentMethodEditor,
                       'check': PaymentMethodEditor,
                       'bill': PaymentMethodEditor,
-                      'deposit': PaymentMethodEditor}
+                      'deposit': PaymentMethodEditor,
+                      'store_credit': PaymentMethodEditor}
 
     def __init__(self, conn):
-        BasicDialog.__init__(self)
-        self._initialize(hide_footer=True, size=PaymentMethodsDialog.size,
-                         title=PaymentMethodsDialog.title)
+        BasicDialog.__init__(self,
+                             hide_footer=True, size=PaymentMethodsDialog.size,
+                             title=PaymentMethodsDialog.title)
         self._can_edit = False
         self.conn = conn
         self._setup_list()
@@ -69,12 +70,7 @@ class PaymentMethodsDialog(BasicDialog):
         self.attach_slave("extra_holder", self._toolbar_slave)
 
     def _setup_list(self):
-        # FIXME: Dont let users see online payments for now, to avoid
-        #        confusions with active state. online is an exception to that
-        #        logic.
-        clause = PaymentMethod.q.method_name != 'online'
-        methods = PaymentMethod.select(connection=self.conn,
-                                       clause=clause).orderBy('description')
+        methods = PaymentMethod.get_editable_methods(self.conn)
         self.klist = ObjectList(self._get_columns(), methods,
                                 gtk.SELECTION_BROWSE)
         self.klist.connect("selection-changed",
@@ -102,6 +98,7 @@ class PaymentMethodsDialog(BasicDialog):
         item = trans.get(item)
         retval = run_dialog(editor, self, trans, item)
         api.finish_transaction(trans, retval)
+        trans.close()
 
     #
     # Callbacks
