@@ -26,12 +26,13 @@
 import datetime
 
 from dateutil.relativedelta import relativedelta
+import gtk
 from kiwi.ui.dialogs import save
 from kiwi.ui.search import DateSearchFilter
 
 from stoqlib.database.orm import ORMObjectQueryExecuter
 from stoqlib.domain.system import SystemTable
-from stoqlib.gui.base.dialogs import ConfirmDialog
+from stoqlib.gui.base.dialogs import BasicDialog
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.message import warning
 from stoqlib.lib.sintegra import SintegraError
@@ -40,12 +41,13 @@ from stoqlib.lib.dateconstants import get_month_names
 _ = stoqlib_gettext
 
 
-class SintegraDialog(ConfirmDialog):
-    size = (780, -1)
+class SintegraDialog(BasicDialog):
     title = _('Fiscal Printer History')
 
     def __init__(self, conn):
-        ConfirmDialog.__init__(self)
+        BasicDialog.__init__(self, title=self.title)
+        self.justify_label(gtk.JUSTIFY_CENTER)
+
         self.conn = conn
         self.ok_button.set_label(_("Generate"))
 
@@ -103,9 +105,12 @@ class SintegraDialog(ConfirmDialog):
         # make sure that they are translated
         month_names = get_month_names()
         for start, end in intervals:
-            # Translators: Month Year, eg: 'May 2007'
-            name = _('%s %s') % (
-                _(month_names[start.month + 1]), start.year)
+            # Translators: Do not translate 'month' and 'year'. You can
+            #              change it's positions. In the way it is,
+            #              it will product for example 'December 2012'
+            name = _('{month} {year}').format(
+                month=month_names[start.month - 1],
+                year=start.year)
             date_filter.add_option_fixed_interval(
                 name, start, end, position=0)
 
