@@ -24,7 +24,7 @@
 """ Dialog to edit the stock average cost for products on a certain branch """
 
 from kiwi import ValueUnset
-from kiwi.datatypes import currency
+from kiwi.currency import currency
 from kiwi.enums import ListType
 from kiwi.ui.objectlist import Column
 from kiwi.ui.listdialog import ListSlave
@@ -64,7 +64,7 @@ class StockCostDialog(BaseEditor):
     def _setup_widgets(self):
         self.branch_label.set_markup(
             _(u"Fixing stock cost for products in <b>%s</b>") %
-                                            self._branch.person.name)
+            api.escape(self._branch.person.name))
 
         items = ProductWithStockView.select_by_branch(None, branch=self._branch,
                                                       connection=self.conn)
