@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2008 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2005-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,6 @@
 ##
 """ Person address editor implementation"""
 
-import gtk
 from kiwi.argcheck import argcheck
 from kiwi.datatypes import ValidationError
 from kiwi.python import AttributeForwarder
@@ -33,11 +32,10 @@ from stoqlib.api import api
 from stoqlib.database.runtime import StoqlibTransaction
 from stoqlib.domain.address import Address, CityLocation
 from stoqlib.domain.person import Person
-from stoqlib.gui.base.lists import ModelListDialog
+from stoqlib.gui.base.lists import ModelListDialog, ModelListSlave
 from stoqlib.gui.editors.baseeditor import BaseEditor, BaseEditorSlave
 from stoqlib.lib.countries import get_countries
 from stoqlib.lib.parameters import sysparam
-from stoqlib.lib.pluginmanager import get_plugin_manager
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -79,7 +77,95 @@ class _AddressModel(AttributeForwarder):
             self.target.city_location = location
 
 
-class AddressSlave(BaseEditorSlave):
+class CityLocationMixin(object):
+    """A mixin class for city locations
+
+    Use this mixin in a multiple inheritance editor to have
+    it's city location validated and prefilled with right data.
+
+    For this to happen, you need to have:
+      - A proxy entry for 'city' accessible at self.city
+      - A proxy entry for 'state' accessible at self.state
+      - A proxy combo entry for 'country' accessible at self.country
+    """
+
+    #
+    #  BaseEditorSlave
+    #
+
+    def setup_proxies(self):
+        self.country.prefill(get_countries())
+        self._cache_l10n_fields()
+
+        self._prefill_states()
+
+        self.city.set_exact_completion()
+        city_completion = self.city.get_completion()
+        city_completion.set_minimum_key_length = 2
+
+    #
+    #  Private
+    #
+
+    def _cache_l10n_fields(self):
+        self._city_l10n = api.get_l10n_field(self.conn, 'city',
+                                             self.model.country)
+        self._state_l10n = api.get_l10n_field(self.conn, 'state',
+                                              self.model.country)
+
+    def _prefill_states(self):
+        self.state.prefill(self._state_l10n.state_list)
+
+    def _prefill_cities(self, force=False):
+        completion = self.city.get_completion()
+        if not completion:
+            # Completion wasn't set yet
+            return
+
+        if len(completion.get_model()) and not force:
+            return
+
+        self.city.prefill([]) # mimic missing .clear method
+        cities = CityLocation.get_cities_by(self.conn,
+                                            state=self.model.state,
+                                            country=self.model.country)
+        self.city.prefill(list(cities))
+
+    #
+    #  Callbacks
+    #
+
+    def on_state__validate(self, entry, state):
+        if not self._state_l10n.validate(state):
+            return ValidationError(_("%s is not valid") % self._state_l10n.label)
+
+    def on_city__validate(self, entry, city):
+        if sysparam(self.conn).ALLOW_REGISTER_NEW_LOCATIONS:
+            return
+
+        # FIXME: Try to avoid lots of database queries here
+        if not self._city_l10n.validate(city,
+                                        self.model.state, self.model.country):
+            return ValidationError(_("%s is not valid") % self._city_l10n.label)
+
+    def on_city__content_changed(self, widget):
+        city = widget.read()
+        if city:
+            self._prefill_cities()
+
+    def after_state__content_changed(self, widget):
+        self._prefill_cities(force=True)
+        self.city.validate(force=True)
+
+    def after_country__content_changed(self, widget):
+        self._cache_l10n_fields()
+        self._prefill_states()
+        self._prefill_cities(force=True)
+        self.state.validate(force=True)
+        self.city.validate(force=True)
+
+
+class AddressSlave(BaseEditorSlave, CityLocationMixin):
     model_type = _AddressModel
     gladefile = 'AddressSlave'
 
@@ -102,12 +188,15 @@ class AddressSlave(BaseEditorSlave):
         self.is_main_address = (model and model.is_main_address
                                 or is_main_address)
         self.db_form = db_form
-        self.state_l10n = api.get_l10n_field(conn, 'state')
         if model is not None:
             model = conn.get(model)
             model = _AddressModel(model, conn)
         BaseEditorSlave.__init__(self, conn, model, visual_mode=visual_mode)
 
+    #
+    #  BaseEditorSlave
+    #
+
     def create_model(self, conn):
         address = Address(person=self.person,
                           city_location=CityLocation.get_default(conn),
@@ -129,27 +218,36 @@ class AddressSlave(BaseEditorSlave):
         self.model.ensure_address()
         return self.model.target
 
-    #
-    # BaseEditorSlave hooks
-    #
-
     def setup_proxies(self):
-        self.country.prefill(get_countries())
+        CityLocationMixin.setup_proxies(self)
+
         if self.db_form:
             self._update_forms()
         self.proxy = self.add_proxy(self.model,
                                     AddressSlave.proxy_widgets)
 
+        # Not using self._statel10n and self._city_l10n here because we need
+        # to get the label name based on SUGGESTED_COUNTRY and not on the
+        # country on model.
+        for field, label in [
+            ('state', self.state_lbl),
+            ('city', self.city_lbl),
+            ]:
+            l10n_field = api.get_l10n_field(self.conn, field)
+            label.set_text(l10n_field.label + ':')
+
         # Enable if we already have a number or if we are adding a new address.
         self.streetnumber_check.set_active(bool(self.model.streetnumber)
                                            or not self.edit_mode)
         self._update_streetnumber()
-        self.state_lbl.set_text(self.state_l10n.label + ':')
-        self._prefill_states()
 
     def can_confirm(self):
         return self.model.is_valid_model()
 
+    #
+    #  Private
+    #
+
     def _update_streetnumber(self):
         if not self.visual_mode:
             # Don't do that on visual mode. Visual mode will handle
@@ -181,47 +279,10 @@ class AddressSlave(BaseEditorSlave):
         self.db_form.update_widget(self.country,
                                    other=self.country_lbl)
 
-    def _get_nfe_plugin(self):
-        manager = get_plugin_manager()
-        if manager.is_active('nfe'):
-            return manager.get_plugin('nfe')
-
-    def _complete_cities(self):
-        city = self.city.read()
-        if city and len(city) >= 2:
-            # mimic the missing .clear method.
-            self.city.prefill([])
-            #FIXME: the city completion is highly attached with the nf-e
-            #       plugin, it should be more generic and avoid the plugin
-            #       dependency.
-            plugin = self._get_nfe_plugin()
-            if plugin is None:
-                return
-
-            # using "set" to avoid duplicates
-            cities = set(c.city_name for c in plugin.get_matching_cities(city))
-            self.city.prefill(list(cities))
-
-    def _prefill_states(self):
-        # FIXME: This should prefill the country states list
-        if self.model.country != sysparam(self.conn).COUNTRY_SUGGESTED:
-            self.state.prefill([])
-            return
-
-        self.state.prefill(self.state_l10n.state_list)
-
     #
     # Kiwi callbacks
     #
 
-    def on_state__validate(self, entry, state):
-        if self.model.country != sysparam(self.conn).COUNTRY_SUGGESTED:
-            return
-
-        if not self.state_l10n.validate(state):
-            return ValidationError(_("%s is not valid") % (
-                self.state_l10n.label))
-
     def on_streetnumber__validate(self, entry, streetnumber):
         if streetnumber <= 0:
             return ValidationError(_("Number cannot be zero or less than zero"))
@@ -229,20 +290,13 @@ class AddressSlave(BaseEditorSlave):
     def on_streetnumber_check__clicked(self, check_button):
         self._update_streetnumber()
 
-    def on_city__content_changed(self, widget):
-        self._complete_cities()
-
-    def after_country__content_changed(self, widget):
-        self._prefill_states()
-        self.state.validate(force=True)
-
 
 class AddressEditor(BaseEditor):
     model_name = _('Address')
     model_type = Address
     gladefile = 'AddressEditor'
 
-    def __init__(self, conn, person, address=None):
+    def __init__(self, conn, person, address=None, visual_mode=False):
         self.person = person
         if not isinstance(person, Person):
             raise TypeError("Invalid type for person argument. It should "
@@ -250,7 +304,7 @@ class AddressEditor(BaseEditor):
                             % type(person))
         self.current_main_address = self.person.get_main_address()
 
-        BaseEditor.__init__(self, conn, address)
+        BaseEditor.__init__(self, conn, address, visual_mode=visual_mode)
         self.set_description(self.model_name)
 
     #
@@ -276,10 +330,8 @@ class AddressEditor(BaseEditor):
         return self.address_slave.confirm()
 
 
-class AddressAdditionDialog(ModelListDialog):
-    title = _('Additional Addresses')
-    size = (600, 250)
-
+class AddressAdditionListSlave(ModelListSlave):
+    model_type = Address
     columns = [
         Column('address_string', title=_('Address'),
                data_type=str, width=250, expand=True),
@@ -288,70 +340,30 @@ class AddressAdditionDialog(ModelListDialog):
         Column('state', title=_('State'), data_type=str),
         ]
 
-    model_type = Address
+    def populate(self):
+        # This is only additional addresses, eg non-main ones
+        return Address.selectBy(
+            person=self.parent.person,
+            is_main_address=False,
+            connection=self.parent.trans)
+
+    def run_editor(self, trans, model):
+        trans.savepoint('before_run_editor_address')
+        retval = self.run_dialog(AddressEditor, conn=trans,
+                                 person=self.parent.person, address=model)
+        if not retval:
+            trans.rollback_to_savepoint('before_run_editor_address')
+        return retval
+
+
+class AddressAdditionDialog(ModelListDialog):
+    list_slave_class = AddressAdditionListSlave
+    title = _('Additional Addresses')
+    size = (600, 250)
 
     def __init__(self, trans, person, reuse_transaction=False):
         self.person = person
         self.trans = trans
         ModelListDialog.__init__(self, trans)
         if reuse_transaction:
-            self.set_reuse_transaction(trans)
-
-    def populate(self):
-        # This is only additional addresses, eg non-main ones
-        return Address.selectBy(
-            person=self.person,
-            is_main_address=False,
-            connection=self.trans)
-
-    def run_editor(self, trans, model):
-        trans.savepoint('before_run_editor_address')
-        retval = self.run_dialog(AddressEditor, conn=trans,
-                                  person=self.person, address=model)
-        if not retval:
-            trans.rollback_to_savepoint('before_run_editor_address')
-        return retval
-
-
-class AddressSelectionDialog(ModelListDialog):
-    title = _('Select an address')
-    size = (600, 250)
-
-    columns = [
-        Column('address_string', title=_('Address'),
-               data_type=str, width=250, expand=True),
-        Column('city', title=_('City'), width=100,
-               data_type=str),
-        Column('state', title=_('State'), data_type=str),
-        ]
-
-    model_type = Address
-
-    def __init__(self, conn, person):
-        self.person = person
-        self.conn = conn
-        ModelListDialog.__init__(self)
-
-        # Remove the close button, we'll add it back shortly
-        self.action_area.remove(self.action_area.get_children()[0])
-        self.add_button(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL)
-        self.add_button(gtk.STOCK_APPLY, gtk.RESPONSE_CLOSE)
-        self.listcontainer.list.connect('row-activated',
-                                        self._on_listcontainer_row_activated)
-        self.connect('response', self._on_dialog__response)
-
-    def _on_dialog__response(self, dialog, response):
-        if response == gtk.RESPONSE_CLOSE:
-            self.retval = self.listcontainer.list.get_selected()
-
-    def _on_listcontainer_row_activated(self, addresses, address):
-        self.response(gtk.RESPONSE_CLOSE)
-
-    def populate(self):
-        return Address.selectBy(
-            person=self.person,
-            connection=self.conn)
-
-    def run_editor(self, trans, model):
-        return self.run_dialog(AddressEditor,
-            conn=trans, person=self.person, address=model)
+            self.list_slave.set_reuse_transaction(trans)
