@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2007 Async Open Source
+## Copyright (C) 2005-2012 Async Open Source
 ##
 ## This program is free software; you can redistribute it and/or
 ## modify it under the terms of the GNU Lesser General Public License
@@ -33,10 +33,8 @@ from kiwi.ui.widgets.label import ProxyLabel
 
 from stoqlib.database.runtime import StoqlibTransaction
 from stoqlib.lib.translation import stoqlib_gettext
-from stoqlib.gui.base.dialogs import BasicWrappingDialog, run_dialog
-from stoqlib.gui.base.messagebar import MessageBar
+from stoqlib.gui.base.dialogs import RunnableView, BasicDialog, run_dialog
 from stoqlib.gui.events import EditorSlaveCreateEvent
-from stoqlib.gui.help import show_section
 
 log = Logger('stoqlib.gui.editors')
 
@@ -107,6 +105,12 @@ class BaseEditorSlave(GladeSlaveDelegate):
             if isinstance(widget, ProxyLabel):
                 continue
             widget.set_sensitive(False)
+
+        if self.fields:
+            for field in self.fields.values():
+                field.set_sensitive(False)
+                field.can_edit = False
+
         self.update_visual_mode()
 
     def create_model(self, trans):
@@ -155,7 +159,7 @@ class BaseEditorSlave(GladeSlaveDelegate):
         return True
 
 
-class BaseEditor(BaseEditorSlave):
+class BaseEditor(BaseEditorSlave, RunnableView):
     """ Base class for editor dialogs. It offers methods of
     BaseEditorSlave, a windows title and OK/Cancel buttons.
 
@@ -166,6 +170,7 @@ class BaseEditor(BaseEditorSlave):
        situation.
     :cvar confirm_widgets: a list of widget names that when activated will
         confirm the dialog
+    :cvar fields: a dictionary that contains :class:`stoqlib.gui.field.Field` attributes
     """
 
     model_name = None
@@ -175,20 +180,34 @@ class BaseEditor(BaseEditorSlave):
     hide_footer = False
     confirm_widgets = ()
     help_section = None
+    fields = None
+    form_holder_name = 'toplevel'
 
     def __init__(self, conn, model=None, visual_mode=False):
         if conn is not None and isinstance(conn, StoqlibTransaction):
             conn.needs_retval = True
-        self._message_bar = None
         self._confirm_disabled = False
+
+        # FIXME:
+        # BasicEditor should inheirt from BasicDialog and instantiate
+        # the slave inside here, but it requires some major surgery
         BaseEditorSlave.__init__(self, conn, model,
                                  visual_mode=visual_mode)
 
-        self.main_dialog = BasicWrappingDialog(self,
-                                               self.get_title(self.model),
-                                               self.header, self.size)
-        self.main_dialog.connect(
-            'confirm', self._on_main_dialog__confirm)
+        self.main_dialog = BasicDialog(title=self.get_title(self.model),
+                                       header_text=self.header,
+                                       help_section=self.help_section,
+                                       size=self.size)
+        # Do not close the dialog if re return False on self.confirm
+        self.main_dialog.enable_confirm_validation = True
+        self.main_dialog.attach_slave("main", self)
+        self.main_dialog.connect('confirm', self._on_main_dialog__confirm)
+        self.main_dialog.connect('cancel', self._on_main_dialog__cancel)
+
+        # This helps kiwis ui test, set the name of ourselves to
+        # the classname of the slave, which is much more helpful than
+        # just "BasicDialog"
+        self.main_dialog.get_toplevel().set_name(self.__class__.__name__)
 
         if self.hide_footer or self.visual_mode:
             self.main_dialog.hide_footer()
@@ -199,24 +218,6 @@ class BaseEditor(BaseEditorSlave):
         self.register_validate_function(self._validation_function)
         self.force_validation()
 
-        if self.help_section:
-            self._add_help_button(self.help_section)
-
-    def _add_help_button(self, section):
-        def on_help__clicked(button):
-            show_section(section)
-
-        self.main_dialog.action_area.set_layout(gtk.BUTTONBOX_END)
-        button = gtk.Button(stock=gtk.STOCK_HELP)
-        button.connect('clicked', on_help__clicked)
-        self.main_dialog.action_area.add(button)
-        self.main_dialog.action_area.set_child_secondary(button, True)
-        button.show()
-
-    def _on_main_dialog__confirm(self, dialog, retval):
-        if isinstance(self.conn, StoqlibTransaction):
-            self.conn.retval = retval
-
     def _get_title_format(self):
         if self.visual_mode:
             return _(u"Details of %s")
@@ -283,15 +284,33 @@ class BaseEditor(BaseEditorSlave):
         """
         Cancel the dialog.
         """
-        self.main_dialog.cancel()
+        # self.on_cancel() should return a considered failure value
+        self.retval = self.on_cancel()
+        self.main_dialog.close()
+
+        log.info("%s: Closed (cancelled), retval=%r" % (
+            self.__class__.__name__, self.retval))
 
     def confirm(self):
         """
         Confirm the dialog.
         """
         if not self.is_valid or self._confirm_disabled:
-            return
-        self.main_dialog.confirm()
+            return False
+        if not self.validate_confirm():
+            return False
+
+        # self.on_confirm() should return a considered success
+        # value. It can be an integer or a model object.
+        self.retval = self.on_confirm()
+        self.main_dialog.close()
+        if isinstance(self.conn, StoqlibTransaction):
+            self.conn.retval = self.retval
+
+        log.info("%s: Closed (confirmed), retval=%r" % (
+            self.__class__.__name__, self.retval))
+
+        return True
 
     def enable_ok(self):
         """
@@ -326,34 +345,41 @@ class BaseEditor(BaseEditorSlave):
         """
         self.main_dialog.set_confirm_widget(widget_name)
 
-    def add_message_bar(self, message, message_type=gtk.MESSAGE_INFO):
-        """Adds a message bar to the top of the search results
+    def set_message(self, message, message_type=gtk.MESSAGE_INFO):
+        """Sets a message for this editor
         :param message: message to add
         :param message_type: type of message to add
         """
-        self._message_bar = MessageBar(message, message_type)
-        toplevel = self.main_dialog.get_toplevel()
-        widget = toplevel.get_child()
-        widget.pack_start(self._message_bar, False, False)
-        widget.reorder_child(self._message_bar, 0)
-        self._message_bar.show_all()
-        return self._message_bar
+        self.main_dialog.set_message(message, message_type)
 
-    def remove_message_bar(self):
-        """Removes the message bar if there was one added"""
-        if not self._message_bar:
-            return
-        self._message_bar.destroy()
-        self._message_bar = None
+    # RunnableView
+    # This delegate everything to self.main_dialog
 
-    def has_message_bar(self):
-        return self._message_bar is not None
+    def close(self):
+        self.main_dialog.close()
+
+    def run(self):
+        self.main_dialog.run()
+
+    def get_current_toplevel(self):
+        return self.main_dialog.get_current_toplevel()
+
+    def destroy(self):
+        self.main_dialog.destroy()
+
+    def set_transient_for(self, window):
+        self.main_dialog.set_transient_for(window)
 
     # Callbacks
 
+    def _on_main_dialog__cancel(self, dialog, retval):
+        self.cancel()
+
+    def _on_main_dialog__confirm(self, dialog, retval):
+        return self.confirm()
+
     def _validation_function(self, is_valid):
         self.refresh_ok(is_valid)
-        self.is_valid = is_valid
 
 
 class BaseRelationshipEditorSlave(GladeSlaveDelegate):
@@ -376,9 +402,10 @@ class BaseRelationshipEditorSlave(GladeSlaveDelegate):
     model_type = None
     editor = None
 
-    def __init__(self, conn, parent=None):
+    def __init__(self, conn, parent=None, visual_mode=False):
         self._parent = parent
         self.conn = conn
+        self.visual_mode = visual_mode
         GladeSlaveDelegate.__init__(self, gladefile=self.gladefile)
         self._setup_widgets()
 
@@ -414,6 +441,11 @@ class BaseRelationshipEditorSlave(GladeSlaveDelegate):
 
         self.relations_list.add_items(self.get_relations())
 
+        if self.visual_mode:
+            self.target_combo.set_sensitive(False)
+            self.add_button.set_sensitive(False)
+            self.relations_list.set_list_type(ListType.READONLY)
+
     def get_targets(self):
         """Returns a list of valid taret objects.
 
@@ -484,7 +516,7 @@ class BaseRelationshipEditorSlave(GladeSlaveDelegate):
 
     def on_target_combo__content_changed(self, widget):
         has_selected = self.target_combo.read() is not None
-        self.add_button.set_sensitive(has_selected)
+        self.add_button.set_sensitive(has_selected and not self.visual_mode)
 
     def _on_edit_item__clicked(self, list, item):
         result = self._run_editor(item)
