@@ -45,9 +45,9 @@ class SellableCategoryEditor(BaseEditor):
                      'tax_constant',
                      'category')
 
-    def __init__(self, conn, model, parent_category=None):
+    def __init__(self, conn, model, parent_category=None, visual_mode=False):
         self._parent_category = parent_category
-        BaseEditor.__init__(self, conn, model)
+        BaseEditor.__init__(self, conn, model, visual_mode)
         self.set_description(self.model.get_description())
 
     #
@@ -94,7 +94,8 @@ class SellableCategoryEditor(BaseEditor):
             self.tax_check.set_active(self.model.tax_constant is None)
 
     def on_confirm(self):
-        self.commission_slave.confirm()
+        for slave in self.slaves.values():
+            slave.on_confirm()
 
         if self.markup_check.get_active():
             self.model.suggested_markup = None
@@ -153,7 +154,10 @@ class SellableCategoryEditor(BaseEditor):
         self.proxy.update('tax_constant')
 
     def on_category__content_changed(self, widget):
-        self._update_widgets()
+        # slaves was not set yet, we have to wait (setup slaves will call
+        # _update_widgets
+        if hasattr(self, 'commission_slave'):
+            self._update_widgets()
 
     def on_description__validate(self, widget, value):
         if not self.model.check_category_description_exists(value, self.conn):
