@@ -24,7 +24,7 @@
 
 import gtk
 
-from kiwi.datatypes import currency
+from kiwi.currency import currency
 
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.purchase import PurchaseOrder
@@ -42,7 +42,7 @@ class _PaymentsEditor(BaseEditor):
     gladefile = "HolderTemplate"
     title = _('Payments Editor')
     model_type = object
-    size = (750, 400)
+    size = (-1, 400)
 
     def __init__(self, conn, model):
         register_payment_slaves()
