@@ -27,14 +27,20 @@ from decimal import Decimal
 import sys
 
 import gtk
-from kiwi.datatypes import ValidationError, currency
+from kiwi.currency import currency
+from kiwi.datatypes import ValidationError
+from kiwi.enums import ListType
+from kiwi.ui.forms import TextField
 from kiwi.ui.widgets.list import Column, SummaryLabel
+
 from stoqdrivers.enum import TaxType
 
+from stoqlib.api import api
 from stoqlib.domain.person import Supplier
 from stoqlib.domain.product import (ProductSupplierInfo, Product,
                                     ProductComponent,
-                                    ProductQualityTest, Storable)
+                                    ProductQualityTest, Storable,
+                                    ProductManufacturer)
 from stoqlib.domain.sellable import (Sellable,
                                      SellableTaxConstant)
 from stoqlib.domain.views import ProductFullStockView
@@ -46,7 +52,7 @@ from stoqlib.gui.editors.sellableeditor import SellableEditor
 from stoqlib.gui.slaves.productslave import (ProductDetailsSlave,
                                              ProductTaxSlave)
 from stoqlib.lib.defaults import quantize
-from stoqlib.lib.message import info, yesno
+from stoqlib.lib.message import info, yesno, warning
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.formatters import get_formatted_cost
@@ -112,11 +118,12 @@ class _TemporaryProductComponent(object):
 class ProductComponentSlave(BaseEditorSlave):
     gladefile = 'ProductComponentSlave'
     model_type = _TemporaryProductComponent
+    proxy_widgets = ['production_time']
 
-    def __init__(self, conn, product=None):
+    def __init__(self, conn, product=None, visual_mode=False):
         self._product = product
         self._remove_component_list = []
-        BaseEditorSlave.__init__(self, conn, model=None)
+        BaseEditorSlave.__init__(self, conn, model=None, visual_mode=visual_mode)
         self._setup_widgets()
 
     def _get_columns(self):
@@ -137,17 +144,26 @@ class ProductComponentSlave(BaseEditorSlave):
                 ]
 
     def _setup_widgets(self):
-        self.component_combo.prefill(list(self._get_products()))
+        component_list = list(self._get_products())
+        if component_list:
+            self.component_combo.prefill(component_list)
+        else:
+            self.sort_components_check.set_sensitive(False)
 
         self.component_tree.set_columns(self._get_columns())
         self._populate_component_tree()
-        self.component_label = SummaryLabel(klist=self.component_tree,
-                                            column='total_production_cost',
-                                            label='<b>%s</b>' % _(u'Total:'),
-                                            value_format='<b>%s</b>')
+        self.component_label = SummaryLabel(
+            klist=self.component_tree,
+            column='total_production_cost',
+            label='<b>%s</b>' % api.escape(_(u'Total:')),
+            value_format='<b>%s</b>')
         self.component_label.show()
         self.component_tree_vbox.pack_start(self.component_label, False)
         self._update_widgets()
+        if self.visual_mode:
+            self.component_combo.set_sensitive(False)
+            self.add_button.set_sensitive(False)
+            self.sort_components_check.set_sensitive(False)
 
     def _get_products(self, sort_by_name=True):
         # FIXME: This is a kind of workaround until we have the
@@ -284,9 +300,7 @@ class ProductComponentSlave(BaseEditorSlave):
     #
 
     def setup_proxies(self):
-        self.proxy = self.add_proxy(self._product, ['production_time'])
-        # FIXME:
-        self.production_time.set_value(self._product.production_time)
+        self.proxy = self.add_proxy(self._product, self.proxy_widgets)
 
     def create_model(self, conn):
         return _TemporaryProductComponent(product=self._product)
@@ -319,12 +333,18 @@ class ProductComponentSlave(BaseEditorSlave):
         self._update_widgets()
 
     def on_component_tree__selection_changed(self, widget, value):
+        if self.visual_mode:
+            return
         self._update_widgets()
 
     def on_component_tree__row_activated(self, widget, selected):
+        if self.visual_mode:
+            return
         self._edit_component()
 
     def on_component_tree__row_expanded(self, widget, value):
+        if self.visual_mode:
+            return
         self._update_widgets()
 
     def on_add_button__clicked(self, widget):
@@ -405,31 +425,44 @@ class QualityTestEditor(BaseEditor):
 
 class ProductQualityTestSlave(ModelListSlave):
     model_type = ProductQualityTest
+    editor_class = QualityTestEditor
+    columns = [
+        Column('description', title=_(u'Description'),
+               data_type=str, expand=True),
+        Column('type_str', title=_(u'Type'), data_type=str),
+        Column('success_value_str', title=_(u'Success Value'), data_type=str),
+        ]
 
-    def __init__(self, conn, product):
+    def __init__(self, parent, conn, product, visual_mode=False):
         self._product = product
-        ModelListSlave.__init__(self)
-        self.set_reuse_transaction(self._product.get_connection())
-        self.set_editor_class(QualityTestEditor)
-        self.set_model_type(self.model_type)
+        ModelListSlave.__init__(self, parent)
+        trans = self._product.get_connection()
+        self.set_reuse_transaction(trans)
+        if visual_mode:
+            self.set_list_type(ListType.READONLY)
+
+        self.refresh()
 
     #
     #   ListSlave Implementation
     #
 
-    def get_columns(self):
-        return [Column('description', title=_(u'Description'),
-                        data_type=str, expand=True),
-                Column('type_str', title=_(u'Type'), data_type=str),
-                Column('success_value_str', title=_(u'Success Value'), data_type=str),
-                ]
-
     def populate(self):
         return self._product.quality_tests
 
-    def run_dialog(self, dialog_class, *args, **kwargs):
-        kwargs['product'] = self._product
-        return ModelListSlave.run_dialog(self, dialog_class, *args, **kwargs)
+    def run_editor(self, trans, model):
+        return self.run_dialog(self.editor_class, conn=trans, model=model,
+                               product=self._product)
+
+    def remove_item(self, item):
+        # If the test was used before in a production, it cannot be
+        # removed
+        if not item.can_remove():
+            warning(_(u'You can not remove this test, since it\'s already '
+                            'been used.'))
+            return False
+
+        return ModelListSlave.remove_item(self, item)
 
 
 #
@@ -493,9 +526,9 @@ class ProductSupplierSlave(BaseRelationshipEditorSlave):
     editor = ProductSupplierEditor
     model_type = ProductSupplierInfo
 
-    def __init__(self, conn, product):
+    def __init__(self, conn, product, visual_mode=False):
         self._product = product
-        BaseRelationshipEditorSlave.__init__(self, conn)
+        BaseRelationshipEditorSlave.__init__(self, conn, visual_mode=visual_mode)
 
         suggested = sysparam(conn).SUGGESTED_SUPPLIER
         if suggested is not None:
@@ -503,7 +536,7 @@ class ProductSupplierSlave(BaseRelationshipEditorSlave):
 
     def get_targets(self):
         suppliers = Supplier.get_active_suppliers(self.conn)
-        return [(s.person.name, s) for s in suppliers]
+        return api.for_person_combo(suppliers)
 
     def get_relations(self):
         return self._product.get_suppliers_info()
@@ -585,6 +618,12 @@ class ProductEditor(SellableEditor):
 
     _model_created = False
 
+    def __init__(self, conn, model, visual_mode=False):
+        SellableEditor.__init__(self, conn, model, visual_mode=visual_mode)
+        # This can't be done in setup_slaves() as we need to access
+        # self.main_dialog when setting up the quality test slave
+        self._add_extra_tabs()
+
     def get_taxes(self):
         query = (SellableTaxConstant.q.tax_type != int(TaxType.SERVICE))
         constants = SellableTaxConstant.select(query,
@@ -595,8 +634,9 @@ class ProductEditor(SellableEditor):
         text = ''
         if self.statuses_combo.read() == Sellable.STATUS_UNAVAILABLE:
             text = ("<b>%s</b>"
-                    % _("This status changes automatically when the\n"
-                        "product is purchased or an inicial stock is added."))
+                    % api.escape(
+                _("This status changes automatically when the\n"
+                  "product is purchased or an inicial stock is added.")))
 
         self.status_unavailable_label.set_text(text)
 
@@ -606,19 +646,21 @@ class ProductEditor(SellableEditor):
 
     def setup_slaves(self):
         details_slave = ProductDetailsSlave(self.conn, self.model.sellable,
-                                            self.db_form)
+                                            self.db_form, self.visual_mode)
         self.add_extra_tab(_(u'Details'), details_slave)
 
+    def _add_extra_tabs(self):
         for tabname, tabslave in self.get_extra_tabs():
             self.add_extra_tab(tabname, tabslave)
 
     def get_extra_tabs(self):
         extra_tabs = []
 
-        suppliers_slave = ProductSupplierSlave(self.conn, self.model)
+        suppliers_slave = ProductSupplierSlave(self.conn, self.model,
+                                               self.visual_mode)
         extra_tabs.append((_(u'Suppliers'), suppliers_slave))
 
-        tax_slave = ProductTaxSlave(self.conn, self.model)
+        tax_slave = ProductTaxSlave(self.conn, self.model, self.visual_mode)
         extra_tabs.append((_(u'Taxes'), tax_slave))
         return extra_tabs
 
@@ -660,9 +702,11 @@ class ProductionProductEditor(ProductEditor):
         return model
 
     def get_extra_tabs(self):
-        self._component_slave = ProductComponentSlave(self.conn, self.model)
-        tax_slave = ProductTaxSlave(self.conn, self.model)
-        quality_slave = ProductQualityTestSlave(self.conn, self.model)
+        self._component_slave = ProductComponentSlave(self.conn, self.model,
+                                                      self.visual_mode)
+        tax_slave = ProductTaxSlave(self.conn, self.model, self.visual_mode)
+        quality_slave = ProductQualityTestSlave(self, self.conn, self.model,
+                                                self.visual_mode)
         return [(_(u'Components'), self._component_slave),
                 (_(u'Taxes'), tax_slave),
                 (_(u'Quality'), quality_slave),
@@ -698,3 +742,42 @@ class ProductStockEditor(BaseEditor):
         details_slave = ProductDetailsSlave(self.conn, self.model.sellable)
         details_slave.hide_stock_details()
         self.attach_slave('place_holder', details_slave)
+
+
+class ProductManufacturerEditor(BaseEditor):
+    model_name = _('Manufacturer')
+    model_type = ProductManufacturer
+    confirm_widgets = ['name']
+
+    fields = dict(
+        name=TextField(_('Name'), proxy=True, mandatory=True),
+        )
+
+    def create_model(self, trans):
+        return ProductManufacturer(name='', connection=trans)
+
+    def setup_proxies(self):
+        self.name.grab_focus()
+
+    #
+    # Kiwi Callbacks
+    #
+
+    def on_name__validate(self, widget, new_name):
+        if not new_name:
+            return ValidationError(
+                _("The manufacturer should have a name."))
+        if self.model.check_unique_value_exists('name', new_name):
+            return ValidationError(
+                _("The manufacturer '%s' already exists.") % new_name)
+
+
+def test_product():
+    ec = api.prepare_test()
+    product = ec.create_product()
+    run_dialog(ProductEditor,
+               parent=None, conn=ec.trans, model=product)
+
+
+if __name__ == '__main__':
+    test_product()
