@@ -44,8 +44,8 @@ class UserProfileEditor(BaseEditor):
     proxy_widgets = ('profile_name', )
     help_section = 'user-profile'
 
-    def __init__(self, conn, model):
-        BaseEditor.__init__(self, conn, model)
+    def __init__(self, conn, model, visual_mode=False):
+        BaseEditor.__init__(self, conn, model, visual_mode)
         self.set_description(self.model.name)
 
     #
