@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2011 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2005-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,9 @@
 import sys
 
 import gtk
-from kiwi.datatypes import ValidationError, currency
+from kiwi.currency import currency
+from kiwi.datatypes import ValidationError
+from kiwi.ui.forms import PriceField, TextField
 from kiwi.ui.objectlist import Column
 from stoqdrivers.enum import TaxType, UnitType
 
@@ -39,7 +41,7 @@ from stoqlib.domain.sellable import (SellableCategory, Sellable,
                                      SellableTaxConstant,
                                      ClientCategoryPrice)
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.base.lists import ModelListDialog
+from stoqlib.gui.base.lists import ModelListDialog, ModelListSlave
 from stoqlib.gui.databaseform import DatabaseForm
 from stoqlib.gui.editors.baseeditor import (BaseEditor,
                                             BaseRelationshipEditorSlave)
@@ -65,14 +67,13 @@ _DEMO_PRODUCT_LIMIT = 30
 
 
 class SellableTaxConstantEditor(BaseEditor):
-    gladefile = 'SellableTaxConstantEditor'
     model_type = SellableTaxConstant
     model_name = _('Taxes and Tax rates')
-    proxy_widgets = ('description',
-                     'tax_value')
 
-    def __init__(self, conn, model=None):
-        BaseEditor.__init__(self, conn, model)
+    fields = dict(
+        description=TextField(_('Name'), proxy=True, mandatory=True),
+        tax_value=PriceField(_('Value'), proxy=True, mandatory=True),
+        )
 
     #
     # BaseEditor
@@ -84,20 +85,10 @@ class SellableTaxConstantEditor(BaseEditor):
                                    description=u'',
                                    connection=conn)
 
-    def setup_proxies(self):
-        self.proxy = self.add_proxy(self.model,
-                                    SellableTaxConstantEditor.proxy_widgets)
 
-
-class SellableTaxConstantsDialog(ModelListDialog):
-
-    # ModelListDialog
+class SellableTaxConstantsListSlave(ModelListSlave):
     model_type = SellableTaxConstant
     editor_class = SellableTaxConstantEditor
-    size = (500, 300)
-    title = _("Taxes")
-
-    # ListDialog
     columns = [
         Column('description', _('Description'), data_type=str, expand=True),
         Column('value', _('Tax rate'), data_type=str, width=150),
@@ -122,6 +113,12 @@ class SellableTaxConstantsDialog(ModelListDialog):
             SellableTaxConstant.delete(model.id, connection=trans)
 
 
+class SellableTaxConstantsDialog(ModelListDialog):
+    list_slave_class = SellableTaxConstantsListSlave
+    size = (500, 300)
+    title = _("Taxes")
+
+
 class BasePriceEditor(BaseEditor):
     gladefile = 'SellablePriceEditor'
     proxy_widgets = ('cost', 'markup', 'max_discount', 'price')
@@ -183,7 +180,7 @@ class SellablePriceEditor(BasePriceEditor):
 
     def on_confirm(self):
         slave = self.get_slave('on_commission_data_holder')
-        slave.confirm()
+        slave.on_confirm()
         return self.model
 
 
@@ -210,9 +207,9 @@ class CategoryPriceSlave(BaseRelationshipEditorSlave):
     editor = CategoryPriceEditor
     model_type = ClientCategoryPrice
 
-    def __init__(self, conn, sellable):
+    def __init__(self, conn, sellable, visual_mode=False):
         self._sellable = sellable
-        BaseRelationshipEditorSlave.__init__(self, conn)
+        BaseRelationshipEditorSlave.__init__(self, conn, visual_mode=visual_mode)
 
     def get_targets(self):
         cats = ClientCategory.select(connection=self.conn).orderBy('name')
@@ -280,25 +277,25 @@ class SellableEditor(BaseEditor):
                         'unit_combo')
     proxy_widgets = (sellable_tax_widgets + sellable_widgets)
 
-    def __init__(self, conn, model=None):
+    def __init__(self, conn, model=None, visual_mode=False):
         is_new = not model
         self._sellable = None
         self._demo_mode = sysparam(conn).DEMO_MODE
         self._requires_weighing_text = (
-            "<b>%s</b>" % _("This unit type requires weighing"))
+            "<b>%s</b>" % api.escape(_("This unit type requires weighing")))
 
         if self.ui_form_name:
             self.db_form = DatabaseForm(conn, self.ui_form_name)
         else:
             self.db_form = None
-        BaseEditor.__init__(self, conn, model)
+        BaseEditor.__init__(self, conn, model, visual_mode)
         self.enable_window_controls()
         if self._demo_mode:
             self._add_demo_warning()
 
         # code suggestion
         edit_code_product = sysparam(self.conn).EDIT_CODE_PRODUCT
-        self.code.set_sensitive(not edit_code_product)
+        self.code.set_sensitive(not edit_code_product and not self.visual_mode)
         if not self.code.read():
             code = u'%d' % self._sellable.id
             self.code.update(code)
@@ -318,7 +315,7 @@ class SellableEditor(BaseEditor):
                                     ])
         self.setup_widgets()
 
-        if not is_new:
+        if not is_new and not self.visual_mode:
             if self._sellable.is_closed():
                 self._add_reopen_button()
             elif self._sellable.can_close():
@@ -328,12 +325,13 @@ class SellableEditor(BaseEditor):
                 self._add_delete_button()
 
         self.set_main_tab_label(self.model_name)
-        price_slave = CategoryPriceSlave(self.conn, self.model.sellable)
+        price_slave = CategoryPriceSlave(self.conn, self.model.sellable,
+                                         self.visual_mode)
         self.add_extra_tab(_(u'Category Prices'), price_slave)
         self._setup_ui_forms()
 
     def _add_demo_warning(self):
-        self.add_message_bar(
+        self.set_message(
             _("This is a demostration mode of Stoq, you cannot create more than %d products.\n"
               "To avoid this limitation, enable production mode.") % (
             _DEMO_PRODUCT_LIMIT))
@@ -504,7 +502,7 @@ class SellableEditor(BaseEditor):
             return
         # We don't call self.confirm since it will call validate_confirm
         self.cancel()
-        self.main_dialog.retval = True
+        self.retval = True
 
     def _on_close_sellable_button__clicked(self, button,
                                            parent_button_label=None):
@@ -573,3 +571,15 @@ class SellableEditor(BaseEditor):
     def on_cost__validate(self, entry, value):
         if value <= 0:
             return ValidationError(_("Cost cannot be zero or negative"))
+
+
+def test_sellable_tax_constant():
+    ec = api.prepare_test()
+    tax_constant = api.sysparam(ec.trans).DEFAULT_PRODUCT_TAX_CONSTANT
+    run_dialog(SellableTaxConstantEditor,
+                       parent=None, conn=ec.trans, model=tax_constant)
+    print tax_constant
+
+
+if __name__ == '__main__':
+    test_sellable_tax_constant()
