@@ -25,7 +25,8 @@
 
 import datetime
 
-from kiwi.datatypes import currency, ValidationError
+from kiwi.currency import currency
+from kiwi.datatypes import ValidationError
 
 from stoqdrivers.enum import TaxType
 
@@ -87,7 +88,8 @@ class ServiceEditor(SellableEditor):
         return [(_(u'No tax'), None), (service_tax.description, service_tax)]
 
     def setup_slaves(self):
-        details_slave = SellableDetailsSlave(self.conn, self.model.sellable)
+        details_slave = SellableDetailsSlave(self.conn, self.model.sellable,
+                                             visual_mode=self.visual_mode)
         self.attach_slave('slave_holder', details_slave)
 
     def setup_widgets(self):
