@@ -45,8 +45,8 @@ class StationEditor(BaseEditor):
     #
     # BaseEditor Hooks
     #
-    def __init__(self, conn, model=None):
-        BaseEditor.__init__(self, conn, model)
+    def __init__(self, conn, model=None, visual_mode=False):
+        BaseEditor.__init__(self, conn, model, visual_mode)
 
         # do not let the user change the current station
         if model and get_current_station(conn) == model:
@@ -62,7 +62,7 @@ class StationEditor(BaseEditor):
 
     def setup_proxies(self):
         branches = Branch.select(connection=self.conn)
-        self.branch.prefill(api.for_combo(branches))
+        self.branch.prefill(api.for_person_combo(branches))
 
         self.add_proxy(self.model, StationEditor.proxy_widgets)
         if not self.edit_mode:
