@@ -26,7 +26,8 @@
 import datetime
 from datetime import timedelta
 
-from kiwi.datatypes import ValidationError, currency
+from kiwi.currency import currency
+from kiwi.datatypes import ValidationError
 from kiwi.python import Settable
 from kiwi.ui.objectlist import Column, ColoredColumn, SummaryLabel
 
@@ -200,7 +201,7 @@ class TillClosingEditor(BaseEditor):
         summary_day_history = SummaryLabel(
                 klist=self.day_history,
                 column='value',
-                label='<b>%s</b>' % _(u'Total balance:'))
+                label='<b>%s</b>' % api.escape(_(u'Total balance:')))
         summary_day_history.show()
         self.day_history_box.pack_start(summary_day_history, False)
 
@@ -373,10 +374,8 @@ class CashAdvanceEditor(BaseEditor):
         return self.employee_combo.get_selected_label()
 
     def _setup_widgets(self):
-        # FIXME: Implement and use IDescribable on Employee
-        employees = [(e.person.name, e)
-                     for e in Employee.select(connection=self.conn)]
-        self.employee_combo.prefill(employees)
+        employees = Employee.select(connection=self.conn)
+        self.employee_combo.prefill(api.for_person_combo(employees))
         self.employee_combo.set_active(0)
 
     #
@@ -387,6 +386,7 @@ class CashAdvanceEditor(BaseEditor):
         till = Till.get_current(self.conn)
         return Settable(employee=None,
                         payment=None,
+                        # FIXME: should send in consts.now()
                         open_date=None,
                         till=till,
                         balance=till.get_balance(),
