@@ -78,15 +78,14 @@ def _flush_interface():
 class FiscalPrinterHelper(gobject.GObject):
     """
 
-    Signals
-    =======
-      - B{till-status-changed} (bool, bool):
-        - Emitted when the status of the till has changed. it can be
-          open/closed, and while open/closed, it can be blocked
+    Signals:
 
-      - B{ecf-changed} (bool):
-        - Emitted fater the check_till method is called, indicating if a
-          ecf printer is present and functional.
+    * *till-status-changed* (bool, bool): Emitted when the status of
+      the till has changed. it can be open/closed, and while open/closed,
+      it can be blocked
+
+    * *ecf-changed* (bool): Emitted fater the check_till method is called,
+      indicating if a ecf printer is present and functional.
 
     """
                                 # Closed, Blocked
@@ -115,7 +114,7 @@ class FiscalPrinterHelper(gobject.GObject):
         try:
             model = run_dialog(TillOpeningEditor, self._parent, trans)
         except TillError, e:
-            warning(e)
+            warning(str(e))
             model = None
 
         retval = api.finish_transaction(trans, model)
@@ -158,6 +157,7 @@ class FiscalPrinterHelper(gobject.GObject):
 
         if not model:
             api.finish_transaction(trans, model)
+            trans.close()
             return
 
         # TillClosingEditor closes the till
@@ -284,7 +284,7 @@ class FiscalPrinterHelper(gobject.GObject):
             HasOpenCouponEvent.emit()
             return True
         except (DeviceError, DriverError), e:
-            warning(e)
+            warning(str(e))
             self.emit('ecf-changed', False)
             return False
 
@@ -293,7 +293,7 @@ class FiscalPrinterHelper(gobject.GObject):
             self._check_needs_closing()
             self.emit('ecf-changed', True)
         except (DeviceError, DriverError), e:
-            warning(e)
+            warning(str(e))
             self.emit('ecf-changed', False)
 
     def run_initial_checks(self):
