@@ -26,7 +26,7 @@
 from decimal import Decimal
 import datetime
 
-from kiwi.datatypes import currency
+from kiwi.currency import currency
 from kiwi.enums import SearchFilterPosition
 from kiwi.ui.search import ComboSearchFilter
 from kiwi.ui.objectlist import SearchColumn, ColoredColumn, Column
