@@ -29,7 +29,7 @@ from decimal import Decimal
 
 import gtk
 
-from kiwi.datatypes import currency
+from kiwi.currency import currency
 from kiwi.ui.objectlist import SearchColumn
 
 from stoqlib.domain.payment.payment import Payment
