@@ -59,7 +59,6 @@ _ = stoqlib_gettext
 class BasePersonSearch(SearchEditor):
     size = (-1, 500)
     title = _('Person Search')
-    editor_class = None
     table = None
     interface = None
     editor_class = None
@@ -75,8 +74,8 @@ class BasePersonSearch(SearchEditor):
         self.set_searchbar_labels(self.search_lbl_text)
         self.set_result_strings(*self.result_strings)
 
-    def run_dialog(self, editor_class, parent, *args):
-        return run_person_role_dialog(editor_class, parent, *args)
+    def run_dialog(self, editor_class, parent, *args, **kwargs):
+        return run_person_role_dialog(editor_class, parent, *args, **kwargs)
 
 
 class EmployeeSearch(BasePersonSearch):
@@ -145,7 +144,8 @@ class SupplierSearch(BasePersonSearch):
                              sorted=True, expand=True),
                 SearchColumn('phone_number', _('Phone Number'), str,
                              format_func=format_phone_number, width=110),
-                SearchColumn('fancy_name', _('Fancy Name'), str,
+                # Translators: http://en.wikipedia.org/wiki/Doing_business_as
+                SearchColumn('fancy_name', _('DBA'), str,
                              width=180),
                 SearchColumn('cnpj', self.company_doc_l10n.label,
                              str, width=140)]
