@@ -26,7 +26,7 @@
 from decimal import Decimal
 
 import gtk
-from kiwi.datatypes import currency
+from kiwi.currency import currency
 from kiwi.enums import SearchFilterPosition
 from kiwi.db.query import DateQueryState, DateIntervalQueryState
 from kiwi.ui.search import ComboSearchFilter, DateSearchFilter, Today
@@ -41,11 +41,10 @@ from stoqlib.domain.views import (ProductQuantityView,
                                   ProductFullStockItemView, SoldItemView,
                                   ProductFullWithClosedStockView,
                                   ProductClosedStockView)
-from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.base.gtkadds import change_button_appearance
 from stoqlib.gui.base.search import (SearchDialog, SearchEditor,
                                      SearchDialogPrintSlave)
-from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporterDialog
+from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporter
 from stoqlib.gui.editors.producteditor import (ProductEditor,
                                                ProductStockEditor)
 from stoqlib.gui.printing import print_report
@@ -166,6 +165,10 @@ class ProductSearch(SearchEditor):
                              data_type=str, width=120),
                 SearchColumn('description', title=_(u'Description'),
                              expand=True, data_type=str),
+                SearchColumn('manufacturer', title=_('Manufacturer'), data_type=str,
+                             visible=False),
+                SearchColumn('model', title=_('Model'), data_type=str,
+                             visible=False),
                 SearchColumn('location', title=_('Location'), data_type=str,
                               visible=False)]
         # The price/cost columns must be controlled by hide_cost_column and
@@ -176,7 +179,7 @@ class ProductSearch(SearchEditor):
             cols.append(SearchColumn('cost', _('Cost'), data_type=currency,
                                      format_func=get_formatted_cost, width=90))
         if not self.hide_price_column:
-            cols.append(SearchColumn('price', title=_('Price'),
+            cols.append(Column('price', title=_('Price'),
                                      data_type=currency, width=90))
 
         cols.append(Column('stock', title=_('Stock'),
@@ -203,8 +206,8 @@ class ProductSearch(SearchEditor):
     #
 
     def _on_export_csv_button__clicked(self, widget):
-        run_dialog(SpreadSheetExporterDialog, self,
-                   object_list=self.results,
+        sse = SpreadSheetExporter()
+        sse.export(object_list=self.results,
                    name=_('Product'),
                    filename_prefix=_('product'))
 
@@ -363,9 +366,10 @@ class ProductStockSearch(SearchEditor):
 
     def setup_widgets(self):
         difference_label = gtk.Label()
-        difference_label.set_markup("<small><b>%s</b></small>"
-                                         % _(u"The DIFFERENCE column is equal "
-                                             "IN STOCK minus MINIMUM columns"))
+        difference_label.set_markup(
+            "<small><b>%s</b></small>"
+            % api.escape(_(u"The DIFFERENCE column is equal "
+                           "IN STOCK minus MINIMUM columns")))
         difference_label.show()
         self.search.search.pack_end(difference_label, False, False, 6)
 
@@ -396,6 +400,10 @@ class ProductStockSearch(SearchEditor):
                              data_type=str, width=100),
                 SearchColumn('description', title=_('Description'), data_type=str,
                              expand=True, sorted=True),
+                SearchColumn('manufacturer', title=_('Manufacturer'), data_type=str,
+                             visible=False),
+                SearchColumn('model', title=_('Model'), data_type=str,
+                             visible=False),
                 SearchColumn('location', title=_('Location'), data_type=str,
                              visible=False),
                 SearchColumn('maximum_quantity', title=_('Maximum'),
