@@ -44,7 +44,7 @@ class BranchDetailsSlave(BaseEditorSlave):
 
     def _setup_manager_entry(self):
         employees = Employee.get_active_employees(self.conn)
-        self.manager.prefill(api.for_combo(employees))
+        self.manager.prefill(api.for_person_combo(employees))
 
     def _setup_crt_combo(self):
         self.crt.prefill(self.crt_options)
