@@ -32,7 +32,8 @@ from decimal import Decimal
 import gtk
 from kiwi import ValueUnset
 from kiwi.component import get_utility
-from kiwi.datatypes import format_price, currency, ValidationError
+from kiwi.currency import format_price, currency
+from kiwi.datatypes import ValidationError
 from kiwi.python import Settable
 from kiwi.utils import gsignal
 from kiwi.ui.delegates import GladeSlaveDelegate
@@ -108,7 +109,7 @@ class _TemporaryBankData(object):
 # Editors
 #
 
-class BasePaymentDataEditor(BaseEditor):
+class _BasePaymentDataEditor(BaseEditor):
     """A base editor to set payment information.
     """
 
@@ -156,7 +157,7 @@ class BasePaymentDataEditor(BaseEditor):
                                       "a positive number"))
 
 
-class CheckDataEditor(BasePaymentDataEditor):
+class CheckDataEditor(_BasePaymentDataEditor):
     """An editor to set payment information of check payment method.
     """
 
@@ -403,16 +404,13 @@ class BasePaymentMethodSlave(BaseEditorSlave):
 
     gladefile = 'BasePaymentMethodSlave'
     model_type = _BaseTemporaryMethodData
+    data_editor_class = _BasePaymentDataEditor
     slave_holder = 'slave_holder'
     proxy_widgets = ('interval_type_combo',
                      'intervals',
                      'first_duedate',
                      'installments_number')
 
-    # This attribute must be defined in child.
-    # Use BasePaymentDataEditor or one of it's children.
-    _data_editor_class = None
-
     def __init__(self, wizard, parent, conn, order_obj, payment_method,
                  outstanding_value=currency(0), first_duedate=None,
                  installments_number=None):
@@ -435,6 +433,10 @@ class BasePaymentMethodSlave(BaseEditorSlave):
         BaseEditorSlave.__init__(self, conn)
         self.register_validate_function(self._refresh_next)
 
+        # Most of slaves don't have bank information
+        self.bank_combo.hide()
+        self.bank_label.hide()
+
     #
     # Private Methods
     #
@@ -452,7 +454,7 @@ class BasePaymentMethodSlave(BaseEditorSlave):
                                              self.payment_group,
                                              self.method,
                                              self.total_value,
-                                             self._data_editor_class,
+                                             self.data_editor_class,
                                              self.wizard)
         if self.get_slave(BasePaymentMethodSlave.slave_holder):
             self.detach_slave(BasePaymentMethodSlave.slave_holder)
@@ -602,22 +604,24 @@ class BasePaymentMethodSlave(BaseEditorSlave):
 
 
 class BillMethodSlave(BasePaymentMethodSlave):
-    _data_editor_class = BasePaymentDataEditor
-
-    def __init__(self, wizard, parent, conn, sale, payment_method,
-                 outstanding_value=currency(0),
-                 first_duedate=None, installments_number=None):
-        BasePaymentMethodSlave.__init__(self, wizard, parent, conn,
-                                        sale, payment_method,
-                                        outstanding_value=outstanding_value,
-                                        installments_number=installments_number,
-                                        first_duedate=first_duedate)
-        self.bank_label.hide()
-        self.bank_combo.hide()
+    """Bill method slave"""
 
 
 class CheckMethodSlave(BasePaymentMethodSlave):
-    _data_editor_class = CheckDataEditor
+    """Check method slave"""
+
+    data_editor_class = CheckDataEditor
+
+    def __init__(self, wizard, parent, conn, total_amount,
+                 payment_method, outstanding_value=currency(0),
+                 first_duedate=None, installments_number=None):
+        BasePaymentMethodSlave.__init__(self, wizard, parent, conn,
+                                        total_amount, payment_method,
+                                        outstanding_value=outstanding_value,
+                                        installments_number=installments_number,
+                                        first_duedate=first_duedate)
+        self.bank_combo.show()
+        self.bank_label.show()
 
     def _setup_widgets(self):
         printer = get_current_cheque_printer_settings(self.conn)
@@ -632,61 +636,16 @@ class CheckMethodSlave(BasePaymentMethodSlave):
         BasePaymentMethodSlave._setup_widgets(self)
 
 
-class MoneyMethodSlave(BasePaymentMethodSlave):
-    model_type = _BaseTemporaryMethodData
-    _data_editor_class = BasePaymentDataEditor
-
-    def __init__(self, wizard, parent, conn, sale, payment_method,
-                 outstanding_value=currency(0),
-                 first_duedate=None, installments_number=None):
-        BasePaymentMethodSlave.__init__(self, wizard, parent, conn,
-                                        sale, payment_method,
-                                        outstanding_value=outstanding_value,
-                                        installments_number=installments_number,
-                                        first_duedate=first_duedate)
-        self.bank_label.hide()
-        self.bank_combo.hide()
-        self.first_duedate_lbl.hide()
-        self.first_duedate.hide()
-        self.intervals_lbl.hide()
-        self.intervals.hide()
-        self.interval_type_combo.hide()
-        self.installments_number_lbl.hide()
-        self.installments_number.hide()
-
-
 class DepositMethodSlave(BasePaymentMethodSlave):
-    model_type = _BaseTemporaryMethodData
-    _data_editor_class = BasePaymentDataEditor
-
-    def __init__(self, wizard, parent, conn, sale, payment_method,
-                 outstanding_value=currency(0),
-                 first_duedate=None, installments_number=None):
-        BasePaymentMethodSlave.__init__(self, wizard, parent, conn,
-                                        sale, payment_method,
-                                        outstanding_value=outstanding_value,
-                                        installments_number=installments_number,
-                                        first_duedate=first_duedate)
-        self.bank_combo.hide()
-        self.bank_label.hide()
+    """Deposit method slave"""
 
 
 class StoreCreditMethodSlave(BasePaymentMethodSlave):
-    model_type = _BaseTemporaryMethodData
-    _data_editor_class = BasePaymentDataEditor
+    """Store credit method slave"""
 
-    def __init__(self, wizard, parent, conn, total_amount,
-                 payment_method, outstanding_value=currency(0),
-                 first_duedate=None, installments_number=None):
-        BasePaymentMethodSlave.__init__(self, wizard, parent, conn,
-                                        total_amount, payment_method,
-                                        outstanding_value=outstanding_value,
-                                        installments_number=installments_number,
-                                        first_duedate=first_duedate)
-        self.bank_label.hide()
-        self.bank_combo.hide()
-        self.first_duedate_lbl.hide()
-        self.first_duedate.hide()
+
+class MoneyMethodSlave(BasePaymentMethodSlave):
+    """Money method slave"""
 
 
 class CardMethodSlave(BaseEditorSlave):
@@ -857,7 +816,7 @@ class _MultipleMethodEditor(BaseEditor):
     gladefile = 'HolderTemplate'
     model_type = PaymentGroup
     model_name = _(u'Payment')
-    size = (600, 375)
+    size = (-1, 375)
 
     def __init__(self, wizard, parent, conn, order, payment_method,
                  outstanding_value=currency(0)):
@@ -969,9 +928,11 @@ class MultipleMethodSlave(BaseEditorSlave):
         else:
             raise AssertionError
 
+        money_method = PaymentMethod.get_by_name(self.conn, 'money')
+        self._add_method(money_method)
         for method in PaymentMethod.get_creatable_methods(
             self.conn, payment_type, separate=False):
-            if method.method_name == 'multiple':
+            if method.method_name in ['multiple', 'money']:
                 continue
             self._add_method(method)
 
@@ -1182,7 +1143,7 @@ class MultipleMethodSlave(BaseEditorSlave):
 
     def _run_payment_editor(self):
         if self._wizard:
-            toplevel = self._wizard.get_toplevel()
+            toplevel = self._wizard.get_current_toplevel()
         else:
             toplevel = None
         retval = run_dialog(_MultipleMethodEditor, toplevel, self._wizard,
@@ -1265,6 +1226,7 @@ def register_payment_slaves():
     dsm = get_utility(IDomainSlaveMapper)
     conn = api.get_connection()
     for method_name, slave_class in [
+        ('money', MoneyMethodSlave),
         ('bill', BillMethodSlave),
         ('check', CheckMethodSlave),
         ('card', CardMethodSlave),
