@@ -100,8 +100,8 @@ class SaleDiscountSlave(BaseEditorSlave):
 
     def set_max_discount(self, discount):
         """Set the maximum percentage value for a discount.
-        @param discount: the value for a discount.
-        @type discount: L{int} in absolute value like 3
+        :param discount: the value for a discount.
+        :type discount: :class:`int` in absolute value like 3
         """
         self.max_discount = discount
 
@@ -208,8 +208,10 @@ class SaleListToolbar(GladeSlaveDelegate):
         if till is None:
             return info(_(u'You must open the till first.'))
         sale = self.sales.get_selected()
-        retval = return_sale(self.get_parent(), sale, self.conn)
-        api.finish_transaction(self.conn, retval)
+        trans = api.new_transaction()
+        retval = return_sale(self.get_parent(), sale, trans)
+        api.finish_transaction(trans, retval)
+        trans.close()
 
         if retval:
             self.emit('sale-returned', retval)
@@ -242,7 +244,7 @@ class SaleListToolbar(GladeSlaveDelegate):
 
     def on_edit_button__clicked(self, button):
         sale = self.sales.get_selected()
-        self._edit_sale(sale)
+        self.edit(sale)
 
     def on_details_button__clicked(self, button):
         self.show_details()
@@ -330,7 +332,8 @@ class SaleReturnSlave(BaseEditorSlave):
             return ValidationError(_(u"Deduction value can not be greater "
                                       "then the paid value"))
         till_balance = self._till.get_balance()
-        if self._return_data.paid_total > till_balance:
+        value_to_return = self._return_data.paid_total - value
+        if value_to_return > till_balance:
             return ValidationError(_(u'You do not have this value on till.'))
 
     def after_penalty_value__changed(self, *args):
