@@ -24,16 +24,15 @@
 from kiwi.datatypes import ValidationError
 
 from stoqlib.api import api
+from stoqlib.domain.person import Company
 from stoqlib.gui.editors.baseeditor import BaseEditorSlave
-from stoqlib.domain.interfaces import ICompany
 from stoqlib.lib.translation import stoqlib_gettext
 
-
 _ = stoqlib_gettext
 
 
 class CompanyDocumentsSlave(BaseEditorSlave):
-    model_iface = ICompany
+    model_type = Company
     gladefile = 'CompanyDocumentsSlave'
     proxy_widgets = ('cnpj',
                      'fancy_name',
@@ -42,7 +41,7 @@ class CompanyDocumentsSlave(BaseEditorSlave):
 
     def setup_proxies(self):
         self.document_l10n = api.get_l10n_field(self.conn, 'company_document')
-        self.cnpj_lbl.set_label(self.document_l10n.label)
+        self.cnpj_lbl.set_label(self.document_l10n.label + ':')
         self.cnpj.set_mask(self.document_l10n.entry_mask)
         self.proxy = self.add_proxy(self.model,
                                     CompanyDocumentsSlave.proxy_widgets)
@@ -63,7 +62,7 @@ class CompanyDocumentsSlave(BaseEditorSlave):
 
 
 class CompanyEditorTemplate(BaseEditorSlave):
-    model_iface = ICompany
+    model_type = Company
     gladefile = 'BaseTemplate'
 
     def __init__(self, conn, model=None, person_slave=None,
