@@ -34,7 +34,8 @@ import sys
 
 import gtk
 
-from kiwi.datatypes import ValidationError, currency
+from kiwi.currency import currency
+from kiwi.datatypes import ValidationError
 from kiwi.ui.widgets.list import SummaryLabel
 from kiwi.ui.objectlist import SearchColumn
 from kiwi.python import Settable
@@ -113,7 +114,11 @@ class _SellableSearch(SearchEditor):
                    SearchColumn('category_description', title=_('Category'),
                                 data_type=str, width=120),
                    SearchColumn('description', title=_('Description'),
-                                data_type=str, expand=True, sorted=True)]
+                                data_type=str, expand=True, sorted=True),
+                   SearchColumn('manufacturer', title=_('Manufacturer'),
+                                data_type=str, visible=False),
+                   SearchColumn('model', title=_('Model'),
+                                data_type=str, visible=False)]
 
         if 'minimum_quantity' in self._table.columns:
             columns.append(SearchColumn('minimum_quantity',
@@ -157,6 +162,7 @@ class _SellableSearch(SearchEditor):
             # If we created a new object, confirm the dialog automatically
             if obj is None:
                 self.confirm(product)
+                trans.close()
                 return
         trans.close()
 
@@ -297,7 +303,7 @@ class SellableItemStep(WizardEditorStep):
         description = u''
 
         if sellable:
-            description = "<b>%s</b>" % sellable.get_description()
+            description = "<b>%s</b>" % api.escape(sellable.get_description())
             cost = sellable.cost
             quantity = Decimal(1)
             storable = sellable.product_storable
@@ -318,6 +324,7 @@ class SellableItemStep(WizardEditorStep):
 
         has_sellable = bool(sellable)
         self.add_sellable_button.set_sensitive(has_sellable)
+        self.force_validation()
         self.quantity.set_sensitive(has_sellable)
         self.cost.set_sensitive(has_sellable)
 
