@@ -26,7 +26,8 @@
 import datetime
 from decimal import Decimal
 
-from kiwi.datatypes import ValidationError, currency
+from kiwi.currency import currency
+from kiwi.datatypes import ValidationError
 from kiwi.ui.widgets.list import Column
 
 from stoqlib.api import api
@@ -70,12 +71,12 @@ class OpenProductionOrderStep(WizardEditorStep):
 
     def _fill_branch_combo(self):
         branches = Branch.get_active_branches(self.conn)
-        self.branch.prefill(api.for_combo(branches))
+        self.branch.prefill(api.for_person_combo(branches))
 
     def _fill_responsible_combo(self):
         employees = Employee.selectBy(status=Employee.STATUS_NORMAL,
                                       connection=self.conn)
-        self.responsible.prefill(api.for_combo(employees))
+        self.responsible.prefill(api.for_person_combo(employees))
 
     def _setup_widgets(self):
         self._fill_branch_combo()
@@ -122,7 +123,7 @@ class OpenProductionOrderStep(WizardEditorStep):
 class ProductionServiceStep(SellableItemStep):
     model_type = ProductionOrder
     item_table = ProductionService
-    summary_label_text = "<b>%s</b>" % _('Total:')
+    summary_label_text = "<b>%s</b>" % api.escape(_('Total:'))
     summary_label_column = 'quantity'
     sellable_view = ServiceView
 
@@ -206,7 +207,7 @@ class ProductionItemStep(SellableItemStep):
     """ Wizard step for production items selection """
     model_type = ProductionOrder
     item_table = ProductionItem
-    summary_label_text = "<b>%s</b>" % _('Total:')
+    summary_label_text = "<b>%s</b>" % (api.escape(_('Total:')),)
     summary_label_column = 'quantity'
     sellable_view = ProductComponentView
 
