@@ -27,7 +27,8 @@ import datetime
 from decimal import Decimal
 
 import gtk
-from kiwi.datatypes import currency, ValidationError
+from kiwi.currency import currency
+from kiwi.datatypes import ValidationError
 from kiwi.python import Settable
 from kiwi.ui.search import DateSearchFilter
 from kiwi.ui.widgets.list import Column
@@ -77,7 +78,7 @@ class StartQuoteStep(WizardEditorStep):
         self.quote_group.set_text(quote_group)
 
         branches = Branch.get_active_branches(self.conn)
-        self.branch_combo.prefill(api.for_combo(branches))
+        self.branch_combo.prefill(api.for_person_combo(branches))
         self.notes.set_accepts_tab(False)
 
     def post_init(self):
