@@ -30,7 +30,8 @@ import sys
 import gtk
 
 from kiwi.component import get_utility
-from kiwi.datatypes import currency, ValidationError
+from kiwi.currency import currency
+from kiwi.datatypes import ValidationError
 from kiwi.ui.widgets.list import Column
 
 from stoqlib.api import api
@@ -82,11 +83,11 @@ class StartPurchaseStep(WizardEditorStep):
 
     def _fill_supplier_combo(self):
         suppliers = Supplier.get_active_suppliers(self.conn)
-        self.supplier.prefill(api.for_combo(suppliers))
+        self.supplier.prefill(api.for_person_combo(suppliers))
 
     def _fill_branch_combo(self):
         branches = Branch.get_active_branches(self.conn)
-        self.branch.prefill(api.for_combo(branches))
+        self.branch.prefill(api.for_person_combo(branches))
 
     def _setup_widgets(self):
         allow_outdated = sysparam(self.conn).ALLOW_OUTDATED_OPERATIONS
@@ -187,7 +188,7 @@ class PurchaseItemStep(SellableItemStep):
     """ Wizard step for purchase order's items selection """
     model_type = PurchaseOrder
     item_table = PurchaseItem
-    summary_label_text = "<b>%s</b>" % _('Total Ordered:')
+    summary_label_text = "<b>%s</b>" % api.escape(_('Total Ordered:'))
     sellable_editable = True
 
     def _set_expected_receival_date(self, item):
@@ -433,8 +434,8 @@ class FinishPurchaseStep(WizardEditorStep):
         self.add_transporter.set_tooltip_text(_("Add a new transporter"))
         self.edit_transporter.set_tooltip_text(_("Edit the selected transporter"))
 
-        items = api.for_combo(Transporter.get_active_transporters(self.conn))
-        self.transporter.prefill(items)
+        items = Transporter.get_active_transporters(self.conn)
+        self.transporter.prefill(api.for_person_combo(items))
         self.transporter.set_sensitive(bool(items))
         self.edit_transporter.set_sensitive(bool(items))
 
