@@ -26,7 +26,8 @@
 
 import gtk
 from kiwi.component import get_utility
-from kiwi.datatypes import currency, ValidationError
+from kiwi.currency import currency
+from kiwi.datatypes import ValidationError
 from kiwi.python import Settable
 
 from stoqlib.api import api
@@ -34,7 +35,7 @@ from stoqlib.database.exceptions import IntegrityError
 from stoqlib.database.orm import AND
 from stoqlib.domain.events import CreatePaymentEvent
 from stoqlib.domain.fiscal import CfopData
-from stoqlib.domain.person import (ClientView,
+from stoqlib.domain.person import (Client,
                                    CreditProvider, SalesPerson, Transporter)
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.payment import Payment
@@ -42,7 +43,7 @@ from stoqlib.domain.payment.renegotiation import PaymentRenegotiation
 from stoqlib.domain.sale import Sale
 from stoqlib.enums import CreatePaymentStatus
 from stoqlib.exceptions import StoqlibError
-from stoqlib.lib.message import warning, marker
+from stoqlib.lib.message import warning, yesno, marker
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.pluginmanager import get_plugin_manager
 from stoqlib.lib.translation import stoqlib_gettext
@@ -53,11 +54,14 @@ from stoqlib.gui.editors.fiscaleditor import CfopEditor
 from stoqlib.gui.editors.noteeditor import NoteEditor
 from stoqlib.gui.editors.personeditor import ClientEditor, TransporterEditor
 from stoqlib.gui.interfaces import IDomainSlaveMapper
+from stoqlib.gui.printing import print_report
 from stoqlib.gui.slaves.cashchangeslave import CashChangeSlave
 from stoqlib.gui.slaves.paymentmethodslave import SelectPaymentMethodSlave
 from stoqlib.gui.slaves.paymentslave import register_payment_slaves
 from stoqlib.gui.slaves.saleslave import SaleDiscountSlave
 from stoqlib.gui.wizards.personwizard import run_person_role_dialog
+from stoqlib.reporting.boleto import BillReport
+from stoqlib.reporting.booklet import BookletReport
 
 N_ = _ = stoqlib_gettext
 
@@ -299,7 +303,7 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         self.cash_change_slave.update_total_sale_amount()
 
     def _update_widgets(self):
-        has_client = bool(self.model.client)
+        has_client = bool(self.client.get_selected())
         self.pm_slave.method_set_sensitive('store_credit', has_client)
         self.pm_slave.method_set_sensitive('bill', has_client)
 
@@ -308,17 +312,16 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         # FIXME: This should not be using a normal ProxyComboEntry,
         #        we need a specialized widget that does the searching
         #        on demand.
-        clients = ClientView.get_active_clients(self.conn)
-        clients = clients.orderBy('name')
-        items = [(c.name, c.client) for c in clients]
-        self.client.prefill(items)
-        self.client.set_sensitive(len(items))
+
+        clients = Client.get_active_clients(self.conn)
+        self.client.prefill(api.for_person_combo(clients))
+        self.client.set_sensitive(len(self.client.get_model()))
         marker('Filled clients')
 
     def _fill_transporter_combo(self):
         marker('Filling transporters')
         transporters = Transporter.get_active_transporters(self.conn)
-        items = api.for_combo(transporters)
+        items = api.for_person_combo(transporters)
         self.transporter.prefill(items)
         self.transporter.set_sensitive(len(items))
         marker('Filled transporters')
@@ -394,7 +397,7 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
 
         marker('Filling sales persons')
         salespersons = SalesPerson.select(connection=self.conn)
-        self.salesperson.prefill(api.for_combo(salespersons))
+        self.salesperson.prefill(api.for_person_combo(salespersons))
         marker('Finished filling sales persons')
 
         marker('Read parameter')
@@ -523,11 +526,10 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
             self.cfop.select_item_by_data(cfop)
 
     def on_invoice_number__validate(self, widget, value):
-        if value <= 0:
-            return ValidationError(_(u'Invoice number should be positive.'))
-        if value > 999999999:
-            return ValidationError(_(u'Invoice number should be lesser '
-                                      'than 999999999.'))
+        if not 0 < value <= 999999999:
+            return ValidationError(
+                _("Invoice number must be between 1 and 999999999"))
+
         exists = Sale.select(AND(Sale.q.invoice_number == value,
                                  Sale.q.id != self.model.id),
                              connection=self.conn)
@@ -609,8 +611,27 @@ class ConfirmSaleWizard(BaseWizard):
                     invoice_number += 1
             else:
                 break
+
         self.close()
 
+        group = self.model.group
+        # FIXME: This is set too late on Sale.confirm(). If PaymentGroup don't
+        #        have a payer, we won't be able to print bills/booklets.
+        group.payer = self.model.client and self.model.client.person
+
+        booklets = list(group.get_payments_by_method_name('store_credit'))
+        bills = list(group.get_payments_by_method_name('bill'))
+
+        if (booklets and
+            yesno(_("Do you want to print the booklets for this sale?"),
+                  gtk.RESPONSE_YES, _("Print booklets"), _("Don't print"))):
+            print_report(BookletReport, booklets)
+
+        if (bills and BillReport.check_printable(bills) and
+            yesno(_("Do you want to print the bills for this sale?"),
+                  gtk.RESPONSE_YES, _("Print bills"), _("Don't print"))):
+            print_report(BillReport, bills)
+
 
 def test():
     creator = api.prepare_test()
