@@ -30,6 +30,9 @@ from kiwi.environ import environ
 from kiwi.log import Logger
 
 from stoqlib.lib.translation import stoqlib_gettext
+from stoqlib.lib.algorithms import (modulo10,
+                                    modulo11,
+                                    calculaDuploDigito)
 
 _ = stoqlib_gettext
 log = Logger('stoqlib.lib.boleto')
@@ -64,7 +67,7 @@ def custom_property(name, num_length):
             setattr(self, internal_attr, '-'.join(val))
 
         else:
-            raise BoletoException('Wrong value format')
+            raise BoletoException(_('Wrong value format'))
 
     return property(
         lambda self: getattr(self, internal_attr),
@@ -147,7 +150,7 @@ class BankInfo(object):
         num = num.replace('X', str(dv), 1)
         if len(num) != 44:
             raise BoletoException(
-                'Código com %d caracteres' % len(num))
+                _('The barcode must have 44 caracteres, found %d') % len(num))
         return num
 
     @property
@@ -159,7 +162,7 @@ class BankInfo(object):
         raise NotImplementedError
 
     def calculate_dv_barcode(self, line):
-        resto2 = self.modulo11(line, 9, 1)
+        resto2 = modulo11(line, 9, 1)
         if resto2 in [0, 1, 10]:
             dv = 1
         else:
@@ -242,12 +245,11 @@ class BankInfo(object):
         return self._sacado
 
     def _sacado_set(self, list_sacado):
-        if len(list_sacado) > 3:
-            raise BoletoException(u'Número de linhas do sacado maior que 3')
-        for line in list_sacado:
-            if len(line) > 80:
-                raise BoletoException(
-                    u'Linha de sacado possui mais que 80 caracteres')
+        # Just get 3 lines
+        list_sacado = list_sacado[:3]
+        for i, line in enumerate(list_sacado):
+            # Just get the first 80 characters
+            list_sacado[i] = list_sacado[i][:80]
         self._sacado = list_sacado
     sacado = property(_sacado_get, _sacado_set)
 
@@ -265,7 +267,7 @@ class BankInfo(object):
     @property
     def codigo_dv_banco(self):
         num = '%03d' % (self.bank_number, )
-        cod = "%s-%s" % (num, self.modulo11(num))
+        cod = "%s-%s" % (num, modulo11(num))
         return cod
 
     @property
@@ -284,7 +286,7 @@ class BankInfo(object):
         assert linha, "Boleto doesn't have a barcode"
 
         def monta_campo(campo):
-            campo_dv = "%s%s" % (campo, self.modulo10(campo))
+            campo_dv = "%s%s" % (campo, modulo10(campo))
             return "%s.%s" % (campo_dv[0:5], campo_dv[5:])
 
         campo1 = monta_campo(linha[0:4] + linha[19:24])
@@ -306,32 +308,27 @@ class BankInfo(object):
     @classmethod
     def validate_field(cls, field, dv_10=None, func=None):
         if ' ' in field:
-            raise BoletoException(
-                u'Campo não pode ter espaços')
+            raise BoletoException(_('The field cannot have spaces'))
         if '.' in field or ',' in field:
-            raise BoletoException(
-                u'Campo não pode ter pontos ou virgulas')
+            raise BoletoException(_('The field cannot have dots of commas'))
         dv = None
         if '-' in field:
             if field.count('-') != 1:
-                raise BoletoException(
-                    u'Só pode ter um hífen')
+                raise BoletoException(_('More than one hyphen found'))
             field, dv = field.split('-', 1)
             if not dv:
-                raise BoletoException(
-                    u'Digito verificador não pode ser vazio')
+                raise BoletoException(_('Verifier digit cannot be empty'))
         try:
             int(field)
         except ValueError:
-            raise BoletoException(
-                u'Conta precisa ser um número')
+            raise BoletoException(_('Account needs to be a number'))
 
         if dv and dv_10 is not None:
             func = cls.validate_field_func
             if func == 'modulo11':
-                ret = cls.modulo11(field)
+                ret = modulo11(field)
             elif func == 'modulo10':
-                ret = cls.modulo10(field)
+                ret = modulo10(field)
             else:
                 ret = None
 
@@ -343,19 +340,16 @@ class BankInfo(object):
                 elif (ret is not None and
                     str(ret) != dv.lower() and
                     ret < 10):
-                    raise BoletoException(
-                        u'Dígito verificador invalido')
+                    raise BoletoException(_('Invalid verifier digit'))
             else:
                 try:
                     dv = int(dv)
                 except ValueError:
                     raise BoletoException(
-                        u'Dígito verificador tem que ser um número ou %s' % (
-                        dv_10))
+                        _('Verifier digit must be a number or %s') % dv_10)
 
                 if ret is not None and ret != dv:
-                    raise BoletoException(
-                        u'Dígito verificador invalido')
+                    raise BoletoException(_('Invalid verifier digit'))
 
     @classmethod
     def validate_option(cls, option, value):
@@ -365,14 +359,14 @@ class BankInfo(object):
     def formata_numero(numero, tamanho):
         if len(numero) > tamanho:
             raise BoletoException(
-                u'Tamanho do numero maior que o permitido')
+                _('Number length must be less than %s') % tamanho)
         return numero.zfill(tamanho)
 
     @staticmethod
     def formata_texto(texto, tamanho):
         if len(texto) > tamanho:
             raise BoletoException(
-                u'Tamanho do texto maior que o permitido')
+                _('Text length must be less than %s') % tamanho)
         return texto.ljust(tamanho)
 
     @staticmethod
@@ -384,50 +378,6 @@ class BankInfo(object):
         except AttributeError:
             pass
 
-    @staticmethod
-    def modulo10(num):
-        soma = 0
-        peso = 2
-        for i in range(len(num) - 1, -1, -1):
-            parcial = int(num[i]) * peso
-            if parcial > 9:
-                s = "%d" % parcial
-                parcial = int(s[0]) + int(s[1])
-            soma += parcial
-            if peso == 2:
-                peso = 1
-            else:
-                peso = 2
-
-        resto10 = soma % 10
-        if resto10 == 0:
-            modulo10 = 0
-        else:
-            modulo10 = 10 - resto10
-
-        return modulo10
-
-    @staticmethod
-    def modulo11(num, base=9, r=0):
-        soma = 0
-        fator = 2
-        for i in range(len(str(num))).__reversed__():
-            parcial10 = int(num[i]) * fator
-            soma += parcial10
-            if fator == base:
-                fator = 1
-            fator += 1
-        if r == 0:
-            soma = soma * 10
-            digito = soma % 11
-            if digito == 10:
-                digito = 0
-            return digito
-        if r == 1:
-            resto = soma % 11
-            return resto
-
-
 _banks = []
 
 
@@ -453,65 +403,12 @@ class BankBanrisul(BankInfo):
     def __init__(self, **kwargs):
         BankInfo.__init__(self, **kwargs)
 
-    # From http://jrimum.org/bopepo/browser/trunk/src/br/com/nordestefomento/jrimum/bopepo/campolivre/AbstractCLBanrisul.java
-    def calculaDuploDigito(self, seisPrimeirosCamposConcatenados):
-        def sum11(s, lmin, lmax):
-            soma = 0
-            peso = lmin
-            for c in reversed(s):
-                soma += peso * int(c)
-                peso += 1
-                if peso > lmax:
-                    peso = lmin
-            return soma
-        primeiroDV = self.modulo10(seisPrimeirosCamposConcatenados)
-        somaMod11 = sum11(
-            seisPrimeirosCamposConcatenados + str(primeiroDV), 2, 7)
-        restoMod11 = self.calculeRestoMod11(somaMod11)
-        while restoMod11 == 1:
-            primeiroDV = self.encontreValorValidoParaPrimeiroDV(primeiroDV)
-            somaMod11 = sum11(
-                seisPrimeirosCamposConcatenados + str(primeiroDV), 2, 7)
-            restoMod11 = self.calculeRestoMod11(somaMod11)
-        segundoDV = self.calculeSegundoDV(restoMod11)
-        return str(primeiroDV) + str(segundoDV)
-
-    def calculeSegundoDV(self, restoMod11):
-        if restoMod11 == 0:
-            return restoMod11
-        else:
-            return 11 - restoMod11
-
-    def calculePrimeiroDV(self, restoMod10):
-        if restoMod10 == 0:
-            return 0
-        else:
-            return 10 - restoMod10
-
-    def calculeRestoMod10(self, somaMod10):
-        if somaMod10 < 10:
-            return somaMod10
-        else:
-            return somaMod10 % 10
-
-    def encontreValorValidoParaPrimeiroDV(self, primeiroDV):
-        if primeiroDV == 9:
-            return 0
-        else:
-            return primeiroDV + 1
-
-    def calculeRestoMod11(self, somaMod11):
-        if somaMod11 < 11:
-            return somaMod11
-        else:
-            return somaMod11 % 11
-
     @property
     def campo_livre(self):
         content = '21%04d%07d%08d40' % (int(self.agencia),
                                         int(self.conta),
                                         int(self.nosso_numero))
-        dv = self.calculaDuploDigito(content)
+        dv = calculaDuploDigito(content)
         return '%s%s' % (content, dv)
 
 
@@ -540,7 +437,7 @@ class BankBradesco(BankInfo):
 
     @property
     def dv_nosso_numero(self):
-        resto2 = self.modulo11(self.nosso_numero, 7, 1)
+        resto2 = modulo11(self.nosso_numero, 7, 1)
         digito = 11 - resto2
         if digito == 10:
             dv = 'P'
@@ -564,15 +461,21 @@ class BankBradesco(BankInfo):
     def validate_option(cls, option, value):
         if option == 'carteira':
             if value == '':
-                return
+                # TRANSLATORS: Do not translate 'Carteira'
+                raise BoletoException(_("Carteira cannot be empty"))
             try:
                 value = int(value)
             except ValueError:
-                raise BoletoException("carteira tem que ser um número")
+                # TRANSLATORS: Do not translate 'Carteira'
+                raise BoletoException(_("Carteira must be a number"))
             if 0 > value:
-                raise BoletoException("carteira tem que ser entre 0 e 99")
+                raise BoletoException(
+                    # TRANSLATORS: Do not translate 'Carteira'
+                    _("Carteira must be a number between 0 and 99"))
             if value > 99:
-                raise BoletoException("carteira tem que ser entre 0 e 99")
+                raise BoletoException(
+                    # TRANSLATORS: Do not translate 'Carteira'
+                    _("Carteira must be a number between 0 and 99"))
 
 
 @register_bank
@@ -581,7 +484,6 @@ class BankBB(BankInfo):
     bank_number = 1
     logo = 'logo_bb.gif'
     options = {'convenio': BILL_OPTION_CUSTOM,
-               'len_convenio': BILL_OPTION_CUSTOM,
                'agencia': BILL_OPTION_BANK_BRANCH,
                'conta': BILL_OPTION_BANK_BRANCH}
 
@@ -592,10 +494,13 @@ class BankBB(BankInfo):
         if not 'carteira' in kwargs:
             kwargs['carteira'] = '18'
 
-        self.len_convenio = 7
-        if 'len_convenio' in kwargs:
-            self.len_convenio = int(kwargs.pop('len_convenio'))
-        self.convenio = ''
+        convenio = kwargs.pop('convenio', None)
+        if convenio:
+            self.len_convenio = len(convenio)
+            self.convenio = convenio
+        else:
+            self.len_convenio = 7
+            self.convenio = ''
 
         self.format_nnumero = 1
         if 'format_nnumero' in kwargs:
@@ -642,14 +547,14 @@ class BankBB(BankInfo):
     def agencia_conta(self):
         return "%s-%s / %s-%s" % (
             self.agencia,
-            self.modulo11(self.agencia),
+            modulo11(self.agencia),
             self.conta,
-            self.modulo11(self.conta)
+            modulo11(self.conta)
         )
 
     @property
     def dv_nosso_numero(self):
-        return self.modulo11(self.nosso_numero)
+        return modulo11(self.nosso_numero)
 
     agencia = custom_property('agencia', 4)
     conta = custom_property('conta', 8)
@@ -674,17 +579,18 @@ class BankBB(BankInfo):
     def validate_option(cls, option, value):
         if option == 'convenio':
             if value == '':
-                raise BoletoException('Convenio não pode ser vazio')
+                # TRANSLATORS: Do not translate 'Convenio'
+                raise BoletoException(_('Convenio cannot be empty'))
             try:
                 int(value)
             except ValueError:
-                raise BoletoException(_("Must be a number"))
-            if len(value) > 8:
-                raise BoletoException(_("Cannot be longer than %d") % (8,))
-
-        if option == 'len_convenio':
-            if value not in ['6', '7', '8']:
-                raise BoletoException('Tem que ser 6, 7 ou 8')
+                # TRANSLATORS: Do not translate 'Convenio'
+                raise BoletoException(_("Convenio must be a number"))
+            if len(value) not in [6, 7, 8]:
+                raise BoletoException(
+                    # TRANSLATORS: Do not translate 'Convenio'
+                    _("Convenio length must be 6, 7 or 8. Try filing it with "
+                      "'0's at the left."))
 
 
 @register_bank
@@ -712,7 +618,7 @@ class BankCaixa(BankInfo):
 
     @property
     def dv_nosso_numero(self):
-        resto2 = self.modulo11(self.nosso_numero.split('-')[0], 9, 1)
+        resto2 = modulo11(self.nosso_numero.split('-')[0], 9, 1)
         digito = 11 - resto2
         if digito == 10 or digito == 11:
             dv = 0
@@ -746,10 +652,10 @@ class BankItau(BankInfo):
     def dac_nosso_numero(self):
         agencia = self.agencia.split('-')[0]
         conta = self.conta.split('-')[0]
-        return self.modulo10(agencia +
-                             conta +
-                             self.carteira +
-                             self.nosso_numero)
+        return modulo10(agencia +
+                        conta +
+                        self.carteira +
+                        self.nosso_numero)
 
     def format_nosso_numero(self):
         return '%s/%s-%s' % (self.carteira,
@@ -762,7 +668,7 @@ class BankItau(BankInfo):
         conta = self.conta.split('-')[0]
         return '%s / %s-%s' % (agencia,
                                conta,
-                               self.modulo10(agencia + conta))
+                               modulo10(agencia + conta))
 
     @property
     def campo_livre(self):
@@ -774,7 +680,7 @@ class BankItau(BankInfo):
             self.dac_nosso_numero,
             agencia,
             conta,
-            self.modulo10(agencia + conta),
+            modulo10(agencia + conta),
             '000'
         )
 
@@ -799,7 +705,7 @@ class BankReal(BankInfo):
         num = "%s%s%s" % (self.nosso_numero,
                           self.agencia,
                           self.conta)
-        return self.modulo10(num)
+        return modulo10(num)
 
     @property
     def campo_livre(self):
@@ -834,12 +740,12 @@ class BankSantander(BankInfo):
     def format_nosso_numero(self):
         return "00000%s-%s" % (
             self.nosso_numero,
-            self.modulo11(self.nosso_numero))
+            modulo11(self.nosso_numero))
 
     @property
     def campo_livre(self):
         conta = self.formata_numero(self.conta, 7)
-        dv_nosso_numero = self.modulo11(self.nosso_numero)
+        dv_nosso_numero = modulo11(self.nosso_numero)
 
         return '%s%s00000%s%s%s%s' % (self.fixo,
                                       conta,
