@@ -34,13 +34,20 @@ from kiwi.python import namedAny
 from zope.interface import implementedBy
 from zope.interface.interface import InterfaceClass
 
+import stoqlib
 
-def get_all_classes(package):
+
+def get_all_classes(root):
     """
     Gets a generator with classes.
     :returns: a generator.
     """
-    for package in listpackages(package):
+    # Convert to absolute path so it works within documentation tools
+    basedir = os.path.dirname(stoqlib.__path__[0])
+    root = os.path.join(basedir, root)
+    for package in listpackages(root):
+        # Remove absolute path
+        package = package[len(basedir):]
         # stoqlib.domain -> stoqlib/domain
         package = package.replace('.', os.path.sep)
 
@@ -57,6 +64,9 @@ def get_all_classes(package):
 
             # stoqlib/domain/base.py -> stoqlib.domain.base
             modulename = filename[:-3].replace(os.path.sep, '.')
+            use_storm = 'STOQLIB_USE_STORM' in os.environ
+            if modulename == 'stoqlib.database.orm' and use_storm:
+                modulename = 'stoqlib.database.stormorm'
             module = namedAny(modulename)
             for unused, klass in inspect.getmembers(module, inspect.isclass):
                 yield klass
