@@ -28,9 +28,13 @@ import sys
 
 from zope.interface import implements
 from kiwi.component import get_utility, provide_utility
+from kiwi.log import Logger
+
 from stoqlib.lib.interfaces import ISystemNotifier
 from stoqlib.lib.uptime import get_uptime
 
+log = Logger('stoqlib.lib.message')
+
 
 class DefaultSystemNotifier:
     implements(ISystemNotifier)
@@ -58,23 +62,32 @@ provide_utility(ISystemNotifier, DefaultSystemNotifier())
 
 def info(short, description=None):
     sn = get_utility(ISystemNotifier)
+    log.info("Info: short='%s' description='%s'" %
+             (short, description))
     sn.info(short, description)
 
 
 def warning(short, description=None, *args, **kwargs):
     sn = get_utility(ISystemNotifier)
+    log.info("Warning: short='%s' description='%s'" %
+             (short, description))
     return sn.warning(short, description, *args, **kwargs)
 
 
 def error(short, description=None):
     sn = get_utility(ISystemNotifier)
+    log.info("Error: short='%s' description='%s'" %
+             (short, description))
     sn.error(short, description)
     sys.exit(1)
 
 
 def yesno(text, default=-1, *verbs):
     sn = get_utility(ISystemNotifier)
-    return sn.yesno(text, default, *verbs)
+    rv = sn.yesno(text, default, *verbs)
+    log.info("Yes/No: text='%s' verbs='%r' rv='%r'" %
+             (text, verbs, rv))
+    return rv
 
 
 def marker(msg):
