@@ -48,7 +48,7 @@ def get_application_dir(appname="stoq"):
     """Fetches a application specific directory,
     this can be used to save temporary files and other state.
     This also creates the directory if it doesn't exist
-    @returns: the application directory
+    :returns: the application directory
     """
     if _system == 'Linux':
         appdir = os.path.join(os.environ['HOME'], '.' + appname)
@@ -65,7 +65,7 @@ def get_application_dir(appname="stoq"):
 
 
 def get_documents_dir():
-    """@returns: the documents dir for the current user"""
+    """:returns: the documents dir for the current user"""
     if _system == 'Linux':
         return _get_xdg_dir("XDG_DOCUMENTS_DIR", "~/Documents")
     elif _system == 'Windows':
@@ -81,7 +81,7 @@ def get_documents_dir():
 
 
 def get_username():
-    """@returns: the current username"""
+    """:returns: the current username"""
     if _system == 'Linux' or _system == 'Darwin':
         return os.environ['USER']
     elif _system == 'Windows':
@@ -117,8 +117,8 @@ def read_registry_key(root, key, value):
 
 def list_recursively(directory, pattern):
     """Returns files recursively from directory matching pattern
-    @directory: directory to list
-    @pattern: glob mattern to match
+    :param directory: directory to list
+    :param pattern: glob mattern to match
     """
     matches = []
     for root, dirnames, filenames in os.walk(directory):
@@ -129,3 +129,15 @@ def list_recursively(directory, pattern):
                 continue
             matches.append(os.path.join(root, filename))
     return matches
+
+
+def find_program(program):
+    """Looks for program in PATH.
+    :param program: name of the program to find
+    :returns: the complete path of the program or None if it couldn't be found
+    """
+
+    for path in os.environ['PATH'].split(':'):
+        fullpath = os.path.join(path, program)
+        if os.path.exists(fullpath):
+            return fullpath
