@@ -39,6 +39,7 @@ from stoqlib.domain.parameter import ParameterData
 from stoqlib.exceptions import DatabaseInconsistency
 from stoqlib.l10n.l10n import get_l10n_field
 from stoqlib.lib.barcode import BarcodeInfo
+from stoqlib.lib.countries import get_countries
 from stoqlib.lib.kiwilibrary import library
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.validators import (validate_int,
@@ -58,7 +59,7 @@ class DirectoryParameter(object):
 
 class ParameterDetails(object):
     def __init__(self, key, group, short_desc, long_desc, type,
-                 initial=None, options=None, range=None,
+                 initial=None, options=None, combo_data=None, range=None,
                  multiline=False, validator=None, onupgrade=None):
         self.key = key
         self.group = group
@@ -67,6 +68,7 @@ class ParameterDetails(object):
         self.type = type
         self.initial = initial
         self.options = options
+        self.combo_data = combo_data
         self.range = range
         self.multiline = multiline
         self.validator = validator
@@ -129,6 +131,15 @@ class ParameterDetails(object):
                 _("'%s' is not a valid %s.")
                 % (value, state_l10n.label.lower(), ))
 
+    @staticmethod
+    def validate_city(value):
+        city_l10n = get_l10n_field(get_connection(), 'city')
+        state = sysparam(get_connection()).STATE_SUGGESTED
+        country = sysparam(get_connection()).COUNTRY_SUGGESTED
+        if not city_l10n.validate(value, state=state, country=country):
+            return ValidationError(_("'%s' is not a valid %s.") %
+                                   (value, city_l10n.label.lower()))
+
     #
     #  Private API
     #
@@ -252,7 +263,8 @@ _details = [
         _('Default city'),
         _('When adding a new address for a certain person we will always '
           'suggest this city.'),
-        str, initial='Sao Carlos'),
+        str, initial='São Carlos',
+        validator=ParameterDetails.validate_city),
 
     ParameterDetails(
         'STATE_SUGGESTED',
@@ -268,7 +280,18 @@ _details = [
         _('Default country'),
         _('When adding a new address for a certain person we will always '
           'suggest this country.'),
-        str, initial='Brazil'),
+        # FIXME: When fixing bug 5100, change this to BR
+        str, initial='Brazil', combo_data=get_countries),
+
+    ParameterDetails(
+        'ALLOW_REGISTER_NEW_LOCATIONS',
+        _('General'),
+        _('Allow registration of new city locations'),
+        # Change the note here when we have more locations to reflect it
+        _('Allow to register new city locations. A city location is a '
+          'single set of a country + state + city.\n'
+          'NOTE: Right now this will only work for brazilian locations.'),
+        bool, initial=False),
 
     ParameterDetails(
         'HAS_DELIVERY_MODE',
@@ -547,7 +570,27 @@ _details = [
           'replaced with the due date of the bill'),
         str, multiline=True, initial=""),
 
-]
+    ParameterDetails(
+        'BOOKLET_INSTRUCTIONS',
+        _('Sales'),
+        _('Booklet instructions '),
+        _('When printing booklets, include the first 4 lines of these on it. '
+          'This usually includes instructions on how to pay the booklet and '
+          'the validity and the terms.'),
+        str, multiline=True,
+        initial=_("Payable at any branch on presentation of this booklet")),
+
+    ParameterDetails(
+        'SMART_LIST_LOADING',
+        _('Smart lists'),
+        _('Load items intelligently from the database'),
+        _('This is useful when you have several thousand items, but it may cause '
+          'some problems as it\'s new and untested. If you want to preserve the old '
+          'list behavior in the payable and receivable applications, '
+          'disable this parameter.'),
+        bool,
+        initial=True),
+    ]
 
 
 class ParameterAccess(ClassInittableObject):
@@ -747,9 +790,10 @@ class ParameterAccess(ClassInittableObject):
 
         self._cache[param_name] = table.get(obj_id, connection=self.conn)
 
-    def clear_cache(self):
+    @classmethod
+    def clear_cache(cls):
         log.info("Clearing cache")
-        ParameterAccess._cache = {}
+        cls._cache = {}
 
     def get_parameter_constant(self, field_name):
         for detail in _details:
