@@ -23,6 +23,7 @@
 ##
 
 import imp
+import locale
 import os
 
 from kiwi.desktopparser import DesktopParser
@@ -34,6 +35,7 @@ from stoqlib.database.runtime import get_connection, new_transaction
 from stoqlib.domain.plugin import InstalledPlugin
 from stoqlib.lib.kiwilibrary import library
 from stoqlib.lib.interfaces import IPlugin, IPluginManager
+from stoqlib.lib.settings import get_settings
 
 log = Logger('stoq.pluginmanager')
 
@@ -47,8 +49,15 @@ class PluginDescription(object):
         self.name = os.path.basename(os.path.dirname(filename))
         self.entry = config.get('Plugin', 'Module')
         self.filename = filename
-        self.long_name = config.get('Plugin', 'Name')
-        self.description = config.get('Plugin', 'Description')
+
+        settings = get_settings()
+        lang = settings.get('user-locale', None)
+        if not lang:
+            # Locale comes in a tuple like ('en_US', 'UTF-8')
+            lang = locale.getlocale(locale.LC_MESSAGES)[0]
+
+        self.long_name = config.get_locale('Plugin', 'Name', lang)
+        self.description = config.get_locale('Plugin', 'Description', lang)
 
     @property
     def dirname(self):
@@ -166,10 +175,11 @@ class PluginManager(object):
 
         This will activate the C{plugin}, calling it's C{activate}
         method and possibly doing some extra logic (e.g. logging).
-        @important: Always activate a plugin using this method because
-            the manager keeps track of all active plugins. Else you
-            probably will activate the same plugin twice, and that
-            probably won't be good :)
+
+        :param important: Always activate a plugin using this method because
+          the manager keeps track of all active plugins. Else you
+          probably will activate the same plugin twice, and that
+          probably won't be good :)
 
         :param plugin: the :class:`IPlugin` implementation of the plugin
         """
@@ -194,7 +204,7 @@ class PluginManager(object):
         plugin = self.get_plugin(plugin_name)
 
         if plugin_name in self.installed_plugins_names:
-            raise PluginError("Plugin %s is already installed on database"
+            raise PluginError("Plugin %s is already enabled."
                               % (plugin_name, ))
 
         trans = new_transaction()
