@@ -31,10 +31,9 @@ from kiwi.db.query import DateIntervalQueryState
 from stoqlib.database.orm import ORMObjectQueryExecuter
 from stoqlib.database.runtime import get_connection, get_current_branch
 from stoqlib.domain.devices import FiscalDayHistory
-from stoqlib.domain.interfaces import ICompany
 from stoqlib.domain.inventory import Inventory
-from stoqlib.domain.person import (PersonAdaptToCompany,
-                                   PersonAdaptToIndividual)
+from stoqlib.domain.person import (Company,
+                                   Individual)
 from stoqlib.domain.receiving import ReceivingOrder
 from stoqlib.domain.sale import Sale
 from stoqlib.lib.sintegra import SintegraFile, SintegraError
@@ -72,7 +71,7 @@ class StoqlibSintegraGenerator(object):
     def _add_header(self):
         branch = get_current_branch(self.conn)
         manager = branch.manager.person
-        company = ICompany(branch.person)
+        company = branch.person.company
         address = branch.person.get_main_address()
 
         state_registry = company.get_state_registry_number()
@@ -117,13 +116,13 @@ class StoqlibSintegraGenerator(object):
     def _get_cnpj_or_cpf(self, receiving_order):
         person = receiving_order.supplier.person
         company = person.has_individual_or_company_facets()
-        if isinstance(company, PersonAdaptToCompany):
+        if isinstance(company, Company):
             if not company.cnpj:
                 raise SintegraError(
                     _("You need to have a CNPJ number set on Company %s" % (
                     company.person.name)))
             cnpj = company.get_cnpj_number()
-        elif isinstance(company, PersonAdaptToIndividual):
+        elif isinstance(company, Individual):
             cnpj = company.get_cpf_number()
         else:
             raise AssertionError
@@ -131,13 +130,13 @@ class StoqlibSintegraGenerator(object):
 
     def _get_state_registry(self, receiving_order):
         company = receiving_order.supplier.person.has_individual_or_company_facets()
-        if isinstance(company, PersonAdaptToCompany):
+        if isinstance(company, Company):
             if not company.state_registry:
                 raise SintegraError(
                     _("You need to have a State Registry set on Company %s" % (
                     company.person.name)))
             return company.get_state_registry_number()
-        elif isinstance(company, PersonAdaptToIndividual):
+        elif isinstance(company, Individual):
             return "ISENTO"
         else:
             raise AssertionError
@@ -354,11 +353,11 @@ def generate(filename, start, end):
     between start and end dates. Start and end are normally
     the first and last day of a month
 
-    @param filename: filename to save the sintegra file
-    @param start: start date
-    @type start: datetime.date
-    @param end: end date
-    @type start: datetime.date
+    :param filename: filename to save the sintegra file
+    :param start: start date
+    :type start: datetime.date
+    :param end: end date
+    :type start: datetime.date
     """
 
     generator = StoqlibSintegraGenerator(get_connection(), start, end)
